<?php
/**
 * Additional function
 */

/**
 * Browser detection functionality
 */
if ( ! function_exists( 'inspiry_ie_detect' ) ) {
	function inspiry_ie_detect() {
		$ie_version = '';

		if ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 6.' ) !== false ) {
			$ie_version = 'ie6';
		} elseif ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 7.' ) !== false ) {
			$ie_version = 'ie7';
		} elseif ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 8.' ) !== false ) {
			$ie_version = 'ie8';
		} elseif ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 9.' ) !== false ) {
			$ie_version = 'ie9';
		} elseif ( strpos( $_SERVER['HTTP_USER_AGENT'], 'MSIE 10.' ) !== false ) {
			$ie_version = 'ie10';
		}

		return $ie_version;
	}
}

if ( ! function_exists( 'inspiry_allowed_html_tags' ) ) {
	/**
	 * @return array Array of allowed html tags.
	 */
	function inspiry_allowed_html_tags() {

		$allowed_tags = array(
			'img'    => array(
				'src'   => array(),
				'class' => array(),
				'alt'   => array(),
				'style' => true,
			),
			'a'      => array(
				'class' => array(),
				'href'  => array(),
				'title' => array(),
			),
			'p'      => array(
				'style' => array(),
				'class' => array(),
			),
			'br'     => array(),
			'em'     => array(),
			'strong' => array(
				'class' => array(),
				'style' => array(),
			),
			'span'   => array(
				'class' => array(),
				'style' => array(),
			),
			'svg'    => array(
				'viewbox'           => array(),
				'width'             => array(),
				'height'            => array(),
				'class'             => array(),
				'enable-background' => array(),
				'xmlns'             => array(),
				'xmlns:xlink'       => array(),
				'x'                 => array(),
				'y'                 => array(),
				'xml:space'         => array(),
				'version'           => array(),
			),
			'path'   => array(
				'class' => array(),
				'd'     => array(),
			),
			'circle' => array(
				'class' => array(),
				'cx'    => array(),
				'cy'    => array(),
				'r'     => array(),
			),
			'g'      => array(
				'class' => array(),
			),
			'i'      => array(
				'class' => array(),
			),
			'iframe' => array(
				'src'             => array(),
				'frameborder'     => array(),
				'allowfullscreen' => array(),
			),
		);

		return apply_filters( 'frp_allowed_html_tags', $allowed_tags );
	}
}


if ( ! function_exists( 'inspiry_get_post_sort' ) ) {
	/**
	 * generate post/recipe sorting dropdown menu
	 */
	function inspiry_get_post_sort() {

		$recipe_sort = '';
		if ( isset( $_GET['sortby'] ) ) {
			$recipe_sort = $_GET['sortby'];
		}
		$current_url         = home_url( add_query_arg( null, null ) );
		$s                   = explode( '=', $current_url );
		$_GET['recipe-sort'] = end( $s );
		?>
		<form class="sorting-form" method="get" action="#">
			<label for="recipe-sorting"><?php esc_html_e( 'Sort : ', 'food-recipes-pack' ); ?></label>
			<select id="recipe-sorting" name="recipe-sort">
				<option 
				<?php
				if ( 'date' === $recipe_sort ) {
					echo esc_attr( 'selected' );
				}
				?>
				 value="date">
					<?php esc_html_e( 'Most Recent', 'food-recipes-pack' ); ?>
				</option>
				<option 
				<?php
				if ( 'rand' === $recipe_sort ) {
					echo esc_attr( 'selected' );
				}
				?>
				 value="rand">
					<?php esc_html_e( 'Rand', 'food-recipes-pack' ); ?>
				</option>
				<option 
				<?php
				if ( 'comment_count' === $recipe_sort ) {
					echo esc_attr( 'selected' );
				}
				?>
				 value="comment_count">
					<?php esc_html_e( 'Comment Count', 'food-recipes-pack' ); ?>
				</option>
				<option 
				<?php
				if ( 'title' === $recipe_sort ) {
					echo esc_attr( 'selected' );
				}
				?>
				 value="title">
					<?php esc_html_e( 'Title', 'food-recipes-pack' ); ?>
				</option>
				<option 
				<?php
				if ( 'rating_average' === $recipe_sort ) {
					echo esc_attr( 'selected' );
				}
				?>
				 value="rating_average">
					<?php esc_html_e( 'High Rated', 'food-recipes-pack' ); ?>
				</option>
				<option 
				<?php
				if ( 'rating_counter' === $recipe_sort ) {
					echo esc_attr( 'selected' );
				}
				?>
				 value="rating_counter">
					<?php esc_html_e( 'Most Rated', 'food-recipes-pack' ); ?>
				</option>
				<option 
				<?php
				if ( 'views' === $recipe_sort ) {
					echo esc_attr( 'selected' );
				}
				?>
				 value="views">
					<?php esc_html_e( 'Most Views', 'food-recipes-pack' ); ?>
				</option>
			</select>
		</form>
		<?php
	}
}


if ( ! function_exists( 'inspiry_generate_advance_search_form' ) ) {
	/**
	 * generate advance search form
	 */
	function inspiry_generate_advance_search_form() {
		if ( class_exists( 'Food_Recipes_Pack' ) ) {

			$search_page_url = get_option( 'adv_search_page_url' );
			$search_fields   = get_option( 'adv_search_fields_checkbox' );

			if ( ! is_array( $search_fields ) ) {
				$search_fields = explode( ',', $search_fields );
			}
			?>
			<div class="col-md-12">
				<form id="advance-search" method="get" action="<?php echo esc_url( $search_page_url ); ?>">
					<?php
					$taxonomies = get_object_taxonomies( 'recipe', 'objects' );
					$taxonomies = wp_list_pluck( $taxonomies, 'label', 'name' );
					$skip_tag   = array_shift( $taxonomies );
					foreach ( $taxonomies as $key => $taxonomy ) {
						if ( isset( $search_fields ) && $search_fields && in_array( $key, $search_fields, true ) ) {
							echo inspiry_build_taxonomy_search_select( $key, $taxonomy );
						}
					}

					if ( isset( $search_fields ) && $search_fields && in_array( 'authors', $search_fields, true ) ) :
						?>
						<fieldset class="search-field">
							<label
								for="recipe-authors"><?php esc_html_e( 'Recipe Authors', 'food-recipes-pack' ); ?></label>
							<?php
							$args = array(
								'show_option_all'  => null,
								'show_option_none' => esc_html__( 'Any', 'food-recipes-pack' ),
								'name'             => 'recipe_authors',
								'id'               => 'recipe-authors',
								'role__in'         => array( 'administrator', 'author' ),
								'role__not_in'     => null,
							);
							wp_dropdown_users( $args );
							?>
						</fieldset>
					<?php endif; ?>

					<fieldset>
						<input class="readmore" type="submit"
							   value="<?php esc_html_e( 'Search', 'food-recipes-pack' ); ?>"/>
					</fieldset>
				</form>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'inspiry_build_taxonomy_select' ) ) {
	/**
	 * Taxonomy drop down Functions.
	 */
	function inspiry_build_taxonomy_select( $tax_name ) {
		$x = '';
		if ( taxonomy_exists( $tax_name ) ) {
			$terms = get_terms( $tax_name );
			$any   = esc_html__( 'Any', 'food-recipes-pack' );
			if ( isset( $_GET[ $tax_name ] ) ) {
				$selected = $_GET[ $tax_name ];
			} else {
				$selected = 'any';
			}
			$x  = '<fieldset class="search-field"><label>' . str_replace( '_', ' ', ucwords( $tax_name ) ) . '</label><select name="' . $tax_name . '">';
			$x .= '<option value="">' . $any . '</option>';
			foreach ( $terms as $term ) {
				if ( $selected == $term->slug ) {
					$x .= '<option selected="selected" value="' . $term->slug . '">' . $term->name . '</option>';
				} else {
					$x .= '<option  value="' . $term->slug . '">' . $term->name . '</option>';
				}
			}
			$x .= '</select></fieldset>';
		}

		return $x;
	}
}

if ( ! function_exists( 'inspiry_build_taxonomy_search_select' ) ) {
	/**
	 * Taxonomy drop down Functions.
	 */
	function inspiry_build_taxonomy_search_select( $tax_name, $label ) {
		$x = '';
		if ( taxonomy_exists( $tax_name ) ) {
			$terms = get_terms( $tax_name );
			$any   = esc_html__( 'Any', 'food-recipes-pack' );
			if ( isset( $_GET[ $tax_name ] ) ) {
				$selected = $_GET[ $tax_name ];
			} else {
				$selected = 'any';
			}
			$x  = '<fieldset class="search-field"><label>' . esc_html( $label ) . '</label><select name="' . $tax_name . '">';
			$x .= '<option value="">' . $any . '</option>';
			foreach ( $terms as $term ) {
				if ( $selected == $term->slug ) {
					$x .= '<option selected="selected" value="' . $term->slug . '">' . $term->name . '</option>';
				} else {
					$x .= '<option  value="' . $term->slug . '">' . $term->name . '</option>';
				}
			}
			$x .= '</select></fieldset>';
		}

		return $x;
	}
}

if ( ! function_exists( 'inspiry_recipe_info' ) ) {
	/**
	 * Generate recipe information list
	 *
	 * @param $recipe_id int
	 * @param $info_items bool/array
	 */
	function inspiry_recipe_info( $recipe_id, $info_items = false ) {
		if ( 'show' === get_option( 'recipe_info_show_hide' ) ) {

			if ( ! $info_items ) {
				$info_items = array(
					'yield'     => esc_html__( 'Yield', 'food-recipes-pack' ),
					'servings'  => esc_html__( 'Servings', 'food-recipes-pack' ),
					'prep_time' => esc_html__( 'Prep Time', 'food-recipes-pack' ),
					'cook_time' => esc_html__( 'Cook Time', 'food-recipes-pack' ),
					'ready_in'  => esc_html__( 'Ready In', 'food-recipes-pack' ),
				);
			}

			$info_values = array();

			if ( is_array( $info_items ) ) {
				foreach ( $info_items as $key => $title ) {
					$info_values[ $key ]['title'] = $title;
					$info_values[ $key ]['value'] = get_post_meta( $recipe_id, 'RECIPE_META_' . $key, true );
				}
			}

			$time_value_ids = array(
				'prep_time',
				'cook_time',
				'ready_in',
			);

			if ( is_array( $info_values ) && count( $info_values ) > 0 ) {
				?>
				<ul class="recipe-info clearfix">
					<?php
					foreach ( $info_values as $val_key => $info_single ) {
						if ( ! empty( $info_single['value'] ) ) {
							if ( in_array( $val_key, $time_value_ids ) ) {
								$info_single['value'] = convert_to_hours( $info_single['value'] );
							}
							?>
							<li class="yield">
								<strong class="name"><?php echo esc_html( $info_single['title'] ); ?>: </strong>
								<span class="value"
									  itemprop="recipeYield"><?php echo esc_attr( $info_single['value'] ); ?></span>
							</li>
							<?php
						}
					}
					?>
				</ul>
				<?php
			}
		}
	}
}


if ( ! function_exists( 'inspiry_generate_weekly_recipe' ) ) {
	/**
	 * Weekly Special Recipe Widget function
	 *
	 * @param $select_id int
	 * @param $name string
	 * @param $post_type string
	 * @param $selected int
	 */
	function inspiry_generate_weekly_recipe( $select_id, $name, $post_type, $selected = 0 ) {
		$label  = '--Choose One--';
		$recipe = get_posts(
			array(
				'post_type'        => $post_type,
				'post_status'      => 'publish',
				'suppress_filters' => false,
				'posts_per_page'   => - 1,
			)
		);
		echo '<select style="width:224px;" name="' . $name . '" id="' . $select_id . '">';
		echo '<option value = "" >' . $label . ' </option>';
		foreach ( $recipe as $post ) {
			echo '<option value="', $post->ID, '"', $selected == $post->ID ? ' selected="selected"' : '', '>', $post->post_title, '</option>';
		}
		echo '</select>';
	}
}


if ( ! function_exists( 'minutes_to_schema_time' ) ) {
	/**
	 * Minutes to Schema Time Conversion
	 *
	 * @param integer $time
	 * @return string $schema_time
	 */
	function minutes_to_schema_time( $time ) {

		if ( $time ) {
			if ( $time > 60 ) {
				$hours       = floor( $time / 60 );
				$minutes     = $time - ( $hours * 60 );
				$minutes     = ( $minutes === 0 ) ? null : $minutes . 'M';
				$hours       = ( $hours === 0 ) ? null : $hours . 'H';
				$schema_time = 'PT' . $hours . $minutes;
			} else {
				$schema_time = 'PT' . $time . 'M';
			}

			return $schema_time;
		} else {
			return false;
		}
	}
}


/**
 * Adding Data Structure for Recipe Single template
 */
if ( ! function_exists( 'inspiry_recipe_data_structure_json_head' ) ) {
	function inspiry_recipe_data_structure_json_head() {
		global $post, $allowed_html_tags;
		if ( is_singular( 'recipe' ) ) {
			$recipe_id   = $post->ID;
			$meta_prefix = 'RECIPE_META_';
			?>
			<script type="application/ld+json">
				{
					"@context": "http://schema.org/",
					"@type": "Recipe",
					"name": "<?php echo get_the_title( $recipe_id ); ?>",
					<?php
					if ( has_post_thumbnail() ) {
						?>
						"image": [
							"<?php echo get_the_post_thumbnail_url( $recipe_id ); ?>"
						],
						<?php
					} else {
						$gallery_images = rwmb_meta(
							'RECIPE_META_more_images_recipe',
							array(
								'type' => 'image_advanced',
								'size' => 'thumbnail-blog',
							),
							$recipe_id
						);

						if ( ! empty( $gallery_images ) ) {
							foreach ( $gallery_images as $gallery_image ) {
								?>
								"image": [
									"<?php echo $gallery_image['full_url']; ?>"
								],
								<?php
								break;
							}
						}
					}

					$post_author_id = get_post_field( 'post_author', $recipe_id );
					$chef_name      = get_the_author_meta( 'display_name', $post_author_id );
					if ( ! empty( $chef_name ) ) {
						?>
						"author": {
							"@type": "Person",
							"name": "<?php echo esc_html( $chef_name ); ?>"
						},
						<?php
					}
					?>

					"datePublished": "<?php the_time( 'Y-d-m' ); ?>",
					"description": "<?php echo strip_tags( wp_trim_words( get_the_excerpt( $recipe_id ), 55 ) ); ?>",
					"prepTime": "<?php echo minutes_to_schema_time( get_post_meta( $recipe_id, $meta_prefix . 'prep_time', true ) ); ?>",
					"cookTime": "<?php echo minutes_to_schema_time( get_post_meta( $recipe_id, $meta_prefix . 'cook_time', true ) ); ?>",
					"totalTime": "<?php echo minutes_to_schema_time( get_post_meta( $recipe_id, $meta_prefix . 'ready_in', true ) ); ?>",
					"recipeYield": "<?php echo get_post_meta( $recipe_id, $meta_prefix . 'yield', true ); ?>",
					<?php
					$recipe_types = get_the_terms( $recipe_id, 'recipe_type' );
					if ( ! is_wp_error( $recipe_types ) && count( $recipe_types ) > 0 ) {
						?>
						"recipeCategory": 
						<?php
						foreach ( $recipe_types as $type ) {
							echo '"' . esc_html( $type->name ) . '"';
							break;
						}
						?>
						,
						<?php
					}

					$recipe_cuisines = get_the_terms( $recipe_id, 'cuisine' );
					if ( ! is_wp_error( $recipe_cuisines ) && count( $recipe_cuisines ) > 0 ) {
						?>
						"recipeCuisine": 
						<?php
						foreach ( $recipe_cuisines as $cuisine ) {
							echo '"' . esc_html( $cuisine->name ) . '"';
							break;
						}
						?>
						,
						<?php
					}

					$recipe_tags = get_the_tags();
					if ( is_array( $recipe_tags ) ) {
						$first = true;
						?>
					"keywords": "
						<?php
						foreach ( $recipe_tags as $tag ) {
							echo ( ! $first ) ? ', ' : '';
							echo esc_attr( $tag->name );
							$first = false;
						}
						?>
						",
						<?php
					}

					// Nutritional Information
					$nutrients = array();

					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_calories', true ) ) ) {
						$nutrients['calories']['name']  = 'Calories';
						$nutrients['calories']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_calories', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_carbohydrates', true ) ) ) {
						$nutrients['carbohydrateContent']['name']  = 'Carbohydrates';
						$nutrients['carbohydrateContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_carbohydrates', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_cholesterol', true ) ) ) {
						$nutrients['cholesterolContent']['name']  = 'Cholesterol';
						$nutrients['cholesterolContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_cholesterol', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_fat', true ) ) ) {
						$nutrients['fatContent']['name']  = 'Fat';
						$nutrients['fatContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_fat', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_fiber', true ) ) ) {
						$nutrients['fiberContent']['name']  = 'Fiber';
						$nutrients['fiberContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_fiber', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_protein', true ) ) ) {
						$nutrients['proteinContent']['name']  = 'Protein';
						$nutrients['proteinContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_protein', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_saturated_fat', true ) ) ) {
						$nutrients['saturatedFatContent']['name']  = 'Saturated Fat';
						$nutrients['saturatedFatContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_saturated_fat', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_serving_size', true ) ) ) {
						$nutrients['servingSize']['name']  = 'Serving Size';
						$nutrients['servingSize']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_serving_size', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_sodium', true ) ) ) {
						$nutrients['sodiumContent']['name']  = 'Sodium';
						$nutrients['sodiumContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_sodium', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_sugar', true ) ) ) {
						$nutrients['sugarContent']['name']  = 'Sugar';
						$nutrients['sugarContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_sugar', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_trans_fat', true ) ) ) {
						$nutrients['transFatContent']['name']  = 'Trans Fat';
						$nutrients['transFatContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_trans_fat', true );
					}
					if ( ! empty( get_post_meta( $post->ID, $meta_prefix . 'nut_unsaturated_fat', true ) ) ) {
						$nutrients['unsaturatedFatContent']['name']  = 'Unsaturated Fat';
						$nutrients['unsaturatedFatContent']['value'] = get_post_meta( $post->ID, $meta_prefix . 'nut_unsaturated_fat', true );
					}

					if ( is_array( $nutrients ) && count( $nutrients ) > 0 ) {
						$first = true;
						$sep   = '';
						?>
						"nutrition": {
							"@type": "NutritionInformation",
							"description": "This information is per serving.",
							<?php
							foreach ( $nutrients as $nut_key => $nutrient ) {
								if ( $first ) {
									$first = false;
								} else {
									$sep = ',';
								}
								echo esc_html( $sep );
								?>
								"<?php echo esc_html( $nut_key ); ?>": "<?php echo esc_html( $nutrient['value'] ); ?>"
								<?php
							}
							?>
						},
						<?php
					}

					$ingredients = get_the_terms( $recipe_id, 'ingredient' );
					if ( ! is_wp_error( $ingredients ) && count( $ingredients ) > 0 ) {
						?>
						"recipeIngredient": [
						<?php
						$first = true;
						$sep   = '';
						foreach ( $ingredients as $ingredient ) {
							if ( $first ) {
								$first = false;
							} else {
								$sep = ',';
							}
							echo esc_html( $sep ) . '"' . esc_html( $ingredient->name ) . '"';
						}
						?>
						],
						<?php
					}

					// Instruction Details
					$instructions = get_post_meta( $recipe_id, 'RECIPE_META_method_steps', true );
					if ( ! is_wp_error( $instructions ) && is_array( $instructions ) ) {
						$instructions_count = count( $instructions );
						$count              = 0;
						?>
						"recipeInstructions": [
						<?php
						foreach ( $instructions as $instruction ) {
							?>
								{
								"@type": "HowToStep",
								"text": "<?php echo wp_kses( $instruction, $allowed_html_tags ); ?>"
								}
								<?php
								$count ++;
								echo ( $count != $instructions_count ) ? ',' . PHP_EOL : '';
								?>
							<?php
						}
						?>
						],
						<?php
					}

					if (
						get_post_meta( $recipe_id, 'RECIPE_META_recipe_video_check', true ) == 'on'
						&& ! empty( get_post_meta( $recipe_id, 'RECIPE_META_recipe_video_code', true ) )
					) {
						preg_match( '/src="([^"]+)"/', get_post_meta( $recipe_id, 'RECIPE_META_recipe_video_code', true ), $match );
						$embed_url = $match[1];
						if ( ! empty( get_post_meta( $recipe_id, 'RECIPE_META_rsd_video_title', true ) ) ) {
							$video_name = get_post_meta( $recipe_id, 'RECIPE_META_rsd_video_title', true );
						} else {
							$video_name = get_the_title( $recipe_id );
						}
						if ( ! empty( get_post_meta( $recipe_id, 'RECIPE_META_rsd_video_description', true ) ) ) {
							$video_desc = get_post_meta( $recipe_id, 'RECIPE_META_rsd_video_description', true );
						} else {
							$video_desc = strip_tags( wp_trim_words( get_the_excerpt( $recipe_id ), 55 ) );
						}
						if ( ! empty( get_post_meta( $recipe_id, 'RECIPE_META_rsd_video_thumbnail', true ) ) ) {
							$video_thumb_url = wp_get_attachment_url( get_post_meta( $recipe_id, 'RECIPE_META_rsd_video_thumbnail', true ) );
						} else {
							$video_thumb_url = get_the_post_thumbnail_url( $recipe_id, 'thumbnail' );
						}
						?>
						"video": {
							"@type": "VideoObject",
							"name": "<?php echo esc_html( $video_name ); ?>",
							<?php
							if ( ! empty( $video_thumb_url ) ) {
								?>
								"thumbnailURL": "<?php echo esc_url( $video_thumb_url ); ?>",
								<?php
							}
							if ( ! empty( get_post_meta( $recipe_id, 'RECIPE_META_rsc_video_upload_date', true ) ) ) {
								?>
									"uploadDate": "<?php echo get_post_meta( $recipe_id, 'RECIPE_META_rsc_video_upload_date', true ); ?>",
									<?php
							}
							?>
							"description": "<?php echo wp_kses( $video_desc, $allowed_html_tags ); ?>",
							"embedUrl": "<?php echo esc_url( $embed_url ); ?>"
						  },
						<?php
					}

					$rating     = new Food_Recipes_Pack_Pack_Rating();
					$rate_count = $rating->get_vote_count( $post->ID );
					$avg_rating = $rating->get_avg_rating( $post->ID );

					if ( ! empty( $rate_count ) || ! empty( $avg_rating ) ) {
						?>
						"aggregateRating": {
							"@type": "AggregateRating",
							<?php
							if ( ! empty( $rate_count ) ) {
								?>
								"ratingCount": "<?php echo esc_html( $rate_count ); ?>"
								<?php
							}
							if ( ! empty( $avg_rating ) ) {
								?>
								,"ratingValue": "<?php echo esc_html( $avg_rating ); ?>"
								<?php
							}
							?>
						}
						<?php
					}
					?>
				}
			</script>
			<?php
		}
	}

	add_action( 'wp_head', 'inspiry_recipe_data_structure_json_head', 99 );
}
