<?php
/**
 * Class Food_Recipes_Meta_Boxes
 *
 * Class to handle stuff related to meta boxes.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( !class_exists( 'Food_Recipes_Meta_Boxes' ) ) {
	class Food_Recipes_Meta_Boxes {

		/**
		 * Initialize meta box extensions
		 *
		 */
		public static function init() {
			do_action( 'food_recipes_before_meta_boxes_init' );

			// Deactivate meta box plugin if it is installed and active
			add_action( 'init', array( __CLASS__, 'deactivate_meta_box_plugin' ) );

			self::includes();

			// Doctors Meta Boxes
			include_once( plugin_dir_path( dirname( __FILE__ ) ) . '/includes/metabox/recipe-meta-boxes.php' );

			do_action( 'food_recipes_meta_boxes_init' );
		}

		/**
		 * Include meta box extensions if plugin exists
		 *
		 * @since 4.0.0
		 */
		protected static function includes() {

			// Include meta box
			if ( ! class_exists( 'RW_Meta_Box' ) ) {
				if ( file_exists( plugin_dir_path( dirname( __FILE__ ) ) . '/includes/metabox/core/meta-box.php' ) ) {
					include_once( plugin_dir_path( dirname( __FILE__ ) ) . '/includes/metabox/core/meta-box.php' );
				}
			}

			// Include show hide extension
			if ( class_exists( 'RW_Meta_Box' ) ) {
				if ( file_exists( plugin_dir_path( dirname( __FILE__ ) ) . '/includes/metabox/extensions/meta-box-columns/meta-box-columns.php' ) ) {
					include_once( plugin_dir_path( dirname( __FILE__ ) ) . '/includes/metabox/extensions/meta-box-columns/meta-box-columns.php' );
				}
				if ( file_exists( plugin_dir_path( dirname( __FILE__ ) ) . '/includes/metabox/extensions/meta-box-tabs/meta-box-tabs.php' ) ) {
					include_once( plugin_dir_path( dirname( __FILE__ ) ) . '/includes/metabox/extensions/meta-box-tabs/meta-box-tabs.php' );
				}
			}

		}

		/**
		 * Deactivate meta box plugin if it is active.
		 */
		public static function deactivate_meta_box_plugin() {

			if ( ! function_exists( 'is_plugin_active' ) ) {
				require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
			}

			// Meta Box Plugin
			if ( is_plugin_active( 'meta-box/meta-box.php' ) ) {
				deactivate_plugins( 'meta-box/meta-box.php' );

				add_action( 'admin_notices', function() {
					?>
					<div class="update-nag notice is-dismissible">
						<p>
							<strong><?php esc_html_e( 'Meta Box plugin has been deactivated!', 'food-recipes-pack' ); ?></strong>
						</p>
						<p><?php esc_html_e( 'As similar functionality is already embedded with in Food Recipes Pack plugin.', 'food-recipes-pack' ); ?></p>
						<p>
							<em><?php esc_html_e( 'So, You should completely remove it from your plugins.', 'food-recipes-pack' ); ?></em>
						</p>
					</div>
					<?php
				} );
			}

		}

	}
}

/*
 * Initialize meta boxes.
 */
Food_Recipes_Meta_Boxes::init();