<?php

/**
 * The admin-specific functionality of the plugin.
 */
class Food_Recipes_Pack_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.3
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.3
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 * @param      string    $plugin_name   The name of this plugin.
	 * @param      string    $version       The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->load_dependencies();
		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Load the required dependencies for the admin side of the plugin.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 */
	private function load_dependencies() {

		/**
		 * This widget displays custom archive
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/custom-archive-widget.php';

		/**
		 * This widget displays footer info
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/footer-info-widget.php';

		/**
		 * This widget displays homepage ad
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/homepage-ad-widget.php';

		/**
		 * This widget displays the news and events
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/news-and-events.php';

		/**
		 * This widget displays recent recipe footer
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/recent-recipe-footer-widget.php';

		/**
		 * This widget displays recipe tabs
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/recipe-tabs-widget.php';

		/**
		 * This widget displays recipe types
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/recipe-types-widget.php';

		/**
		 * This widget displays recipes slider cuisine
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/recipes-slider-cuisine-widget.php';

		/**
		 * This widget displays recipes slider recipe type
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/recipes-slider-recipe-type-widget.php';

		/**
		 * This widget displays recipe sidebar ad
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/sidebar-ad-widget.php';

		/**
		 * This widget displays weekly special
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/widgets/weekly-special-widget.php';

		/**
		 * This short code displays columns
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/shortcodes/class-food-recipes-columns.php';

		/**
		 * This short code displays elements
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/shortcodes/class-food-recipes-elements.php';

		/**
		 * This short code displays typography
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/shortcodes/class-food-recipes-typography.php';

		/**
		 * This short code displays Recipe Post Type
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-post-type.php';

		/**
		 * This file contains Contact Mail Functions
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-pack-mail.php';

		/**
		 * This file contains additional user fields related functions
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-user-fields.php';

		/**
		 * This file contains Customizer repeater class
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/custom/inc/customizer-repeater.php';

		/**
		 * This file contains Customizer multi checkbox class
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/custom/multi-checkboxes/inc/multi-checkbox.php';

		/**
		 * This file contains Customizer options class
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-food-recipes-pack-customizer.php';

	}

	/**
	 * Register Widgets
	 *
	 * @since    1.0.0
	 */
	public function register_theme_widgets() {

		if ( function_exists( 'register_widget' ) ) {
			register_widget( 'Recipe_Sidebar_Tabed_Widget' );
			register_widget( 'Recipe_News_And_Events_Widget' );
			register_widget( 'Recipe_Archive_Widget' );
			register_widget( 'Recipe_Types_Widget' );
			register_widget( 'Weekly_Special_Widget' );
			register_widget( 'Homepage_Ad_Widget' );
			register_widget( 'Sidebar_Ad_Widget' );
			register_widget( 'Recent_Recipe_Footer_Widget' );
			register_widget( 'Recipes_from_Cuisine' );
			register_widget( 'Recipes_from_Recipe_Type' );
			register_widget( 'Footer_Info_Widget' );
		}

	}

	/**
	 * Register the stylesheets for the admin area.
	 * @since    1.0.3
	 */
	public function enqueue_styles() {

		if ( is_admin() ) {
			wp_enqueue_style( $this->plugin_name, PLUGIN_URI . '/css/frp-admin-styles.css', array(), $this->version, 'all');
		}

	}

	/**
	 * Set Post Type Columns For Users
	 * @since 1.0.3
	 * @param $columns
	 * @return array|string
	 */
	public function inspiry_add_user_post_type_columns( $columns ) {
		$user_recipes_column[ 'inspiry_user_recipes_col' ] = esc_html__( 'Recipes', 'food-recipes-pack' );
		$columns = array_merge( $columns, $user_recipes_column );
		return $columns;
	}

	/**
	 * Set Values for Post Type Columns
	 * @since 1.0.3
	 * @param $value
	 * @param $column_name
	 * @param $user_id
	 * @return array|string
	 */
	public function inspiry_manage_post_type_columns( $value, $column_name, $user_id ){
		$user_recipes = 0;
		if ( 'inspiry_user_recipes_col' == $column_name ) {
			$user_recipes = count_user_posts( $user_id, 'recipe' );
		}
		return '<div class="num">' . $user_recipes . '</div>';
	}

	/**
	 * Make Columns Sortable
	 * @since 1.0.3
	 * @param $columns
	 * @return array|string
	 */
	public function make_add_post_type_sortable( $columns ) {
			$columns['inspiry_user_recipes_col'] = 'inspiry_user_recipes_col';
			return $columns;
	}
}