<?php

/**
 * The admin-specific functionality of the plugin.
 */
class Food_Recipes_Pack_WP_Customize_Manager {

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct() {

	}


	public function inspiry_admin_customizer( WP_Customize_Manager $wp_customize ) {

		$wp_customize->add_setting(
			'recipe_show_rating',
			array(
				'type'              => 'option',
				'default'           => 'show_rating',
				'sanitize_callback' => 'theme_sanitize_select',
			)
		);
		$wp_customize->add_control(
			'recipe_show_rating',
			array(
				'label'       => esc_html__( 'Show Rating for Recipe post', 'food-recipes-pack' ),
				'description' => esc_html__( 'Select if you want to Show or Hide Rating for recipe post.', 'food-recipes-pack' ),
				'type'        => 'select',
				'section'     => 'inspiry_recipe_single_section',
				'choices'     => array(
					'show_rating' => esc_html__( 'Show', 'food-recipes-pack' ),
					'hide_rating' => esc_html__( 'Hide', 'food-recipes-pack' ),
				),
			)
		);

		$wp_customize->add_setting(
			'contact_form_heading',
			array(
				'type'              => 'option',
				'transport'         => 'postMessage',
				'default'           => 'Contact Form',
				'sanitize_callback' => 'sanitize_text_field',
			)
		);
		$wp_customize->add_control(
			'contact_form_heading',
			array(
				'label'       => esc_html__( 'Contact Form Heading', 'food-recipes-pack' ),
				'description' => esc_html__( 'Give a heading to your contact form.', 'food-recipes-pack' ),
				'type'        => 'text',
				'section'     => 'inspiry_contact_page_section',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'contact_form_heading',
			array(
				'selector'        => '#contact-template-form-heading',
				'render_callback' => function () use ( $wp_customize ) {
					return $wp_customize->get_setting( 'contact_form_heading' )->value();
				},
			)
		);

		$wp_customize->add_setting(
			'contact_email_address',
			array(
				'type'              => 'option',
				'transport'         => 'postMessage',
				'default'           => get_bloginfo( 'admin_email' ),
				'sanitize_callback' => 'sanitize_email',
			)
		);
		$wp_customize->add_control(
			'contact_email_address',
			array(
				'label'       => esc_html__( 'Contact Form Email', 'food-recipes-pack' ),
				'description' => esc_html__( 'Enter an email address that will receive contact form messages.', 'food-recipes-pack' ),
				'type'        => 'email',
				'section'     => 'inspiry_contact_page_section',
			)
		);

		$wp_customize->add_setting(
			'recipe_show_social_icons',
			array(
				'type'              => 'option',
				'default'           => 'show_social',
				'sanitize_callback' => 'theme_sanitize_select',
			)
		);
		$wp_customize->add_control(
			'recipe_show_social_icons',
			array(
				'label'       => esc_html__( 'Show Social icons on Single Recipe Page', 'food-recipes-pack' ),
				'description' => esc_html__( 'Select if you want to Show or Hide social icons at the end of each single recipe.', 'food-recipes-pack' ),
				'type'        => 'select',
				'section'     => 'inspiry_recipe_single_section',
				'choices'     => array(
					'show_social' => esc_html__( 'Show', 'food-recipes-pack' ),
					'hide_social' => esc_html__( 'Hide', 'food-recipes-pack' ),
				),
			)
		);

		$wp_customize->add_setting( 'post_show_social_icons', array(
			'type'              => 'option',
			'default'           => 'show_social',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'post_show_social_icons', array(
			'label'       => esc_html__( 'Show Social icons on Single Post Page', 'FoodRecipe' ),
			'description' => esc_html__( 'Select if you want to enable or disable social icons at the end of each post single page.', 'FoodRecipe' ),
			'type'        => 'select',
			'section'     => 'inspiry_blog_section',
			'choices'     => array(
				'show_social' => esc_html__( 'Show', 'FoodRecipe' ),
				'hide_social' => esc_html__( 'Hide', 'FoodRecipe' ),
			),
		) );
	}

	public function inspiry_recipe_single_customizer( WP_Customize_Manager $wp_customize ) {


		$wp_customize->add_section( 'inspiry_recipe_single_section', array(
			'title'    => esc_html__( 'Recipe Single', 'FoodRecipe' ),
			'priority' => 32,
		) );


		$wp_customize->add_setting( 'recipe_template_type', array(
			'type'              => 'option',
			'default'           => 'Recipe Template with Sidebar',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'recipe_template_type', array(
			'label'       => esc_html__( 'Select Single Recipe Template Type', 'FoodRecipe' ),
			'description' => esc_html__( 'Select from the options how you want to show your single recipe page.', 'FoodRecipe' ),
			'type'        => 'select',
			'section'     => 'inspiry_recipe_single_section',
			'choices'     => array(
				'Recipe Template with Sidebar'     => esc_html__( 'Recipe Template with Sidebar', 'FoodRecipe' ),
				'Recipe Template Full Width'       => esc_html__( 'Recipe Template Full Width', 'FoodRecipe' ),
				'Recipe Template Full Width Video' => esc_html__( 'Recipe Template With Full Width Video', 'FoodRecipe' ),
			),
		) );

		$wp_customize->add_setting( 'recipe_info_show_hide', array(
			'type'              => 'option',
			'default'           => 'show',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'recipe_info_show_hide', array(
			'label'       => esc_html__( 'Do you want to show recipe info', 'FoodRecipe' ),
			'description' => esc_html__( 'Please select if you want to show recipe information under slider on recipe single.', 'FoodRecipe' ),
			'type'        => 'select',
			'section'     => 'inspiry_recipe_single_section',
			'choices'     => array(
				'show' => esc_html__( 'Show', 'FoodRecipe' ),
				'hide' => esc_html__( 'Hide', 'FoodRecipe' ),
			),
		) );


		$wp_customize->add_setting( 'recipe_right_info_show_hide', array(
			'type'              => 'option',
			'default'           => 'show',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'recipe_right_info_show_hide', array(
			'label'       => esc_html__( 'Do you want to show recipe information column.', 'FoodRecipe' ),
			'description' => esc_html__( 'Please select if you want to show recipe information column which are rating, nutritional info, author info, and related recipes in right section on recipe single.', 'FoodRecipe' ),
			'type'        => 'select',
			'section'     => 'inspiry_recipe_single_section',
			'choices'     => array(
				'show' => esc_html__( 'Show', 'FoodRecipe' ),
				'hide' => esc_html__( 'Hide', 'FoodRecipe' ),
			),
		) );


		$wp_customize->add_setting( 'more_recipe_show_hide', array(
			'type'              => 'option',
			'default'           => 'show',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'more_recipe_show_hide', array(
			'label'           => esc_html__( 'Do you want to show related/more recipes', 'FoodRecipe' ),
			'description'     => esc_html__( 'Please select if you want to show/hide more/related recipes on single recipe.', 'FoodRecipe' ),
			'type'            => 'select',
			'section'         => 'inspiry_recipe_single_section',
			'choices'         => array(
				'show' => esc_html__( 'Show', 'FoodRecipe' ),
				'hide' => esc_html__( 'Hide', 'FoodRecipe' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'show' === $wp_customize->get_setting( 'recipe_right_info_show_hide' )->value();
			},
		) );

		$wp_customize->add_setting( 'recipe_author_show_hide', array(
			'type'              => 'option',
			'default'           => 'show',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'recipe_author_show_hide', array(
			'label'           => esc_html__( 'Do you want to show recipe author info', 'FoodRecipe' ),
			'description'     => esc_html__( 'Please select if you want to show/hide recipe author information on recipe single.', 'FoodRecipe' ),
			'type'            => 'select',
			'section'         => 'inspiry_recipe_single_section',
			'choices'         => array(
				'show' => esc_html__( 'Show', 'FoodRecipe' ),
				'hide' => esc_html__( 'Hide', 'FoodRecipe' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'show' === $wp_customize->get_setting( 'recipe_right_info_show_hide' )->value();
			},
		) );

		$wp_customize->add_setting( 'recipe_nutrition_show_hide', array(
			'type'              => 'option',
			'default'           => 'show',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'recipe_nutrition_show_hide', array(
			'label'           => esc_html__( 'Do you want to show recipe nutritional info', 'FoodRecipe' ),
			'description'     => esc_html__( 'Please select if you want to show/hide recipe nutritional information on recipe single.', 'FoodRecipe' ),
			'type'            => 'select',
			'section'         => 'inspiry_recipe_single_section',
			'choices'         => array(
				'show' => esc_html__( 'Show', 'FoodRecipe' ),
				'hide' => esc_html__( 'Hide', 'FoodRecipe' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'show' === $wp_customize->get_setting( 'recipe_right_info_show_hide' )->value();
			},
		) );

	}

	public function inspiry_recipe_slugs_customizer( WP_Customize_Manager $wp_customize ) {


		$wp_customize->add_section( 'inspiry_recipe_slugs_section', array(
			'title'    => esc_html__( 'Recipe Slugs', 'FoodRecipe' ),
			'priority' => 33,
		) );


		$wp_customize->add_setting( 'recipe_slug', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => 'recipe',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'recipe_slug', array(
			'label'       => esc_html__( 'Recipe Post.', 'FoodRecipe' ),
			'description' => sprintf( esc_html__( 'If you want to change recipe related slugs then you can use below fields. Slug name should be lowercase without space and only in alphabets. Do not use any special characters or digits. If you want further information then consider %s article. %s After changing slugs, please save the permalinks twice so WordPress can rewrite the slugs. You can find the permalinks under %s as shown %s.', 'FoodRecipe' ), '<a target="_blank" href="http://www.wpbeginner.com/glossary/post-slug/"><strong>THIS</strong></a>', '<br><strong>Important:</strong>', '<strong>SETTINGS</strong>', '<a target="_blank" href="http://jmp.sh/MMjSWtx">HERE</a>' ),
			'type'        => 'text',
			'section'     => 'inspiry_recipe_slugs_section',
		) );

		$wp_customize->add_setting( 'recipe_type_slug', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => 'recipe-type',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'recipe_type_slug', array(
			'label'   => esc_html__( 'Recipe Type Taxonomy.', 'FoodRecipe' ),
			'type'    => 'text',
			'section' => 'inspiry_recipe_slugs_section',
		) );

		$wp_customize->add_setting( 'recipe_cuisine_slug', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => 'cuisine',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'recipe_cuisine_slug', array(
			'label'   => esc_html__( 'Recipe Cuisine Taxonomy.', 'FoodRecipe' ),
			'type'    => 'text',
			'section' => 'inspiry_recipe_slugs_section',
		) );

		$wp_customize->add_setting( 'recipe_course_slug', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => 'course',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'recipe_course_slug', array(
			'label'   => esc_html__( 'Recipe Course Taxonomy.', 'FoodRecipe' ),
			'type'    => 'text',
			'section' => 'inspiry_recipe_slugs_section',
		) );

		$wp_customize->add_setting( 'recipe_ingredient_slug', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => 'ingredient',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'recipe_ingredient_slug', array(
			'label'   => esc_html__( 'Recipe Ingredient Taxonomy.', 'FoodRecipe' ),
			'type'    => 'text',
			'section' => 'inspiry_recipe_slugs_section',
		) );

		$wp_customize->add_setting( 'recipe_skill_level_slug', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => 'skill-level',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'recipe_skill_level_slug', array(
			'label'   => esc_html__( 'Recipe Skill Level Taxonomy.', 'FoodRecipe' ),
			'type'    => 'text',
			'section' => 'inspiry_recipe_slugs_section',
		) );

	}

	public function inspiry_recipe_submit_customizer( WP_Customize_Manager $wp_customize ) {


		$wp_customize->add_section( 'inspiry_recipe_submit_section', array(
			'title'    => esc_html__( 'Recipe Submit', 'FoodRecipe' ),
			'priority' => 35,
		) );

		$wp_customize->add_setting( 'submit_recipe_email_target', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => 'robot@inspirythemes.com',
			'sanitize_callback' => 'sanitize_email',
		) );
		$wp_customize->add_control( 'submit_recipe_email_target', array(
			'label'       => esc_html__( 'Email Address for Recipe Submit Notification', 'FoodRecipe' ),
			'description' => esc_html__( 'Provide email address that will receive email notification on recipe submission. If you do not want to receive notification, then leave this field empty.', 'FoodRecipe' ),
			'type'        => 'email',
			'section'     => 'inspiry_recipe_submit_section',
		) );
	}

	public function inspiry_recipes_listing_customizer( WP_Customize_Manager $wp_customize ) {

		/**
		 * Home Slider Section
		 */
		$wp_customize->add_section( 'inspiry_recipes_listing_section', array(
			'title'    => esc_html__( 'Recipe Listing', 'FoodRecipe' ),
			'priority' => 31,
		) );

		// Slider Settings.
		$wp_customize->add_setting( 'recipes_per_page_listing', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => '6',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'recipes_per_page_listing', array(
			'label'       => esc_html__( 'Recipes Per Page', 'FoodRecipe' ),
			'description' => esc_html__( 'Enter the number of recipes you want to show on recipe listing page. Default value is 6.', 'FoodRecipe' ),
			'type'        => 'number',
			'section'     => 'inspiry_recipes_listing_section',
		) );

		$wp_customize->add_setting( 'recipe_show_sorting', array(
			'type'              => 'option',
			'default'           => 'on',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'recipe_show_sorting', array(
			'label'       => esc_html__( 'Show Sorting for Recipe post', 'FoodRecipe' ),
			'description' => esc_html__( 'Select YES if you want show Sorting for recipe post.', 'FoodRecipe' ),
			'type'        => 'radio',
			'section'     => 'inspiry_recipes_listing_section',
			'choices'     => array(
				'on'  => esc_html__( 'Yes', 'FoodRecipe' ),
				'off' => esc_html__( 'No', 'FoodRecipe' ),
			),
		) );

		// Slider Settings.
		$wp_customize->add_setting( 'pp_ctrl_for_recipe', array(
			'type'              => 'option',
			'default'           => 'true',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'pp_ctrl_for_recipe', array(
			'label'       => esc_html__( 'Do you want to open recipe thumbnail in lightbox?', 'FoodRecipe' ),
			'description' => esc_html__( 'Select "Enable" to show recipe thumbnail image on single recipe page in lightbox on click.', 'FoodRecipe' ),
			'type'        => 'select',
			'section'     => 'inspiry_recipes_listing_section',
			'choices'     => array(
				'true'  => esc_html__( 'Enable', 'FoodRecipe' ),
				'false' => esc_html__( 'Disable', 'FoodRecipe' ),
			),
		) );
	}

	public function inspiry_advance_search_customizer( WP_Customize_Manager $wp_customize ) {

		/**
		 * Custom Taxonomies Array.
		 */
		$taxonomies = get_object_taxonomies( 'recipe' );
		$skipTag    = array_shift( $taxonomies );
		foreach ( $taxonomies as $taxonomy ) {
			$tax_choices_array[ $taxonomy ] = esc_html( str_replace( '_', ' ', ucwords( $taxonomy ) ) );
		}
		$tax_choices_array['authors'] = esc_html__( 'Authors', 'FoodRecipe' );

		$pages       = get_pages();
		$pages_array = [];
		foreach ( $pages as $page ) {
			$pages_array[ $page->ID ] = $page->post_title;
		}


		$wp_customize->add_section( 'inspiry_advance_search_section', array(
			'title'    => esc_html__( 'Recipe Advance Search', 'FoodRecipe' ),
			'priority' => 34,
		) );


		$wp_customize->add_setting( 'adv_search_show_hide', array(
			'type'              => 'option',
			'default'           => 'on',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'adv_search_show_hide', array(
			'label'       => esc_html__( 'Advance Search', 'FoodRecipe' ),
			'description' => esc_html__( 'The Select option type is used to ON and OFF for advance search feature', 'FoodRecipe' ),
			'type'        => 'radio',
			'section'     => 'inspiry_advance_search_section',
			'choices'     => array(
				'on'  => esc_html__( 'Yes', 'FoodRecipe' ),
				'off' => esc_html__( 'No', 'FoodRecipe' ),
			),
		) );

		$wp_customize->add_setting( 'adv_search_page_url', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'esc_url',
		) );
		$wp_customize->add_control( 'adv_search_page_url', array(
			'label'           => esc_html__( 'Advance Search Page URL', 'FoodRecipe' ),
			'description'     => esc_html__( 'To configure the search functionality, create the Advance Recipe Search page by using Advance Search Result template and provide its url here.', 'FoodRecipe' ),
			'type'            => 'url',
			'section'         => 'inspiry_advance_search_section',
			'active_callback' => function () use ( $wp_customize ) {
				return 'on' === $wp_customize->get_setting( 'adv_search_show_hide' )->value();
			},
		) );


		$wp_customize->add_setting( 'adv_search_page_checkbox', array(
			'type'              => 'option',
			'default'           => 'recipe_type,cuisine,course,ingredient,skill_level',
			'sanitize_callback' => 'inspiry_sanitize_muti_checkbox',
		) );

		$wp_customize->add_control( new Inspiry_Customize_Control_Checkbox_Multiple( $wp_customize, 'adv_search_page_checkbox', array(
			'section'         => 'inspiry_advance_search_section',
			'label'           => esc_html__( 'Page Checkbox for Advance Search', 'FoodRecipe' ),
			'description'     => esc_html__( 'Please select the pages on which you want to show the advance search feature.', 'FoodRecipe' ),
			'choices'         => $pages_array,
			'active_callback' => function () use ( $wp_customize ) {
				return 'on' === $wp_customize->get_setting( 'adv_search_show_hide' )->value();
			},
		) ) );


		$wp_customize->add_setting( 'adv_search_fields_checkbox', array(
			'type'              => 'option',
			'sanitize_callback' => 'inspiry_sanitize_muti_checkbox',
		) );

		$wp_customize->add_control( new Inspiry_Customize_Control_Checkbox_Multiple( $wp_customize, 'adv_search_fields_checkbox', array(
			'section'         => 'inspiry_advance_search_section',
			'label'           => esc_html__( 'Fields Checkbox for Advance Search', 'FoodRecipe' ),
			'description'     => esc_html__( 'Please select the fields which you want to show in advance search.', 'FoodRecipe' ),
			'choices'         => $tax_choices_array,
			'active_callback' => function () use ( $wp_customize ) {
				return 'on' === $wp_customize->get_setting( 'adv_search_show_hide' )->value();
			},
		) ) );
	}

	public function inspiry_google_keys_customizer( WP_Customize_Manager $wp_customize ) {
		/**
		 * Google API Keys Section
		 */
		$wp_customize->add_section( 'inspiry_google_api_key', array(
			'title'    => esc_html__( 'Google API Keys', 'inspirythemes-food-recipes' ),
			'priority' => 129,
		) );

		/* Google Maps API Key */
		$wp_customize->add_setting( 'inspiry_google_maps_api_key', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'inspiry_google_maps_api_key', array(
			'label'   => esc_html__( 'Google Maps API Key', 'inspirythemes-food-recipes' ),
			'type'    => 'text',
			'section' => 'inspiry_google_api_key',
		) );

		/* Google reCAPTCHA Site Key */
		$wp_customize->add_setting( 'inspiry_google_recaptcha_site_key', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'inspiry_google_recaptcha_site_key', array(
			'label'   => esc_html__( 'Google reCAPTCHA Site Key', 'inspirythemes-food-recipes' ),
			'type'    => 'text',
			'section' => 'inspiry_google_api_key',
		) );

		/* Google reCAPTCHA Secret Key */
		$wp_customize->add_setting( 'inspiry_google_recaptcha_secret_key', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'inspiry_google_recaptcha_secret_key', array(
			'label'   => esc_html__( 'Google reCAPTCHA Secret Key', 'inspirythemes-food-recipes' ),
			'type'    => 'text',
			'section' => 'inspiry_google_api_key',
		) );
	}

	public function inspiry_admin_customizer_default( WP_Customize_Manager $wp_customize ) {

		$default_settings_ids = array(
			'recipe_show_rating',
			'contact_form_heading',
			'contact_email_address',
			'recipe_show_social_icons',
			'post_show_social_icons',
			'recipe_template_type',
			'recipe_info_show_hide',
			'recipe_right_info_show_hide',
			'more_recipe_show_hide',
			'recipe_author_show_hide',
			'recipe_nutrition_show_hide',
			'recipe_show_social_icons',
			'recipe_slug',
			'recipe_type_slug',
			'recipe_cuisine_slug',
			'recipe_course_slug',
			'recipe_ingredient_slug',
			'recipe_skill_level_slug',
			'submit_recipe_email_target',
			'recipes_per_page_listing',
			'recipe_show_sorting',
			'pp_ctrl_for_recipe',
			'adv_search_show_hide',
			'adv_search_page_url',
			'adv_search_page_checkbox',
			'adv_search_fields_checkbox',
		);
		inspiry_initialize_defaults( $wp_customize, $default_settings_ids );
	}
}
