<?php

/**
 * The admin-specific functionality of the plugin.
 */
class Food_Recipes_Pack_Mail {

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct() {

	}

	/**
	 * Override 'WordPress' as from name in emails sent by wp_mail function
	 *
	 * @return string
	 */
	public function inspiry_mail_from_name() {
		// The blogname option is escaped with esc_html on the way into the database in sanitize_option
		// we want to reverse this for the plain text arena of emails.
		$blogname = wp_specialchars_decode( get_option( 'blogname' ), ENT_QUOTES );

		return $blogname;
	}

	/**
	 * Send message function to process contact form submission.
	 */
	public function send_message() {

		if ( ! empty( get_option( 'inspiry_google_recaptcha_site_key' ) ) && ! empty( get_option( 'inspiry_google_recaptcha_secret_key' ) ) ) {

			$secret   = get_option( 'inspiry_google_recaptcha_secret_key' );
			$remoteip = $_SERVER['REMOTE_ADDR'];
			$url      = 'https://www.google.com/recaptcha/api/siteverify';

			// Form info.
			$response = $_POST['g-recaptcha-response'];

			// Curl Request.
			$curl = curl_init();
			curl_setopt( $curl, CURLOPT_URL, $url );
			curl_setopt( $curl, CURLOPT_POST, true );
			curl_setopt( $curl, CURLOPT_RETURNTRANSFER, 1 );
			curl_setopt( $curl, CURLOPT_POSTFIELDS, array(
				'secret'   => $secret,
				'response' => $response,
				'remoteip' => $remoteip,
			) );
			$curl_data = curl_exec( $curl );
			curl_close( $curl );

			$recaptcha = json_decode( $curl_data, true );

			if ( ! $recaptcha['success'] ) {
				if ( ! empty( $recaptcha['error-codes'] ) ) {
					switch ( $recaptcha['error-codes'][0] ) {
						case 'missing-input-secret':
							echo wp_json_encode(
								array(
									'success' => false,
									'message' => esc_html__( 'The secret parameter is missing! ', 'food-recipes-pack' ),
								)
							);
							break;
						case 'invalid-input-secret':
							echo wp_json_encode(
								array(
									'success' => false,
									'message' => esc_html__( 'The secret parameter is invalid or malformed! ', 'food-recipes-pack' ),
								)
							);
							break;
						case 'missing-input-response':
							echo wp_json_encode(
								array(
									'success' => false,
									'message' => esc_html__( 'The response parameter is missing! ', 'food-recipes-pack' ),
								)
							);
							break;
						case 'invalid-input-response':
							echo wp_json_encode(
								array(
									'success' => false,
									'message' => esc_html__( 'The response parameter is invalid or malformed! ', 'food-recipes-pack' ),
								)
							);
							break;
						default:
							echo wp_json_encode(
								array(
									'success' => false,
									'message' => esc_html__( 'The request is invalid or malformed! ', 'food-recipes-pack' ),
								)
							);
					}
				} else {
					echo wp_json_encode(
						array(
							'success' => false,
							'message' => esc_html__( 'The request is invalid or malformed! ', 'food-recipes-pack' ),
						)
					);
				}
				wp_die();
			}
		}

		if ( isset( $_POST['email'] ) ) {
			/*
			 * Verify Nonce
			 */
			if ( ! isset( $_POST['nonce'] ) || ! wp_verify_nonce( $_POST['nonce'], 'send_message_nonce' ) ) {
				echo wp_json_encode(
					array(
						'success' => false,
						'message' => esc_html__( 'Unverified Nonce!', 'food-recipes-pack' ),
					)
				);
				wp_die();
			}

			/*
			 * Sanitize and Validate Target email address that will be configured from theme options
			 */
			$to_email = get_option( 'contact_email_address' );
			$to_email = sanitize_email( $to_email );
			$to_email = is_email( $to_email );
			if ( ! $to_email ) {
				echo wp_json_encode(
					array(
						'success' => false,
						'message' => esc_html__( 'Target Email address is not properly configured!', 'food-recipes-pack' ),
					)
				);
				wp_die();
			}

			/*
			 * Sanitize and Validate contact form input data
			 */
			$from_name  = sanitize_text_field( $_POST['name'] );
			$from_email = sanitize_email( $_POST['email'] );
			$message    = stripslashes( $_POST['message'] );

			$from_email = is_email( $from_email );
			if ( ! $from_email ) {
				echo wp_json_encode(
					array(
						'success' => false,
						'message' => esc_html__( 'Provided Email address is invalid!', 'food-recipes-pack' ),
					)
				);
				wp_die();
			}

			/*
			 * Email Subject
			 */
			$email_subject = esc_html__( 'New message sent by', 'food-recipes-pack' ) . ' ' . $from_name . ' ' . esc_html__( 'using contact form at', 'food-recipes-pack' ) . ' ' . get_bloginfo( 'name' );

			/*
			 * Email Body
			 */
			$email_body = esc_html__( 'You have received a message from:  ', 'food-recipes-pack' ) . $from_name . ' <br/> ';
			$email_body .= esc_html__( 'Their additional message is as follows. ', 'food-recipes-pack' ) . ' <br/> ';
			$email_body .= wpautop( $message ) . ' <br/> ';

			/*$add_gdpr_in_email = get_option( 'inspiry_gdpr_in_email', '0' );

			if ( '1' == $add_gdpr_in_email ) {
				$GDPR_agreement = $_POST['gdpr'];
				if ( ! empty( $GDPR_agreement ) ) {
					$email_body .= esc_html__( 'GDPR Agreement: ' ) . wpautop( $GDPR_agreement ) .  ' <br/> ';
				}
			}*/

			$email_body .= esc_html__( 'You can contact  ', 'food-recipes-pack' ) . $from_name . esc_html__( ' via email,  ', 'food-recipes-pack' ) . $from_email;

			/*
			 * Email Headers ( Reply To and Content Type )
			 */
			$headers = array();

			$headers[] = "Reply-To: $from_name <$from_email>";
			$headers[] = 'Content-Type: text/html; charset=UTF-8';
			$headers   = apply_filters( 'inspiry_contact_mail_header', $headers );    // just in case if you want to modify the header in child theme.

			if ( wp_mail( $to_email, $email_subject, $email_body, $headers ) ) {
				echo wp_json_encode(
					array(
						'success' => true,
						'message' => esc_html__( 'Message Sent Successfully! ', 'food-recipes-pack' ),
					)
				);
			} else {
				echo wp_json_encode(
					array(
						'success' => false,
						'message' => esc_html__( 'Server Error: WordPress mail function failed! ', 'food-recipes-pack' ),
					)
				);
			}
		} else {
			echo wp_json_encode(
				array(
					'success' => false,
					'message' => esc_html__( 'Invalid Request ! ', 'food-recipes-pack' ),
				)
			);
			wp_die();
		}
		wp_die();
	}

	/**
	 * Send message function to process recipe form submission.
	 */
	public function recipe_submit_mail( $address, $title, $short_description ) {
		$current_user       = wp_get_current_user();
		$rs_submitter_name  = $current_user->display_name;
		$rs_submitter_email = $current_user->user_email;

		$e_reply = esc_html__( 'You can contact the submitter ', 'food-recipes-pack' ) . $rs_submitter_name . esc_html__( ' via email, ', 'food-recipes-pack' ) . $rs_submitter_email;

		$rs_subject  = esc_html__( 'New recipe has been submitted.', 'food-recipes-pack' );
		$email_html  = esc_html__( "A new recipe has been submitted on your website using recipe submit page.\n\n", 'food-recipes-pack' );
		$email_html .= esc_html__( 'Recipe Title: ', 'food-recipes-pack' ) . $title;
		$email_html .= esc_html__( "\n\nDescription: ", 'food-recipes-pack' ) . $short_description;
		$email_html .= "\n\n" . $e_reply;

		wp_mail( $address, $rs_subject, $email_html, "From: $rs_submitter_email\r\nReply-To: $rs_submitter_email\r\nReturn-Path: $rs_submitter_email\r\n", "-f $address" );
	}
}
