<?php

/**
 * The admin-specific functionality of the plugin.
 */
class Food_Recipes_Pack_Pack_Rating {

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct() {

	}

	public function inspiry_rate_this() {

		if ( isset( $_POST['selected_rating'] ) ) {

			$ip              = $_SERVER['REMOTE_ADDR'];
			$post_id         = intval( $_POST['post_id'] );
			$selected_rating = intval( $_POST['selected_rating'] );

			$meta_ip  = get_post_meta( $post_id, 'voted_IP' );
			$voted_ip = $meta_ip[0];

			if ( ! is_array( $voted_ip ) ) {
				$voted_ip = array();
			}

			if ( ! in_array( $ip, $voted_ip, true ) ) {

				$rating_count = get_post_meta( $post_id, 'rating_counter', true );
				if ( empty( $rating_count ) ) {
					$rating_count = 0;
				}

				$rating_array_holder = get_post_meta( $post_id, 'rating_array' );

				if ( ! empty( $rating_array_holder ) && is_array( $rating_array_holder[0] ) ) {
					$rating_array   = $rating_array_holder[0];
					$rating_array[] = $selected_rating;
				} else {
					$rating_array = array( $selected_rating );
				}

				if ( update_post_meta( $post_id, 'rating_array', $rating_array ) ) {
					$voted_ip[] = $ip;
					$rating_count ++;
					update_post_meta( $post_id, 'voted_IP', $voted_ip );
					update_post_meta( $post_id, 'rating_counter', $rating_count );

					$avg_rating = $this->get_avg_rating( $post_id );
					update_post_meta( $post_id, 'rating_average', $avg_rating );

					esc_html_e( 'Thank you for rating!', 'food-recipes-pack' );
				} else {
					esc_html_e( 'Failed', 'food-recipes-pack' );
				}
			} else {
				esc_html_e( 'Already Voted!', 'food-recipes-pack' );
			}
		} else {
			esc_html_e( 'No Rating Found!', 'food-recipes-pack' );
		}
		die;
	}

	public static function already_voted( $post_id ) {
		$ip      = $_SERVER['REMOTE_ADDR'];
		$meta_ip = get_post_meta( intval( $post_id ), 'voted_IP' );

		if ( ! empty( $meta_ip ) && is_array( $meta_ip[0] ) ) {
			$voted_ip = $meta_ip[0];

			return in_array( $ip, $voted_ip, true );
		}

		return false;
	}

	public static function get_vote_count( $post_id ) {
		$meta_ip = get_post_meta( intval( $post_id ), 'voted_IP' );

		if ( ! empty( $meta_ip ) && is_array( $meta_ip[0] ) ) {
			$voted_ip = $meta_ip[0];

			return count( $voted_ip );
		}

		return 0;
	}

	public static function get_avg_rating( $post_id ) {
		$rating_array_holder = get_post_meta( intval( $post_id ), 'rating_array' );

		if ( ! empty( $rating_array_holder ) && is_array( $rating_array_holder[0] ) ) {
			$rating_array  = $rating_array_holder[0];
			$rating_length = count( $rating_array );
			$rate_total    = array_sum( $rating_array );

			return round( $rate_total / $rating_length, 1 );
		}

		return 0;
	}

	public function the_recipe_rating( $post_id, $echo = true ) {
		$rate_avg = $this->get_avg_rating( $post_id );
		$rt = 0;
		$ratings = '';
		while ( $rt < 5 ) {
			if ( $rt > $rate_avg - 1 ) {
				$rclass = 'off';
			} else {
				$rclass = 'on';
			}
			$ratings .= '<span class="' . $rclass . '"><svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 346.16 465.95"><title>fork</title><path fill="currentColor" d="M259.67,323.25a60.36,60.36,0,0,0,4.84,59.15L351,494.73a10.23,10.23,0,0,0,16.27-12.38L299,391.52a11.55,11.55,0,0,1,19.13-12.95L384,470.94a11.05,11.05,0,0,0,18.3-12.39L341.08,363a11.55,11.55,0,1,1,19.13-12.95l59,97.14a10.22,10.22,0,0,0,17.54-10.51l-72.15-122a60.36,60.36,0,0,0-53.12-26.47A34.16,34.16,0,0,1,279.49,270C237.82,190.84,162,66.89,153.15,53.8c-12.87-19-35-26.51-49.46-16.74S88,70.18,100.85,89.19c8.86,13.09,95.77,129.54,153.78,197.63A34.18,34.18,0,0,1,259.67,323.25Z" transform="translate(-91.97 -32.77)"/></svg></span>';
			$rt ++;
		}

		if( $echo ){
			echo $ratings;
		} else {
			return $ratings;
		}
	}

	public function render_rating_section( $id ) {
		?>
		<div class="rate-box">

			<h6><?php esc_html_e( 'Average Member Rating', 'food-recipes-pack' ); ?></h6>

			<p class="ex-rates">
				<?php $this->the_recipe_rating( $id ); ?>
				(<?php echo esc_html( $this->get_avg_rating( $id ) ); ?> / 5)
			</p>

			<div class="hreview-aggregate">
			<span class="rating" itemprop="aggregateRating" itemscope itemtype="http://schema.org/AggregateRating">
				<span class="average"><?php echo esc_html( $this->get_avg_rating( $id ) ); ?></span>
				<span class="best" itemprop="ratingValue">5</span>
				<span class="count" itemprop="reviewCount"><?php echo esc_html( $this->get_vote_count( $id ) ); ?></span>
			</span>
			</div>

			<?php
			if ( ! $this->already_voted( $id ) ) {
				?>
				<form action="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>" method="post" id="rate-product">
					<h6><?php esc_html_e( 'Rate this recipe', 'food-recipes-pack' ); ?></h6>
					<p class="rates">
                        <span class="off"><svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 346.16 465.95"><title>fork</title><path fill="currentColor" d="M259.67,323.25a60.36,60.36,0,0,0,4.84,59.15L351,494.73a10.23,10.23,0,0,0,16.27-12.38L299,391.52a11.55,11.55,0,0,1,19.13-12.95L384,470.94a11.05,11.05,0,0,0,18.3-12.39L341.08,363a11.55,11.55,0,1,1,19.13-12.95l59,97.14a10.22,10.22,0,0,0,17.54-10.51l-72.15-122a60.36,60.36,0,0,0-53.12-26.47A34.16,34.16,0,0,1,279.49,270C237.82,190.84,162,66.89,153.15,53.8c-12.87-19-35-26.51-49.46-16.74S88,70.18,100.85,89.19c8.86,13.09,95.77,129.54,153.78,197.63A34.18,34.18,0,0,1,259.67,323.25Z" transform="translate(-91.97 -32.77)"/></svg></span>
                        <span class="off"><svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 346.16 465.95"><title>fork</title><path fill="currentColor" d="M259.67,323.25a60.36,60.36,0,0,0,4.84,59.15L351,494.73a10.23,10.23,0,0,0,16.27-12.38L299,391.52a11.55,11.55,0,0,1,19.13-12.95L384,470.94a11.05,11.05,0,0,0,18.3-12.39L341.08,363a11.55,11.55,0,1,1,19.13-12.95l59,97.14a10.22,10.22,0,0,0,17.54-10.51l-72.15-122a60.36,60.36,0,0,0-53.12-26.47A34.16,34.16,0,0,1,279.49,270C237.82,190.84,162,66.89,153.15,53.8c-12.87-19-35-26.51-49.46-16.74S88,70.18,100.85,89.19c8.86,13.09,95.77,129.54,153.78,197.63A34.18,34.18,0,0,1,259.67,323.25Z" transform="translate(-91.97 -32.77)"/></svg></span>
                        <span class="off"><svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 346.16 465.95"><title>fork</title><path fill="currentColor" d="M259.67,323.25a60.36,60.36,0,0,0,4.84,59.15L351,494.73a10.23,10.23,0,0,0,16.27-12.38L299,391.52a11.55,11.55,0,0,1,19.13-12.95L384,470.94a11.05,11.05,0,0,0,18.3-12.39L341.08,363a11.55,11.55,0,1,1,19.13-12.95l59,97.14a10.22,10.22,0,0,0,17.54-10.51l-72.15-122a60.36,60.36,0,0,0-53.12-26.47A34.16,34.16,0,0,1,279.49,270C237.82,190.84,162,66.89,153.15,53.8c-12.87-19-35-26.51-49.46-16.74S88,70.18,100.85,89.19c8.86,13.09,95.77,129.54,153.78,197.63A34.18,34.18,0,0,1,259.67,323.25Z" transform="translate(-91.97 -32.77)"/></svg></span>
                        <span class="off"><svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 346.16 465.95"><title>fork</title><path fill="currentColor" d="M259.67,323.25a60.36,60.36,0,0,0,4.84,59.15L351,494.73a10.23,10.23,0,0,0,16.27-12.38L299,391.52a11.55,11.55,0,0,1,19.13-12.95L384,470.94a11.05,11.05,0,0,0,18.3-12.39L341.08,363a11.55,11.55,0,1,1,19.13-12.95l59,97.14a10.22,10.22,0,0,0,17.54-10.51l-72.15-122a60.36,60.36,0,0,0-53.12-26.47A34.16,34.16,0,0,1,279.49,270C237.82,190.84,162,66.89,153.15,53.8c-12.87-19-35-26.51-49.46-16.74S88,70.18,100.85,89.19c8.86,13.09,95.77,129.54,153.78,197.63A34.18,34.18,0,0,1,259.67,323.25Z" transform="translate(-91.97 -32.77)"/></svg></span>
                        <span class="off"><svg id="Layer_1" data-name="Layer 1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 346.16 465.95"><title>fork</title><path fill="currentColor" d="M259.67,323.25a60.36,60.36,0,0,0,4.84,59.15L351,494.73a10.23,10.23,0,0,0,16.27-12.38L299,391.52a11.55,11.55,0,0,1,19.13-12.95L384,470.94a11.05,11.05,0,0,0,18.3-12.39L341.08,363a11.55,11.55,0,1,1,19.13-12.95l59,97.14a10.22,10.22,0,0,0,17.54-10.51l-72.15-122a60.36,60.36,0,0,0-53.12-26.47A34.16,34.16,0,0,1,279.49,270C237.82,190.84,162,66.89,153.15,53.8c-12.87-19-35-26.51-49.46-16.74S88,70.18,100.85,89.19c8.86,13.09,95.77,129.54,153.78,197.63A34.18,34.18,0,0,1,259.67,323.25Z" transform="translate(-91.97 -32.77)"/></svg></span>
						<input type="hidden" name="selected_rating" id="selected_rating" value=""/>
						<input type="hidden" name="post_id" value="<?php echo esc_html( $id ); ?>"/>
						<input type="hidden" name="action" value="inspiry_rate_this"/>
					</p>
				</form>
				<?php
			} else {
				echo '<p class="already-rated">' . esc_html__( 'You have already Rated.', 'food-recipes-pack' ) . '</p>';
			}
			?>
			<p id="output"></p>
			<p class="status">
			<span>
				<?php
				echo esc_html( $this->get_vote_count( $id ) );
				?>
			</span>
				<?php esc_html_e( ' People rated this recipe', 'food-recipes-pack' ); ?>
			</p>
			<?php
			if ( function_exists( 'pvc_post_views' ) ) {
				pvc_post_views( get_the_ID() );
			} elseif ( function_exists( 'echo_post_views' ) ) {
				echo_post_views( get_the_ID() );
			}
			?>

		</div><!-- end of rate-box div -->
		<?php
	}
}
