<?php

/**
 * The admin-specific functionality of the plugin.
 */
class Food_Recipes_Pack_Post_Type {

	/**
	 * Initialize the class and set its properties.
	 */
	public function __construct() {

	}

	public function create_recipe() {

		$recipe_slug = get_option( 'recipe_slug' );
		$labels      = array(
			'name'               => esc_html__( 'Recipes', 'food-recipes-pack' ),
			'singular_name'      => esc_html__( 'Recipe', 'food-recipes-pack' ),
			'add_new'            => esc_html__( 'Add New', 'food-recipes-pack' ),
			'add_new_item'       => esc_html__( 'Recipe', 'food-recipes-pack' ),
			'edit_item'          => esc_html__( 'Edit Recipe', 'food-recipes-pack' ),
			'new_item'           => esc_html__( 'New Recipe', 'food-recipes-pack' ),
			'view_item'          => esc_html__( 'View Recipe', 'food-recipes-pack' ),
			'search_items'       => esc_html__( 'Search Recipes', 'food-recipes-pack' ),
			'not_found'          => esc_html__( 'No Recipes found', 'food-recipes-pack' ),
			'not_found_in_trash' => esc_html__( 'No Recipes found in Trash', 'food-recipes-pack' ),
			'parent_item_colon'  => '',
		);

		$supports = array(
			'title',
			'editor',
			'thumbnail',
			'categories',
			'comments',
			'excerpt',
			'author',
			'publicize',
		);

		register_post_type( 'recipe',
			array(
				'labels'        => $labels,
				'public'        => true,
				'menu_position' => 5,
				'hierarchical'  => false,
				'supports'      => $supports,
				'taxonomies'    => array( 'recipe-type', 'post_tag' ),
				'rewrite'       => array( 'slug' => isset( $recipe_slug ) ? $recipe_slug : esc_html__( 'recipe', 'food-recipes-pack' ) ),
				'show_in_rest'  => true,
				'rest_base'     => apply_filters( 'inspiry_recipe_rest_base', esc_html__( 'recipes', 'food-recipes-pack' ) ),
			)
		);

	}


	/**
	 * Custom Texonomy Recipe Types for Recipe
	 */

	public function build_taxonomies() {
		$recipe_type_slug        = get_option( 'recipe_type_slug' );
		$recipe_cuisine_slug     = get_option( 'recipe_cuisine_slug' );
		$recipe_course_slug      = get_option( 'recipe_course_slug' );
		$recipe_ingredient_slug  = get_option( 'recipe_ingredient_slug' );
		$recipe_skill_level_slug = get_option( 'recipe_skill_level_slug' );

		// Recipe Type Custom Taxonomy.
		$recipe_type_labels = array(
			'name'              => esc_html__( 'Recipe Types', 'food-recipes-pack' ),
			'singular_name'     => esc_html__( 'Recipe Type', 'food-recipes-pack' ),
			'search_items'      => esc_html__( 'Search Recipe Types', 'food-recipes-pack' ),
			'all_items'         => esc_html__( 'All Recipe Types', 'food-recipes-pack' ),
			'parent_item'       => esc_html__( 'Parent Recipe Type', 'food-recipes-pack' ),
			'parent_item_colon' => esc_html__( 'Parent Recipe Type:', 'food-recipes-pack' ),
			'edit_item'         => esc_html__( 'Edit Recipe Type', 'food-recipes-pack' ),
			'update_item'       => esc_html__( 'Update Recipe Type', 'food-recipes-pack' ),
			'add_new_item'      => esc_html__( 'Add New Recipe Type', 'food-recipes-pack' ),
			'new_item_name'     => esc_html__( 'Recipe Type Name', 'food-recipes-pack' ),
			'menu_name'         => esc_html__( 'Recipe Types', 'food-recipes-pack' ),
		);


		register_taxonomy(
			'recipe_type',
			'recipe',
			array(
				'hierarchical' => true,
				'labels'       => $recipe_type_labels,
				'query_var'    => true,
				'show_in_rest' => true,
				'rewrite'      => array( 'slug' => isset( $recipe_type_slug ) ? $recipe_type_slug : esc_html__( 'recipe-type', 'food-recipes-pack' ) ),
			)
		);

		// Cuisine Custom Taxonomy.
		$cuisines_labels = array(
			'name'              => esc_html__( 'Cuisines', 'food-recipes-pack' ),
			'singular_name'     => esc_html__( 'Cuisine', 'food-recipes-pack' ),
			'search_items'      => esc_html__( 'Search Cuisines', 'food-recipes-pack' ),
			'all_items'         => esc_html__( 'All Cuisines', 'food-recipes-pack' ),
			'parent_item'       => esc_html__( 'Parent Cuisine', 'food-recipes-pack' ),
			'parent_item_colon' => esc_html__( 'Parent Cuisine:', 'food-recipes-pack' ),
			'edit_item'         => esc_html__( 'Edit Cuisine', 'food-recipes-pack' ),
			'update_item'       => esc_html__( 'Update Cuisine', 'food-recipes-pack' ),
			'add_new_item'      => esc_html__( 'Add New Cuisine', 'food-recipes-pack' ),
			'new_item_name'     => esc_html__( 'Cuisine Name', 'food-recipes-pack' ),
			'menu_name'         => esc_html__( 'Cuisines', 'food-recipes-pack' ),
		);

		register_taxonomy(
			'cuisine',
			'recipe',
			array(
				'hierarchical' => true,
				'labels'       => $cuisines_labels,
				'query_var'    => true,
				'show_in_rest' => true,
				'rewrite'      => array( 'slug' => isset( $recipe_cuisine_slug ) ? $recipe_cuisine_slug : esc_html__( 'cuisine', 'food-recipes-pack' ) ),
			)
		);

		// Courses Custom Taxonomy.
		$courses_labels = array(
			'name'              => esc_html__( 'Courses', 'food-recipes-pack' ),
			'singular_name'     => esc_html__( 'Course', 'food-recipes-pack' ),
			'search_items'      => esc_html__( 'Search Courses', 'food-recipes-pack' ),
			'all_items'         => esc_html__( 'All Courses', 'food-recipes-pack' ),
			'parent_item'       => esc_html__( 'Parent Course', 'food-recipes-pack' ),
			'parent_item_colon' => esc_html__( 'Parent Course:', 'food-recipes-pack' ),
			'edit_item'         => esc_html__( 'Edit Course', 'food-recipes-pack' ),
			'update_item'       => esc_html__( 'Update Course', 'food-recipes-pack' ),
			'add_new_item'      => esc_html__( 'Add New Course', 'food-recipes-pack' ),
			'new_item_name'     => esc_html__( 'Course Name', 'food-recipes-pack' ),
			'menu_name'         => esc_html__( 'Courses', 'food-recipes-pack' ),
		);

		register_taxonomy(
			'course',
			'recipe',
			array(
				'hierarchical' => true,
				'labels'       => $courses_labels,
				'query_var'    => true,
				'show_in_rest' => true,
				'rewrite'      => array( 'slug' => isset( $recipe_course_slug ) ? $recipe_course_slug : esc_html__( 'course', 'food-recipes-pack' ) ),
			)
		);

		// Ingredients Custom Taxonomy.
		$ingredients_labels = array(
			'name'              => esc_html__( 'Ingredients', 'food-recipes-pack' ),
			'singular_name'     => esc_html__( 'Ingredient', 'food-recipes-pack' ),
			'search_items'      => esc_html__( 'Search Ingredients', 'food-recipes-pack' ),
			'all_items'         => esc_html__( 'All Ingredients', 'food-recipes-pack' ),
			'parent_item'       => esc_html__( 'Parent Ingredient', 'food-recipes-pack' ),
			'parent_item_colon' => esc_html__( 'Parent Ingredient:', 'food-recipes-pack' ),
			'edit_item'         => esc_html__( 'Edit Ingredient', 'food-recipes-pack' ),
			'update_item'       => esc_html__( 'Update Ingredient', 'food-recipes-pack' ),
			'add_new_item'      => esc_html__( 'Add New Ingredient', 'food-recipes-pack' ),
			'new_item_name'     => esc_html__( 'Ingredient Name', 'food-recipes-pack' ),
			'menu_name'         => esc_html__( 'Ingredients', 'food-recipes-pack' ),
		);

		register_taxonomy(
			'ingredient',
			'recipe',
			array(
				'hierarchical' => true,
				'labels'       => $ingredients_labels,
				'query_var'    => true,
				'show_in_rest' => true,
				'rewrite'      => array( 'slug' => isset( $recipe_ingredient_slug ) ? $recipe_ingredient_slug : esc_html__( 'ingredient', 'food-recipes-pack' ) ),
			)
		);

		// Skill Level.
		$skill_levels_labels = array(
			'name'              => esc_html__( 'Skill Levels', 'food-recipes-pack' ),
			'singular_name'     => esc_html__( 'Skill Level', 'food-recipes-pack' ),
			'search_items'      => esc_html__( 'Search Skill Levels', 'food-recipes-pack' ),
			'all_items'         => esc_html__( 'All Skill Levels', 'food-recipes-pack' ),
			'parent_item'       => esc_html__( 'Parent Skill Level', 'food-recipes-pack' ),
			'parent_item_colon' => esc_html__( 'Parent Skill Level:', 'food-recipes-pack' ),
			'edit_item'         => esc_html__( 'Edit Skill Level', 'food-recipes-pack' ),
			'update_item'       => esc_html__( 'Update Skill Level', 'food-recipes-pack' ),
			'add_new_item'      => esc_html__( 'Add New Skill Level', 'food-recipes-pack' ),
			'new_item_name'     => esc_html__( 'Skill Level Name', 'food-recipes-pack' ),
			'menu_name'         => esc_html__( 'Skill Levels', 'food-recipes-pack' ),
		);

		register_taxonomy(
			'skill_level',
			'recipe',
			array(
				'hierarchical' => true,
				'labels'       => $skill_levels_labels,
				'query_var'    => true,
				'show_in_rest' => true,
				'rewrite'      => array( 'slug' => isset( $recipe_skill_level_slug ) ? $recipe_skill_level_slug : esc_html__( 'skill-level', 'food-recipes-pack' ) ),
			)
		);

	}


	/**
	 * Add Custom Columns
	 */
	public function recipe_edit_columns( $columns ) {

		$columns = array(
			'cb'    => "<input type='checkbox' />",
			'title' => esc_html__( 'Recipe Title', 'food-recipes-pack' ),
			'thumb' => esc_html__( 'Thumbnail', 'food-recipes-pack' ),
			'id'    => esc_html__( 'Recipe ID', 'food-recipes-pack' ),
		);

		if ( function_exists( 'echo_post_views' ) ) {
			$columns['views'] = esc_html__( 'Views', 'food-recipes-pack' );
		}

		$columns['date'] = esc_html__( 'Publish Time', 'food-recipes-pack' );

		return $columns;
	}


	public function recipe_custom_columns( $column ) {
		global $post;
		switch ( $column ) {
			case 'thumb':
				if ( has_post_thumbnail( get_the_ID() ) ) {
					?>
                    <a href="<?php the_permalink(); ?>" target="_blank">
						<?php the_post_thumbnail( 'sidebar-tabs' ); ?>
                    </a>
					<?php
				} else {
					esc_html_e( 'No Thumbnail', 'food-recipes-pack' );
				}
				break;

			case 'views':
				if ( function_exists( 'pvc_post_views' ) ) {
					pvc_post_views( get_the_ID(), true );
				}
				break;

			case 'id':
				echo esc_html( get_the_ID() );
				break;
		}
	}


	/**
	 * Add Recipes in RSS Feed.
	 */

	public function my_recipes_feed( $qv ) {
		if ( isset( $qv['feed'] ) && ! isset( $qv['post_type'] ) ) {
			$qv['post_type'] = array( 'post', 'recipe' );
		}

		return $qv;
	}

	public function alter_recipe_singular( $single_template ) {
		global $post;

		if ( 'recipe' === $post->post_type ) {
			remove_action( 'wp_head', 'feed_links_extra', 3 ); // Display the links to the extra feeds such as category feeds.
			remove_action( 'wp_head', 'feed_links', 2 ); // Display the links to the general feeds: Post and Comment Feed.
		}

		return $single_template;
	}


	/**
	 * Add Thumbnails in RSS Feed
	 */
	public function rss_post_thumbnail_excerpt( $content ) {
		global $post;
		if ( has_post_thumbnail( get_the_ID() ) ) {
			$content = '<p>' . get_the_post_thumbnail( get_the_ID(), 'medium' ) . '</p>' . get_the_excerpt();
		}

		return $content;
	}


	public function rss_post_thumbnail( $content ) {
		global $post;
		if ( has_post_thumbnail( get_the_ID() ) ) {
			$content = '<p>' . get_the_post_thumbnail( get_the_ID(), 'medium' ) . '</p>' . do_shortcode( get_the_content() );
		}

		return $content;
	}

}