<?php
if ( ! function_exists( 'food_recipes_metaboxes' ) ) :
	/**
	 * Contains recipe post type meta box declaration
	 * @param $meta_boxes
	 * @return array
	 */
	function food_recipes_metaboxes( $meta_boxes ) {

		$prefix = 'RECIPE_META_';

		$meta_boxes[] = array(
			'id'         => 'recipe_additional',
			'title'      => esc_html__('Recipe Information', 'food-recipes-pack'),
			'post_types' => array( 'recipe' ),
			'context'    => 'normal',

			// Order of meta box: high (default), low. Optional.
			'priority'   => 'high',

			// Auto save: true, false (default). Optional.
			'autosave'   => true,

			// Tabs.
			'tabs'      => array(
				'basic-section' => array(
					'label' => esc_html__( 'Basic Information', 'food-recipes-pack' ),
					'icon'  => 'dashicons-admin-settings',
				),
				'ingredients-section' => array(
					'label' => esc_html__( 'Ingredients', 'food-recipes-pack' ),
					'icon'  => 'dashicons-email',
				),
				'method-section'  => array(
					'label' => esc_html__( 'Method', 'food-recipes-pack' ),
					'icon'  => 'dashicons-filter'
				),
				'nitration-section'  => array(
					'label' => esc_html__( 'Nutration', 'food-recipes-pack' ),
					'icon'  => 'dashicons-universal-access'
				),
				'gallery-section'  => array(
					'label' => esc_html__( 'Gallery', 'food-recipes-pack' ),
					'icon'  => 'dashicons-images-alt'
				),
				'video-section'  => array(
					'label' => esc_html__( 'Video', 'food-recipes-pack' ),
					'icon'  => 'dashicons-format-video'
				)
			),
			'tab_style' => 'left',

			// List of meta fields
			'fields'	=> array(
				array(
					'name'	=> esc_html__('Attach Images', 'food-recipes-pack'),
					'desc'	=> esc_html__('Upload recipe images here. Minimum required size for an image is 575px in width and 262px in height. These Images will appear in slider on recipe page. Please do not forget to provide featured image for this recipe using Featured Image metabox in right sidebar as featured image will be displayed on homepage, recipe listings and widgets. ', 'food-recipes-pack'),
					'id'	=> "{$prefix}more_images_recipe",
					'type'	=> 'image_advanced',
					'tab'       => 'gallery-section'
				),
				array(
					'name'		=> esc_html__('Yield', 'food-recipes-pack'),
					'id'		=> $prefix . 'yield',
					'desc'		=> esc_html__('How much/many does this recipe produce?', 'food-recipes-pack'),
					'clone'		=> false,
					'type'		=> 'text',
					'std'		=> '',
					'tab'       => 'basic-section',
					'columns'   => 6
				),
				array(
					'name'		=> esc_html__('Servings', 'food-recipes-pack'),
					'id'		=> $prefix . 'servings',
					'desc'		=> esc_html__('How many servings?', 'food-recipes-pack'),
					'clone'		=> false,
					'type'		=> 'text',
					'std'		=> '',
					'tab'       => 'basic-section',
					'columns'   => 6
				),
				array(
					'name'		=> esc_html__('Prep Time', 'food-recipes-pack'),
					'id'		=> $prefix . 'prep_time',
					'desc'		=> esc_html__('How Many Minutes ?  Minutes Above 60 will be displayed in hours.', 'food-recipes-pack'),
					'clone'		=> false,
					'type'		=> 'text',
					'std'		=> '',
					'tab'       => 'basic-section',
					'columns'   => 6
				),
				array(
					'name'		=> esc_html__('Cook Time', 'food-recipes-pack'),
					'id'		=> $prefix . 'cook_time',
					'desc'		=> esc_html__('How Many Minutes ?  Minutes Above 60 will be displayed in hours.', 'food-recipes-pack'),
					'clone'		=> false,
					'type'		=> 'text',
					'std'		=> '',
					'tab'       => 'basic-section',
					'columns'   => 6
				),
				array(
					'name'		=> esc_html__('Ready In', 'food-recipes-pack'),
					'id'		=> $prefix . 'ready_in',
					'desc'		=> esc_html__('How Many Minutes ?  Minutes Above 60 will be displayed in hours.', 'food-recipes-pack'),
					'clone'		=> false,
					'type'		=> 'text',
					'std'		=> '',
					'tab'       => 'basic-section',
					'columns'   => 6
				),
				array(
					'name'		=> esc_html__('Ingredients', 'food-recipes-pack'),
					'id'		=> $prefix . 'ingredients',
					'desc'		=> sprintf( esc_html__('You can add list of ingredients here. Use %s on the right to add new ingredient. %s', 'food-recipes-pack'), '<strong>+ button</strong>', '<strong>To display the list you need to write [ingredients] short code in your content editor.</strong>' ),
					'clone'		=> true,
					'type'		=> 'text',
					'std'		=> 'New',
					'rows'      => 1,
					'tab'       => 'ingredients-section'
				),
				array(
					'name'		=> esc_html__('Method Steps', 'food-recipes-pack'),
					'id'		=> $prefix . 'method_steps',
					'desc'		=> sprintf( esc_html__('You can add list of recipe method steps here. Use %s on the right to add new step. %s', 'food-recipes-pack'), '<strong>+ button</strong>', '<strong>To display the list you need to write [method] short code in your content editor.</strong>' ),
					'clone'		=> true,
					'type'		=> 'textarea',
					'std'		=> '',
					'tab'       => 'method-section'
				),

				// Nutrients
				array(
					'name'		=> esc_html__( 'Recommended Nutrients Information', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_main_heading',
					'type'		=> 'heading',
					'desc'		=> esc_html__( 'Provide the value you want to display in front end and google structure data.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 12
				),
				array(
					'name'		=> esc_html__( 'Calories', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_calories',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of calories.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Carbohydrates', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_carbohydrates',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of grams of carbohydrates.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Cholesterol', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_cholesterol',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of milligrams of cholesterol.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Fat', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_fat',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of grams of fat.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Fiber', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_fiber',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of grams of fiber.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Protein', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_protein',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of grams of protein.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Saturated Fat', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_saturated_fat',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of grams of saturated fat.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Serving Size', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_serving_size',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The serving size, in terms of the number of volume or mass.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Sodium', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_sodium',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of milligrams of sodium.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Sugar', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_sugar',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of grams of sugar.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Trans Fat', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_trans_fat',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of grams of trans fat.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),
				array(
					'name'		=> esc_html__( 'Unsaturated Fat', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_unsaturated_fat',
					'type'		=> 'text',
					'desc'		=> esc_html__( 'The number of grams of unsaturated fat.', 'food-recipes-pack' ),
					'tab'       => 'nitration-section',
					'columns'   => 3
				),

				// More Nutrients
				array(
					'name'		=> esc_html__( 'More Nutrients', 'food-recipes-pack' ),
					'id'		=> $prefix . 'additional_nut_heading',
					'desc'		=> esc_html__('Enter any additional nutrients which are not available in the list given above.', 'food-recipes-pack'),
					'type'		=> 'heading',
					'tab'       => 'nitration-section'
				),
				array(
					'name'		=> esc_html__( 'Nutrient Name', 'food-recipes-pack' ),
					'id'		=> $prefix . 'nut_name',
					'desc'		=> sprintf( esc_html__('Enter the name of nutritional Item Name. Use %s on the right to add new Nutrient Name', 'food-recipes-pack'), '<strong>+ button</strong>' ),
					'clone'		=> true,
					'type'		=> 'text',
					'std'		=> '',
					'tab'       => 'nitration-section',
					'columns'   => 6
				),
				array(
					'name'		=> esc_html__('Mass', 'food-recipes-pack'),
					'id'		=> $prefix . 'nut_mass',
					'desc'		=> sprintf( esc_html__('Enter Nutrient Mass. Use %s on the right to add new Mass Value.', 'food-recipes-pack'), '<strong>+ button</strong>' ),
					'clone'		=> true,
					'type'		=> 'text',
					'std'		=> '',
					'tab'       => 'nitration-section',
					'columns'   => 6
				),

				// Video
				array(
					'name'		=> esc_html__('Video Based Recipe', 'food-recipes-pack'),
					'desc'      => esc_html__('A Video Based recipe does not display attached images and only display a video at top.', 'food-recipes-pack'),
					'id'		=> $prefix . 'recipe_video_check',
					'type'		=> 'radio',
					'options'   => array( 'on' => esc_html__('Yes ', 'food-recipes-pack'), 'off'   =>  esc_html__('No ', 'food-recipes-pack')),
					'std'       => 'off',
					'tab'       => 'video-section'
				),
				array(
					'name'		=> esc_html__('Video Embed Code', 'food-recipes-pack'),
					'id'		=> $prefix . 'recipe_video_code',
					'desc'		=> esc_html__('Provide the video embed code and Modify the width attribute to 575px and height attribute to 323px. 16:9 Ratio', 'food-recipes-pack'),
					'type'		=> 'textarea',
					'std'		=> '',
					'tab'       => 'video-section'
				),
				array(
					'name'	=> esc_html__('Structure Data related information', 'food-recipes-pack'),
					'desc'	=> esc_html__('This video related information is optional. It is related to the search engines related structure data information.', 'food-recipes-pack'),
					'id'	=> "{$prefix}rsd_heading",
					'type'	=> 'heading',
					'tab'       => 'video-section'
				),
				array(
					'name'		=> esc_html__('Video Title', 'food-recipes-pack'),
					'id'		=> $prefix . 'rsd_video_title',
					'desc'		=> esc_html__('Provide title for the video. If not provided then recipe title will be used.', 'food-recipes-pack'),
					'type'		=> 'text',
					'std'		=> '',
					'tab'       => 'video-section',
				),
				array(
					'name'	=> esc_html__('Video Thumbnail', 'food-recipes-pack'),
					'desc'	=> esc_html__('Provide video thumbnail. If not provided then recipe thumbnail will be used.', 'food-recipes-pack'),
					'id'	=> "{$prefix}rsd_video_thumbnail",
					'type'	=> 'image_advanced',
					'max_file_uploads' => 1,
					'tab'       => 'video-section'
				),
				array(
					'name'		=> esc_html__('Video Upload Date', 'food-recipes-pack'),
					'id'		=> $prefix . 'rsc_video_upload_date',
					'desc'		=> esc_html__('Provide video upload date.', 'food-recipes-pack'),
					'type'		=> 'date',
					'tab'       => 'video-section',
					'columns'   => 6
				),
				array(
					'name'		=> esc_html__('Video Length', 'food-recipes-pack'),
					'id'		=> $prefix . 'rsc_video_length',
					'desc'		=> esc_html__('Provide video total play time.', 'food-recipes-pack'),
					'type'		=> 'time',
					'js_options' => array(
						'showSecond' => 1,
						'timeFormat' => 'HH:mm:ss'
					),
					'tab'       => 'video-section',
					'columns'   => 6
				),
				array(
					'name'		=> esc_html__('Video Description', 'food-recipes-pack'),
					'id'		=> $prefix . 'rsd_video_description',
					'desc'		=> esc_html__('Provide description related to this video. If not provided then recipe excerpt will be used.', 'food-recipes-pack'),
					'type'		=> 'textarea',
					'tab'       => 'video-section',
					'columns'   => 12
				),
			)
		);

		// apply a filter before returning doctor meta boxes
		$meta_boxes = apply_filters( 'food_recipes_pack_filter_recipe_meta_boxes', $meta_boxes );

		return $meta_boxes;
	}

	add_filter( 'rwmb_meta_boxes', 'food_recipes_metaboxes' );

endif;