<?php

/**
 * Define the Typography
 */
class Food_Recipes_Pack_Typography {

	/**
	 * Define the core functionality of the plugin.
	 */
	public function __construct() {

		add_shortcode( 'ingredients', [ $this, 'show_ingredients' ] );
		add_shortcode( 'method', [ $this, 'show_method_steps' ] );
		add_shortcode( 'red_heading', [ $this, 'show_red_heading' ] );
		add_shortcode( 'blue_heading', [ $this, 'show_blue_heading' ] );
		add_shortcode( 'step_head', [ $this, 'show_step_head' ] );
		add_shortcode( 'blockquote', [ $this, 'show_blockquote' ] );
		add_shortcode( 'ppframe', [ $this, 'ppframe_fn' ] );
	}


	// [ingredients] short code
	public function show_ingredients( $atts, $content = null ) {

		extract( shortcode_atts( array(
			'title' => '',
		), $atts ) );

		if ( function_exists( 'rwmb_meta' ) ) {

			$ingredients = rwmb_meta( 'RECIPE_META_ingredients' );

			$ingredients_count = count( $ingredients );

			if ( empty( $title ) ) {
				$ingredients_html = '<h3 class="blue">' . esc_html__( 'Ingredients', 'food-recipes-pack' ) . '</h3>';
			} else {
				$ingredients_html = '<h3 class="blue">' . $title . '</h3>';
			}

			if ( $ingredients_count >= 1 ) {
				$ingredients_html .= '<ul>';
				foreach ( $ingredients as $ingredient ) {
					$ingredients_html .= '<li class="ingredient" itemprop="recipeIngredient">';
					$ingredients_html .= $ingredient;
					$ingredients_html .= '</li>';
				}

				$ingredients_html .= '</ul>';
			} else {
				$ingredients_html .= '<p>';
				$ingredients_html .= esc_html__( 'No Ingredients Found ! ', 'food-recipes-pack' );
				$ingredients_html .= '</p>';
			}

			return $ingredients_html;
		} else {
			return false;
		}
	}


// [method] short code
	public function show_method_steps( $atts, $content = null ) {

		extract( shortcode_atts( array(
			'title' => ''
		), $atts ) );

		if ( function_exists( 'rwmb_meta' ) ) {

			global $post;

			$method_steps = rwmb_meta( 'RECIPE_META_method_steps' );
			if ( is_array( $method_steps ) ) :
				$steps_count = count( $method_steps );
			else :
				$steps_count = 0;
			endif;

			if ( empty( $title ) ) {
				$method_html = '<h3 class="blue">' . esc_html__( 'Method', 'food-recipes-pack' ) . '</h3>';
			} else {
				$method_html = '<h3 class="blue">' . $title . '</h3>';
			}

			$method_html .= '<div>';

			if ( $steps_count >= 1 ) {
				$i = 1;
				foreach ( $method_steps as $step ) {
					$method_html .= '<h4 class="red me-steps"><span class="stepcheck"></span>' . esc_html__( 'Step ', 'food-recipes-pack' ) . ( $i ++ ) . '</h4>';
					$method_html .= '<p class="instructions" itemprop="recipeInstructions">';
					$method_html .= $step;
					$method_html .= '</p>';
				}
			} else {
				$method_html .= '<p>' . esc_html__( 'No Steps Found ! ', 'food-recipes-pack' ) . '</p>';
			}

			$method_html .= '</div>';

			return $method_html;
		} else {
			return false;
		}
	}


	/**
	 * Red Heading Short code.
	 */
	public function show_red_heading( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'border' => false,
		), $atts ) );

		global $bot_border;

		if ( $border == 'true' ) {
			$bot_border = '<span class="w-pet-border"></span>';
		}

		return '<h3 class="red-heading">' . $content . '</h3>' . $bot_border;
	}


	/**
	 * Blue Heading Short code.
	 */
	public function show_blue_heading( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'border' => false,
		), $atts ) );

		global $bot_border;

		if ( $border == true ) {
			$bot_border = '<span class="w-pet-border"></span>';
		}

		return '<h3 class="blue">' . $content . '</h3>' . $bot_border;
	}


	/**
	 * Recipe Steps Heading Short code.
	 */
	public function show_step_head( $atts, $content = null ) {
		return '<h4 class="red">' . $content . '</h4>';
	}


	/**
	 * Blockquote Left Aligned.
	 */
	public function show_blockquote( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'width' => '',
			'align' => '',
		), $atts ) );

		global $align_class, $mwidth, $end_quote;

		if ( $width ) {
			$mwidth = $width . 'px';
		} else {
			$mwidth    = 'auto';
			$end_quote = '<span class="end-quote"></span>';
		}

		if ( $align == 'left' ) {
			$align_class = 'leftalign';
		}
		if ( $align == 'right' ) {
			$align_class = 'rightalign';
		}
		if ( $align == 'none' ) {
			$align_class = 'noalign';
		}

		return '<blockquote class="' . $align_class . '" style="width:' . $mwidth . ';"><p>' . $content . ' ' . $end_quote . '</p></blockquote>';
	}


	/**
	 * Pretty photo frame for image.
	 */
	public function ppframe_fn( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'imageurl' => '',
			'title'    => ''
		), $atts ) );

		global $Image_URL, $image_title;

		if ( $imageurl ) {
			$Image_URL = 'href="' . $imageurl . '"';
		}

		if ( $title ) {
			$image_title = 'title="' . $title . ' "';
		}

		return '<a ' . $Image_URL . ' ' . $image_title . ' rel="prettyphoto">' . $content . '</a>';
	}

}
