<?php

/********* Starting Recipe Archives Widget for Sidebar *********/
if ( ! class_exists( 'Recipe_Archive_Widget' ) ) {
	class Recipe_Archive_Widget extends WP_Widget {

		function __construct() {
			parent::__construct(
				'recipe_archives', // Base ID
				esc_html__( 'Food Recipe: Custom Archive', 'food-recipes-pack' ), // Name
				array( 'description' => esc_html__( 'Show Archives from Recipes or from Blog.', 'food-recipes-pack' ), ) // Args
			);
		}

		/********* Starting Recipe Archives Widget Function *********/
		public function widget( $args, $instance ) {
			extract( $args );
			$title = apply_filters( 'widget_title', $instance['title'] );
			if ( empty( $title ) ) {
				$title = false;
			}

			$archive_type = $instance['archive_type'];

			$args = array(
				'type'   => $archive_type,
				'format' => 'html',
				'echo'   => 1
			);
			echo $before_widget;
			if ( $title ):

				echo '<h2 class="w-bot-border bmarginless">';
				echo $title;
				echo '</h2>';

			endif;

			echo '<div class="archives clearfix">
					<ul>';
			wp_get_archives( $args );
			echo '</ul>
				</div><!-- end of fav-recipes widget -->';
			echo $after_widget;
		}


		/********* Starting Recipe Archives Widget Admin Form *********/

		public function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, array( 'title'        => esc_html__( 'Archives', 'food-recipes-pack' ),
			                                                     'archive_type' => 'monthly'
			) );

			$title        = esc_attr( $instance['title'] );
			$archive_type = esc_attr( $instance['archive_type'] );

			?>
            <p>
                <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Widget Title', 'food-recipes-pack' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
                       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
                       value="<?php echo $title; ?>"/>
            </p>
            <p>
                <label for="<?php echo $this->get_field_id( 'archive_type' ); ?>"><?php esc_html_e( 'Archives Type', 'food-recipes-pack' ); ?></label>
                <select name="<?php echo $this->get_field_name( 'archive_type' ); ?>"
                        id="<?php echo $this->get_field_id( 'archive_type' ); ?>">
                    <option value="yearly"<?php selected( $instance['archive_type'], 'yearly' ); ?>><?php esc_html_e( 'Yearly Archives', 'food-recipes-pack' ); ?></option>
                    <option value="monthly"<?php selected( $instance['archive_type'], 'monthly' ); ?>><?php esc_html_e( 'Monthly Archives', 'food-recipes-pack' ); ?></option>
                    <option value="weekly"<?php selected( $instance['archive_type'], 'weekly' ); ?>><?php esc_html_e( 'Weekly Archives', 'food-recipes-pack' ); ?></option>
                    <option value="daily"<?php selected( $instance['archive_type'], 'daily' ); ?>><?php esc_html_e( 'Daily Archives', 'food-recipes-pack' ); ?></option>
                </select>
            </p>
			<?php
		}

		/********* Starting Recipe Archives Widget Update Function *********/

		public function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title']        = strip_tags( $new_instance['title'] );
			$instance['archive_type'] = strip_tags( $new_instance['archive_type'] );

			return $instance;

		}

	}
}
