<?php

/********* Starting Recipe News and Events Widget for Sidebar or Homepage Bottom Area *********/
if ( ! class_exists( 'Recipe_News_And_Events_Widget' ) ) {
	class Recipe_News_And_Events_Widget extends WP_Widget {
		function __construct() {
			parent::__construct(
				'recipe_news_and_events_widget', // Base ID
				esc_html__( 'Food Recipe: News And Events', 'food-recipes-pack' ), // Name
				array( 'description' => esc_html__( 'Show Latest News and Events from Blog.', 'food-recipes-pack' ), ) // Args
			);
		}

		/**
		 * Starting Recipe News and Events Widget Function
		 * @param $args array
		 * @param $instance array
		 * @return null
		 */

		public function widget( $args, $instance ) {
			extract( $args );

			$title = apply_filters( 'widget_title', $instance['title'] );
			if ( empty( $title ) ) {
				$title = false;
			}

			$post_count     = intval( $instance['post_per_page'] );
			$excerpt_length = intval( $instance['excerpt_length'] );

			echo $before_widget;
			echo '<div class="newsEvent nostylewt">
					<h2 class="w-bot-border">';
			echo $title;
			echo '</h2>
					<ul class="list">';
			$this->news_and_event_loop( $post_count, $excerpt_length );
			echo '</ul>
				</div><!-- end of fav-recipes widget -->';
			echo $after_widget;

		}


		/**
		 * Recipe News and Events Loop
		 * @param $post_count int
		 * @param $excerpt_length int
		 */
		function news_and_event_loop( $post_count = 3, $excerpt_length = 23 ) {

			$args = array(
				'post_type' => 'post',
				'posts_per_page' => $post_count,
				'ignore_sticky_posts' => 1
			);

			$get_posts_query = new WP_Query( $args );
			if ( $get_posts_query->have_posts() ):
				while ( $get_posts_query->have_posts() ):
					$get_posts_query->the_post();
					?>
                    <li>
                        <h5 class="entry-title">
	                        <a href="<?php the_permalink(); ?>">
		                        <?php echo wp_trim_words( get_the_title(), 7, '...' ); ?>
	                        </a>
                        </h5>
                        <p>
	                        <?php
	                        echo wp_trim_words( esc_attr( get_the_excerpt() ), $excerpt_length, '...' );
	                        ?>
	                        <a href="<?php the_permalink(); ?>">
		                        <?php esc_html_e( 'more', 'food-recipes-pack' ); ?>
	                        </a>
                        </p>
                    </li>
				<?php
				endwhile;
			endif;
			wp_reset_postdata();
		}


		/**
		 * Starting Recipe News and Events Widget Admin Form
		 * @param $instance array
		 * @return null
		 */

		public function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, array( 'title'          => esc_html__( 'News and Events', 'food-recipes-pack' ),
			                                                     'post_per_page'  => 3,
			                                                     'excerpt_length' => 12
			) );

			$title          = $instance['title'];
			$post_count     = $instance['post_per_page'];
			$excerpt_length = $instance['excerpt_length'];

			?>
            <p>
                <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Widget Title', 'food-recipes-pack' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
                       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
                       value="<?php echo $title; ?>"/>
            </p>
            <p>
                <label for="<?php echo $this->get_field_id( 'post_per_page' ); ?>"><?php esc_html_e( 'Number of Posts', 'food-recipes-pack' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'post_per_page' ); ?>"
                       name="<?php echo $this->get_field_name( 'post_per_page' ); ?>" type="text"
                       value="<?php echo $post_count; ?>"/>
            </p>
            <p>
                <label for="<?php echo $this->get_field_id( 'excerpt_length' ); ?>"><?php esc_html_e( 'Number of Words', 'food-recipes-pack' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'excerpt_length' ); ?>"
                       name="<?php echo $this->get_field_name( 'excerpt_length' ); ?>" type="text"
                       value="<?php echo $excerpt_length; ?>"/>
            </p>

			<?php
		}


		/**
		 * Starting Recipe News and Events Widget Update Function
		 * @param $new_instance array
		 * @param $old_instance array
		 * @return array
		 */

		public function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title']          = strip_tags( $new_instance['title'] );
			$instance['post_per_page']  = intval( $new_instance['post_per_page'] );
			$instance['excerpt_length'] = intval( $new_instance['excerpt_length'] );

			return $instance;
		}
	}
}