<?php

/********* Starting Recent Recipe Widget For Footer *********/

if ( ! class_exists( 'Recent_Recipe_Footer_Widget' ) ) {
	class Recent_Recipe_Footer_Widget extends WP_Widget {
		function __construct() {
			parent::__construct(
				'recent_recipe_footer_widget', // Base ID
				esc_html__( 'Food Recipe: Recent Recipes Widget', 'food-recipes-pack' ), // Name
				array( 'description' => esc_html__( 'This widget show recent recipes from all recipes.', 'food-recipes-pack' ), ) // Args
			);
		}

		/********* Starting Recent Recipe Widget Function *********/

		public function widget( $args, $instance ) {
			extract( $args );

			$title = apply_filters( 'widget_title', $instance['title'] );
			if ( empty( $title ) ) {
				$title = false;
			}

			$rrf_post_count     = $instance['post_per_page'];
			$rrf_excerpt_length = $instance['excerpt_length'];

			echo $before_widget;
			echo '<h2 class="w-bot-border">' . $title . '</h2>
						<ul class="recent-posts nostylewt">';
			$args = array( 'post_type' => 'recipe', 'posts_per_page' => $rrf_post_count );

			$rrf_posts_query = new WP_Query( $args );

			if ( $rrf_posts_query->have_posts() ):
				while ( $rrf_posts_query->have_posts() ):
					$rrf_posts_query->the_post();
					?>
                    <li class="clearfix">
						<?php if ( has_post_thumbnail() ) { ?>
                            <a href="<?php the_permalink(); ?>"
                               class="img-box"><?php the_post_thumbnail( 'most-rated-thumb' ); ?></a>
						<?php } ?>
                        <h5 class="entry-title"><a
                                    href="<?php the_permalink(); ?>"><?php echo wp_trim_words( esc_attr( get_the_title() ), 5, '...' ); ?></a>
                        </h5>
                        <p><?php echo wp_trim_words( get_the_excerpt(), $rrf_excerpt_length, '...' ); ?></p>
                    </li>
				<?php
				endwhile;
			endif;
			echo '</ul>';
			echo $after_widget;
		}


		/********* Starting Recent Recipe Widget Admin From *********/

		public function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, array( 'title'          => esc_html__( 'Recent Recipes', 'food-recipes-pack' ),
			                                                     'post_per_page'  => 2,
			                                                     'excerpt_length' => 10
			) );

			$title              = $instance['title'];
			$rrf_post_count     = $instance['post_per_page'];
			$rrf_excerpt_length = $instance['excerpt_length'];

			?>
            <p>
                <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Widget Title', 'food-recipes-pack' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>"
                       name="<?php echo $this->get_field_name( 'title' ); ?>" type="text"
                       value="<?php echo $title; ?>"/>
            </p>
            <p>
                <label for="<?php echo $this->get_field_id( 'post_per_page' ); ?>"><?php esc_html_e( 'Number of Posts', 'food-recipes-pack' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'post_per_page' ); ?>"
                       name="<?php echo $this->get_field_name( 'post_per_page' ); ?>" type="text"
                       value="<?php echo $rrf_post_count; ?>"/>
            </p>
            <p>
                <label for="<?php echo $this->get_field_id( 'excerpt_length' ); ?>"><?php esc_html_e( 'Number of Words', 'food-recipes-pack' ); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id( 'excerpt_length' ); ?>"
                       name="<?php echo $this->get_field_name( 'excerpt_length' ); ?>" type="text"
                       value="<?php echo $rrf_excerpt_length; ?>"/>
            </p>
			<?php
		}


		/********* Starting Recent Recipe Widget Update Function *********/

		public function update( $new_instance, $old_instance ) {
			$instance                   = $old_instance;
			$instance['title']          = strip_tags( $new_instance['title'] );
			$instance['post_per_page']  = intval( $new_instance['post_per_page'] );
			$instance['excerpt_length'] = intval( $new_instance['excerpt_length'] );

			return $instance;

		}

	}
}