<?php

/**
 * Starting Recipe Sidebar Tabs Widget For Sidebar and Homepage Bottom Area.
 */

if ( ! class_exists( 'Recipe_Sidebar_Tabed_Widget' ) ) {

	class Recipe_Sidebar_Tabed_Widget extends WP_Widget {

		function __construct() {
			parent::__construct(
				'recipe_sidebar_widget', // Base ID.
				esc_html__( 'Food Recipe: Tabs for Recipes', 'food-recipes-pack' ), // Name.
				array( 'description' => esc_html__( 'Show Recent or Popular or Random Recipes in Tabs with thumbnail.', 'food-recipes-pack' ) ) // Args.
			);
		}


		// Starting Recipe Sidebar Tabs Widget Function.
		public function widget( $args, $instance ) {
			extract( $args );

			$title = apply_filters( 'widget_title', $instance['title'] );
			echo $before_widget;
			if ( empty( $title ) ) {
				$title = false;
			}

			$tab_title_one   = $instance['tab_title_one'];
			$tab_title_two   = $instance['tab_title_two'];
			$tab_title_three = $instance['tab_title_three'];

			$recipe_tab_one   = $instance['recipe_tab_one'];
			$recipe_tab_two   = $instance['recipe_tab_two'];
			$recipe_tab_three = $instance['recipe_tab_three'];

			echo '<h2 class="w-bot-border">';
			echo $title;
			echo '</h2><div class="tabed"><ul class="tabs clearfix">';
			if ( $tab_title_one ) {
				echo '<li class="current">' . $tab_title_one . '<span></span></li>';
			}
			if ( $tab_title_two ) {
				echo '<li>' . $tab_title_two . '<span></span></li>';
			}
			if ( $tab_title_three ) {
				echo '<li>' . $tab_title_three . '<span></span></li>';
			}
			echo '</ul><div class="block current"><ul class="highest">';
			$this->recipe_loop( $recipe_tab_one );
			echo '</ul></div><!-- end of block div -->';

			if ( $tab_title_two ) {
				echo '<div class="block"><ul class="highest">';
				$this->recipe_loop( $recipe_tab_two );
				echo '</ul></div><!-- end of block div -->';
			}

			if ( $tab_title_three ) {
				echo '<div class="block"><ul class="highest">';
				$this->recipe_loop( $recipe_tab_three );
				echo '</ul></div><!-- end of block div -->';
			}
			echo '<div class="bot-border"></div></div><!-- end of tabed div --><!-- end of fav-recipes widget -->';
			echo $after_widget;
		}


		/**
		 * Recipe Sidebar Tabs Widget Loop.
		 */

		private function recipe_loop( $loop_type = 'popular_posts' ) {

			$args['post_type']   = 'recipe';
			$args['numberposts'] = 3;

			if ( 'popular_posts' === $loop_type ) {
				$args['orderby'] = 'comment_count';
			}

			if ( 'random' === $loop_type ) {
				$args['orderby'] = 'rand';
			}
			$get_posts_list = get_posts( $args );
			foreach ( $get_posts_list as $recipe ) {
				?>
				<li>
					<?php if ( has_post_thumbnail( $recipe->ID ) ) { ?>
						<a href="<?php echo esc_url( get_the_permalink( $recipe->ID ) ); ?>" class="img-box"><?php echo get_the_post_thumbnail( $recipe->ID, 'sidebar-tabs' ); ?></a>
					<?php } ?>
					<h5 class="entry-title"><a href="<?php echo esc_url( get_the_permalink( $recipe->ID ) ); ?>"><?php echo wp_kses_post( $recipe->post_title ); ?></a></h5>
					<?php
					$rating_check = get_option( 'recipe_show_rating' );
					if ( 'show_rating' === $rating_check && class_exists( 'Food_Recipes_Pack_Pack_Rating' ) ) {
						$rating = new Food_Recipes_Pack_Pack_Rating();
						?>
						<p class="rate">
							<?php $rating->the_recipe_rating( $recipe->ID ); ?>
							(<?php echo esc_html( Food_Recipes_Pack_Pack_Rating::get_avg_rating( $recipe->ID ) ); ?> / 5)
						</p>
					    <?php
					}
					?>
				</li>
				<?php
			}
		}


		// Starting Recipe Sidebar Tabs Widget Admin Form.
		public function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, array(
				'title'            => esc_html__( 'MISC Recipes', 'food-recipes-pack' ),
				'tab_title_one'    => esc_html__( 'Recent', 'food-recipes-pack' ),
				'tab_title_two'    => esc_html__( 'Popular', 'food-recipes-pack' ),
				'tab_title_three'  => esc_html__( 'Random', 'food-recipes-pack' ),
				'recipe_tab_one'   => 'recent_posts',
				'recipe_tab_two'   => 'popular_posts',
				'recipe_tab_three' => 'random',
			) );

			$title = esc_attr( $instance['title'] );

			$tab_title_one   = esc_attr( $instance['tab_title_one'] );
			$tab_title_two   = esc_attr( $instance['tab_title_two'] );
			$tab_title_three = esc_attr( $instance['tab_title_three'] );

			?>
			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Widget Title', 'food-recipes-pack' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>"/>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'tab_title_one' ); ?>"><?php esc_html_e( 'First Tab Title', 'food-recipes-pack' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'tab_title_one' ); ?>" name="<?php echo $this->get_field_name( 'tab_title_one' ); ?>" type="text" value="<?php echo $tab_title_one; ?>"/>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'tab_title_two' ); ?>"><?php esc_html_e( 'Second Tab Title', 'food-recipes-pack' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'tab_title_two' ); ?>" name="<?php echo $this->get_field_name( 'tab_title_two' ); ?>" type="text" value="<?php echo $tab_title_two; ?>"/>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'tab_title_three' ); ?>"><?php esc_html_e( 'Third Tab Title', 'food-recipes-pack' ); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'tab_title_three' ); ?>" name="<?php echo $this->get_field_name( 'tab_title_three' ); ?>" type="text" value="<?php echo $tab_title_three; ?>"/>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'recipe_tab_one' ); ?>"><?php esc_html_e( 'First Tab Posts View', 'food-recipes-pack' ); ?></label>
				<select name="<?php echo $this->get_field_name( 'recipe_tab_one' ); ?>" id="<?php echo $this->get_field_id( 'recipe_tab_one' ); ?>">
					<option value="recent_posts"<?php selected( $instance['recipe_tab_one'], 'recent_posts' ); ?>><?php esc_html_e( 'Recent Posts', 'food-recipes-pack' ); ?></option>
					<option value="popular_posts"<?php selected( $instance['recipe_tab_one'], 'popular_posts' ); ?>><?php esc_html_e( 'Most Popular Posts', 'food-recipes-pack' ); ?></option>
					<option value="random"<?php selected( $instance['recipe_tab_one'], 'random' ); ?>><?php esc_html_e( 'Random Recipes', 'food-recipes-pack' ); ?></option>
				</select>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'recipe_tab_two' ); ?>"><?php esc_html_e( 'Second Tab Posts View', 'food-recipes-pack' ); ?></label>
				<select name="<?php echo $this->get_field_name( 'recipe_tab_two' ); ?>" id="<?php echo $this->get_field_id( 'recipe_tab_two' ); ?>">
					<option value="recent_posts" <?php selected( $instance['recipe_tab_two'], 'recent_posts' ); ?>><?php esc_html_e( 'Recent Posts', 'food-recipes-pack' ); ?></option>
					<option value="popular_posts"<?php selected( $instance['recipe_tab_two'], 'popular_posts' ); ?>><?php esc_html_e( 'Most Popular Posts', 'food-recipes-pack' ); ?></option>
					<option value="random"<?php selected( $instance['recipe_tab_two'], 'random' ); ?>><?php esc_html_e( 'Random Recipes', 'food-recipes-pack' ); ?></option>
				</select>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'recipe_tab_three' ); ?>"><?php esc_html_e( 'Third Tab Posts View', 'food-recipes-pack' ); ?></label>
				<select name="<?php echo $this->get_field_name( 'recipe_tab_three' ); ?>" id="<?php echo $this->get_field_id( 'recipe_tab_three' ); ?>">
					<option value="recent_posts"<?php selected( $instance['recipe_tab_three'], 'recent_posts' ); ?>><?php esc_html_e( 'Recent Recipes', 'food-recipes-pack' ); ?></option>
					<option value="popular_posts"<?php selected( $instance['recipe_tab_three'], 'popular_posts' ); ?>><?php esc_html_e( 'Most Popular Recipes', 'food-recipes-pack' ); ?></option>
					<option value="random"<?php selected( $instance['recipe_tab_three'], 'random' ); ?>><?php esc_html_e( 'Random Recipes', 'food-recipes-pack' ); ?></option>
				</select>
			</p>

			<?php
		}


		/**
		 * Starting Recipe Sidebar Tabs Widget Update Function.
		 */

		public function update( $new_instance, $old_instance ) {
			$instance                     = $old_instance;
			$instance['title']            = wp_strip_all_tags( $new_instance['title'] );
			$instance['tab_title_one']    = wp_strip_all_tags( $new_instance['tab_title_one'] );
			$instance['tab_title_two']    = wp_strip_all_tags( $new_instance['tab_title_two'] );
			$instance['tab_title_three']  = wp_strip_all_tags( $new_instance['tab_title_three'] );
			$instance['recipe_tab_one']   = $new_instance['recipe_tab_one'];
			$instance['recipe_tab_two']   = $new_instance['recipe_tab_two'];
			$instance['recipe_tab_three'] = $new_instance['recipe_tab_three'];

			return $instance;
		}

	}
}
