<?php

if ( ! class_exists( 'Weekly_Special_Widget' ) ) {
	/**
	 * Starting Weekly Special Recipe Widget For Sidebar and Home Page Bottom Area
	 */
	class Weekly_Special_Widget extends WP_Widget {

		function __construct() {
			parent::__construct(
				'weekly_special', // Base ID.
				esc_html__( 'Food Recipe: Weekly Special Recipe', 'food-recipes-pack' ), // Name.
				array( 'description' => esc_html__( 'Show one weekly special recipe', 'food-recipes-pack' ) ) // Args.
			);
		}

		/**
		 * Tarting Weekly Special Recipe Widget Function.
		 */
		public function widget( $args, $instance ) {
			extract( $args );

			$title = apply_filters( 'widget_title', $instance['title'] );
			//$weekly_recipe =  $instance['weekly-recipe'];

			if ( empty( $title ) ) {
				$title = false;
			}

			$special_post = (array) $instance['weekly-recipe'];
			echo $before_widget;
			if ( $title ) :
				echo '<h2 class="w-bot-border entry-title">';
				echo wp_kses_post( $title );
				echo '</h2>';
			endif;
			$special_args = array(
				'post_type'      => 'recipe',
				'posts_per_page' => 1,
				'post__in'       => $special_post,
			);

			$special_query = new WP_Query( $special_args );

			if ( $special_query->have_posts() ) {
				while ( $special_query->have_posts() ) :
					$special_query->the_post();

					if ( has_post_thumbnail() ) {
						?>
                        <div class="img-box for-all">
                            <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'weekly-special-thumb' ); ?></a>
                        </div>
						<?php
					}
					?>
                    <div class="for-res">
                        <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'weekly-for-res' ); ?></a>
                    </div>
                    <h4 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
                    <p>
						<?php
						echo wp_trim_words( get_the_excerpt(), 21, '...' );
						?>
                    </p>
                    <a href="<?php the_permalink(); ?>"
                       class="readmore"><?php esc_html_e( 'Read More', 'food-recipes-pack' ); ?></a>
				<?php
				endwhile;
			}
			echo $after_widget;
		}


		/**
		 * Starting Weekly Special Recipe Widget Admin From.
		 */
		public function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, array(
				'title'         => esc_html__( 'Weekly Special', 'food-recipes-pack' ),
				'weekly-recipe' => '',
			) );

			$title         = esc_attr( $instance['title'] );
			$weekly_recipe = $instance['weekly-recipe'];

			?>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Widget Title', 'food-recipes-pack' ); ?></label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
                       name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text"
                       value="<?php echo wp_kses( $title, inspiry_allowed_html_tags() ); ?>"/>
            </p>
            <p>
				<?php
				$id_value   = $this->get_field_id( 'weekly-recipe' );
				$name_value = $this->get_field_name( 'weekly-recipe' );
				?>
                <label for="<?php echo esc_attr( $id_value ); ?>"><?php esc_html_e( 'Weekly Special Recipe', 'food-recipes-pack' ); ?></label>
				<?php inspiry_generate_weekly_recipe( $id_value, $name_value, 'recipe', $weekly_recipe ); ?>
            </p>

			<?php
		}


		/**
		 * Starting Weekly Special Recipe Widget Update Function.
		 * @param $new_instance array
		 * @param $old_instance array
		 * @return array
		 */
		public function update( $new_instance, $old_instance ) {
			$instance                  = $old_instance;
			$instance['title']         = strip_tags( $new_instance['title'] );
			$instance['weekly-recipe'] = strip_tags( $new_instance['weekly-recipe'] );

			return $instance;
		}

	}
}
