<?php
/**
 * Registering meta boxes
 *
 * All the definitions of meta boxes are listed below with comments.
 * Please read them CAREFULLY.
 *
 * You also should read the changelog to know what has been changed before updating.
 *
 * For more information, please visit:
 * @link http://metabox.io/docs/registering-meta-boxes/
 */


add_filter( 'rwmb_meta_boxes', 'inspiry_register_meta_boxes' );

/**
 * Register meta boxes
 *
 * Remember to change "your_prefix" to actual prefix in your project
 *
 * @param array $meta_boxes List of meta boxes
 *
 * @return array
 */
function inspiry_register_meta_boxes( $meta_boxes ){

    $prefix = 'RECIPE_META_';

    $meta_boxes[] = array(
        'id'         => 'recipe_additional',
        'title'      => esc_html__('Recipe Information', 'inspirythemes-food-recipes'),
        'post_types' => array( 'recipe' ),
        'context'    => 'normal',

        // Order of meta box: high (default), low. Optional.
        'priority'   => 'high',

        // Auto save: true, false (default). Optional.
        'autosave'   => true,

        // List of meta fields
        'fields'	=> array(
            array(
                'name'		=> esc_html__('Video Based Recipe', 'inspirythemes-food-recipes'),
                'desc'      => esc_html__('A Video Based recipe does not display attached images and only display a video at top.', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'recipe_video_check',
                'type'		=> 'radio',
                'options'   => array( 'on' => esc_html__('Yes ', 'inspirythemes-food-recipes'), 'off'   =>  esc_html__('No ', 'inspirythemes-food-recipes')),
                'std'   =>  'off'
            ),
            array(
                'name'		=> esc_html__('Video Embed Code', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'recipe_video_code',
                'desc'		=> esc_html__('Provide the video embed code and Modify the width attribute to 575px and height attribute to 323px. 16:9 Ratio', 'inspirythemes-food-recipes'),
                'clone'		=> false,
                'type'		=> 'textarea',
                'std'		=> ''
            ),
            array(
                'name'	=> esc_html__('Attach Images', 'inspirythemes-food-recipes'),
                'desc'	=> esc_html__('Upload recipe images here. Minimum required size for an image is 575px in width and 262px in height. These Images will appear in slider on recipe page. Please do not forget to provide featured image for this recipe using Featured Image metabox in right sidebar as featured image will be displayed on homepage, recipe listings and widgets. ', 'inspirythemes-food-recipes'),
                'id'	=> "{$prefix}more_images_recipe",
                'type'	=> 'image_advanced'
            ),
            array(
                'name'		=> esc_html__('Yield', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'yield',
                'desc'		=> esc_html__('How much/many does this recipe produce?', 'inspirythemes-food-recipes'),
                'clone'		=> false,
                'type'		=> 'text',
                'std'		=> ''
            ),
            array(
                'name'		=> esc_html__('Servings', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'servings',
                'desc'		=> esc_html__('How many servings?', 'inspirythemes-food-recipes'),
                'clone'		=> false,
                'type'		=> 'text',
                'std'		=> ''
            ),
            array(
                'name'		=> esc_html__('Prep Time', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'prep_time',
                'desc'		=> esc_html__('How Many Minutes ?  Minutes Above 60 will be displayed in hours.', 'inspirythemes-food-recipes'),
                'clone'		=> false,
                'type'		=> 'text',
                'std'		=> ''
            ),
            array(
                'name'		=> esc_html__('Cook Time', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'cook_time',
                'desc'		=> esc_html__('How Many Minutes ?  Minutes Above 60 will be displayed in hours.', 'inspirythemes-food-recipes'),
                'clone'		=> false,
                'type'		=> 'text',
                'std'		=> ''
            ),
            array(
                'name'		=> esc_html__('Ready In', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'ready_in',
                'desc'		=> esc_html__('How Many Minutes ?  Minutes Above 60 will be displayed in hours.', 'inspirythemes-food-recipes'),
                'clone'		=> false,
                'type'		=> 'text',
                'std'		=> ''
            ),
            array(
                'name'		=> esc_html__('Ingredients', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'ingredients',
                'desc'		=> sprintf( esc_html__('You can add list of ingredients here. Use %s on the right to add new ingredient. %s', 'inspirythemes-food-recipes'), '<strong>+ button</strong>', '<strong>To display the list you need to write [ingredients] short code in your content editor.</strong>' ),
                'clone'		=> true,
                'type'		=> 'text',
                'std'		=> 'New',
                'rows'      => 1
            ),
            array(
                'name'		=> esc_html__('Method Steps', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'method_steps',
                'desc'		=> sprintf( esc_html__('You can add list of recipe method steps here. Use %s on the right to add new step. %s', 'inspirythemes-food-recipes'), '<strong>+ button</strong>', '<strong>To display the list you need to write [method] short code in your content editor.</strong>' ),
                'clone'		=> true,
                'type'		=> 'textarea',
                'std'		=> ''
            ),
            array(
                'name'		=> esc_html__('Nutrient Name', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'nut_name',
                'desc'		=> sprintf( esc_html__('Enter the name of nutritional Item Name. Use %s on the right to add new Nutrient Name', 'inspirythemes-food-recipes'), '<strong>+ button</strong>' ),
                'clone'		=> true,
                'type'		=> 'text',
                'std'		=> ''
            ),
            array(
                'name'		=> esc_html__('Mass', 'inspirythemes-food-recipes'),
                'id'		=> $prefix . 'nut_mass',
                'desc'		=> sprintf( esc_html__('Enter Nutrient Mass. Use %s on the right to add new Mass Value.', 'inspirythemes-food-recipes'), '<strong>+ button</strong>' ),
                'clone'		=> true,
                'type'		=> 'text',
                'std'		=> ''
            )
        )
    );

    // Filtering metaboxes plugin to be edited from child theme.
    $meta_boxes = apply_filters( 'foodrecipes_meta_boxes', $meta_boxes);

    return $meta_boxes;
}
