<?php
/**
 * Customizer settings for Contact Page
 *
 * @package FR
 */

if ( ! function_exists( 'inspiry_contact_page_customizer' ) ) :
	function inspiry_contact_page_customizer( WP_Customize_Manager $wp_customize ) {


		$wp_customize->add_section( 'inspiry_contact_page_section', array(
			'title'    => esc_html__( 'Contact', 'inspirythemes-food-recipes' ),
			'priority' => 39,
		) );


		$wp_customize->add_setting( 'show_contact_map', array(
			'type'              => 'option',
			'default'           => 'show',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'show_contact_map', array(
			'label'   => esc_html__( 'Google Map', 'inspirythemes-food-recipes' ),
			'type'    => 'radio',
			'section' => 'inspiry_contact_page_section',
			'choices' => array(
				'show' => esc_html__( 'Show', 'inspirythemes-food-recipes' ),
				'hide' => esc_html__( 'Hide', 'inspirythemes-food-recipes' ),
			),
		) );


		$wp_customize->add_setting( 'map_latitude', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => '48.858370',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'map_latitude', array(
			'label'       => esc_html__( 'Map Latitude', 'inspirythemes-food-recipes' ),
			'description' => sprintf( esc_html__( 'Enter Google Map Latitude for your place. You can get Latitude Value From %s', 'inspirythemes-food-recipes' ), '<a target="_blank" href="http://itouchmap.com/latlong.html">' . esc_html__( 'HERE', 'inspirythemes-food-recipes' ) . '</a>' ),
			'type'        => 'number',
			'section'     => 'inspiry_contact_page_section',
		) );


		$wp_customize->add_setting( 'map_longitude', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => '2.294481',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'map_longitude', array(
			'label'       => esc_html__( 'Map Longitude', 'inspirythemes-food-recipes' ),
			'description' => sprintf( esc_html__( 'Enter Google Map Longitude for your place. You can get Longitude Value From %s', 'inspirythemes-food-recipes' ), '<a target="_blank" href="	http://itouchmap.com/latlong.html">' . esc_html__( 'HERE', 'inspirythemes-food-recipes' ) . '</a>' ),
			'type'        => 'number',
			'section'     => 'inspiry_contact_page_section',
		) );

		$wp_customize->add_setting( 'map_zoom_level', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => '17',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'map_zoom_level', array(
			'label'       => esc_html__( 'Google Map Zoom Level', 'inspirythemes-food-recipes' ),
			'description' => esc_html__( 'Enter Google Map Zoom Level', 'inspirythemes-food-recipes' ),
			'type'        => 'number',
			'section'     => 'inspiry_contact_page_section',
		) );

	}

	add_action( 'customize_register', 'inspiry_contact_page_customizer' );
endif;

if ( ! function_exists( 'inspiry_contact_page_defaults' ) ) :
	/**
	 * Set default values for contact_page settings
	 *
	 * @param WP_Customize_Manager $wp_customize
	 */
	function inspiry_contact_page_defaults( WP_Customize_Manager $wp_customize ) {
		$homepage_settings_ids = array(
			'show_contact_map',
			'map_latitude',
			'map_longitude',
			'map_zoom_level',
			'contact_form_heading',
			'contact_email_address',
		);
		inspiry_initialize_defaults( $wp_customize, $homepage_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_contact_page_defaults' );
endif;
