<?php
/**
 * Customizer
 *
 * @package FR
 */

if ( ! function_exists( 'inspiry_initialize_defaults' ) ) :
	/**
	 * Helper function to initialize default values for settings as customizer api do not do so by default.
	 *
	 * @param WP_Customize_Manager $wp_customize - Instance of WP_Customize_Manager.
	 * @param $inspiry_settings_ids - Settings ID of the theme.
	 *
	 * @since 1.0.0
	 */
	function inspiry_initialize_defaults( WP_Customize_Manager $wp_customize, $inspiry_settings_ids ) {
		if ( is_array( $inspiry_settings_ids ) && ! empty( $inspiry_settings_ids ) ) {
			foreach ( $inspiry_settings_ids as $setting_id ) {
				$setting = $wp_customize->get_setting( $setting_id );
				if ( $setting ) {
					add_option( $setting->id, $setting->default );
				}
			}
		}
	}
endif;

if ( ! function_exists( 'theme_sanitize_radio' ) ) :
	/**
	 * Select sanitation function.
	 *
	 * @param string $input Select input.
	 *
	 * @param string $setting Setting name from customizer.
	 *
	 * @return string Return the value after sanitize.
	 */
	function theme_sanitize_radio( $input, $setting ) {

		// Input must be a slug: lowercase alphanumeric characters, dashes and underscores are allowed only.
		$input = sanitize_key( $input );

		// Get the list of possible select options.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// Return input if valid or return default option.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

	}
endif;


if ( ! function_exists( 'theme_sanitize_select' ) ) :
	function theme_sanitize_select( $input, $setting ) {
		global $wp_customize;

		$control = $wp_customize->get_control( $setting->id );

		if ( array_key_exists( $input, $control->choices ) ) {
			return $input;
		} else {
			return $setting->default;
		}
	}
endif;

if ( ! function_exists( 'remove_customizer_settings' ) ) :
	/**
	 * Helper function to remove default sections.
	 *
	 * @param WP_Customize_Manager $wp_customize - Instance of WP_Customize_Manager.
	 * @param $inspiry_settings_ids - Settings ID of the theme.
	 *
	 * @since 1.0.0
	 */

	function remove_customizer_settings( $wp_customize ) {

		$wp_customize->remove_section( 'background_image' );
		$wp_customize->get_control( 'header_image' )->section   = 'inspiry_header_background_image_section';
		$wp_customize->get_control( 'header_image' )->priority  = 10;
		$wp_customize->get_control( 'show_on_front' )->section  = 'inspiry_home_general_section';
		$wp_customize->get_control( 'page_on_front' )->section  = 'inspiry_home_general_section';
		$wp_customize->get_control( 'page_for_posts' )->section = 'inspiry_home_general_section';

	}

	add_action( 'customize_register', 'remove_customizer_settings', 20 );

endif;

/**
 * Header Settings
 */
require_once INSPIRY_FRAMEWORK . 'header.php';

/**
 * Home Page Settings
 */

require_once INSPIRY_FRAMEWORK . 'home.php';


/**
 * Blog Settings
 */
require_once INSPIRY_FRAMEWORK . 'blog.php';

/**
 * User Listing Settings
 */
require_once INSPIRY_FRAMEWORK . 'user-listing.php';

/**
 * User Profile Settings
 */
require_once INSPIRY_FRAMEWORK . 'user-profile.php';

/**
 * Contact Page Settings
 */
require_once INSPIRY_FRAMEWORK . 'contact-page.php';

/**
 * Footer Settings
 */
require_once INSPIRY_FRAMEWORK . 'footer.php';

/**
 * Styles Settings
 */
require_once INSPIRY_FRAMEWORK . 'styles.php';


/**
 * Filter to modify input label in repeater control
 * You can filter by control id and input name.
 * /
 *
 * @param string $string Input label.
 * @param string $id Input id.
 * @param string $control Control name.
 *
 * @modified 1.1.41
 *
 * @return string
 */
function repeater_labels( $string, $id, $control ) {
	if ( 'right_info_slider' === $id || 'basic_image_slider' === $id || 'whats_hot_list_item' === $id ) {
		if ( 'customizer_repeater_title_control' === $control ) {
			return esc_html__( 'Recipe / Post ID', 'inspirythemes-food-recipes' );
		}
	}

	return $string;
}

add_filter( 'repeater_input_labels_filter', 'repeater_labels', 10, 3 );
