<?php
/**
 * Customizer settings for Header
 *
 * @package FR
 */

if ( ! function_exists( 'inspiry_header_customizer' ) ) :
	function inspiry_header_customizer( WP_Customize_Manager $wp_customize ) {

		/**
		 * Header Panel
		 */
		$wp_customize->add_panel( 'inspiry_header_panel', array(
			'title'    => esc_html__( 'Header', 'inspirythemes-food-recipes' ),
			'priority' => 30,
		) );

		/**
		 * Header General Section
		 */
		$wp_customize->add_section( 'inspiry_header_general_section', array(
			'title' => esc_html__( 'General', 'inspirythemes-food-recipes' ),
			'panel' => 'inspiry_header_panel',
		) );


		// Number of recipe types.
		$wp_customize->add_setting( 'header_terms_count', array(
			'type'              => 'option',
			'default'           => esc_html__( '15', 'inspirythemes-food-recipes' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'header_terms_count', array(
			'label'       => esc_html__( 'Number of recipe types you want to show under main menu.', 'inspirythemes-food-recipes' ),
			'description' => esc_html__( 'Provide number for recipe types you want to show on the right side of search field under main menu. Leaving it empty will hide terms. Term with no recipe assigned will be skipped.', 'inspirythemes-food-recipes' ),
			'type'        => 'number',
			'section'     => 'inspiry_header_general_section',
		) );

		/* Show/Hide Header User Menu */
		$wp_customize->add_setting( 'header_user_menu_show_hide', array(
			'type'              => 'option',
			'default'           => 'on',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'header_user_menu_show_hide', array(
			'label'       => esc_html__( 'Header User Menu', 'inspirythemes-food-recipes' ),
			'description' => esc_html__( 'Select if you want to turn the header user login options on or off.', 'inspirythemes-food-recipes' ),
			'type'        => 'radio',
			'section'     => 'inspiry_header_general_section',
			'choices'     => array(
				'on'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'off' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
		) );


		/**
		 * Header Section
		 */
		$wp_customize->add_section( 'inspiry_header_section', array(
			'title'       => esc_html__( 'Site Identity', 'inspirythemes-food-recipes' ),
			'description' => sprintf( esc_html__( '**IMPORTANT** This section will be %s in the favour of default WordPress Site Identity Settings.', 'inspirythemes-food-recipes' ), '<strong style="color: red;">' . esc_attr__( 'DEPRECATED', 'inspirythemes-food-recipes' ) . '</strong>' ),
			'panel'       => 'inspiry_header_panel',
		) );

		/* Logo */
		$wp_customize->add_setting( 'header_logo_image', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'header_logo_image', array(
			'label'       => esc_html__( 'Site Logo', 'inspirythemes-food-recipes' ),
			'section'     => 'inspiry_header_section',
			'settings'    => 'header_logo_image',
			'flex_width'  => true,
			'flex_height' => true,
			'width'       => 165,
			'height'      => 60,
			'priority'    => 1,
		) ) );


		/* Site Icon */
		$wp_customize->add_setting( 'favicon', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'favicon', array(
			'label'       => esc_html__( 'Site Favicon', 'inspirythemes-food-recipes' ),
			'section'     => 'inspiry_header_section',
			'settings'    => 'favicon',
			'flex_width'  => true,
			'flex_height' => true,
			'width'       => 25,
			'height'      => 25,
			'priority'    => 2,
		) ) );

		/**
		 * Header Background Image Section
		 */
		$wp_customize->add_section( 'inspiry_header_background_image_section', array(
			'title' => esc_html__( 'Background Image', 'inspirythemes-food-recipes' ),
			'panel' => 'inspiry_header_panel',
		) );

		/* Show/Hide Header Image */
		$wp_customize->add_setting( 'header_image_on_off', array(
			'type'              => 'option',
			'default'           => 'on',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'header_image_on_off', array(
			'label'       => esc_html__( 'Do you want to upload header image.', 'inspirythemes-food-recipes' ),
			'description' => esc_html__( 'Please select on if you want to upload header image form there. if you upload header image from then your default header image will be override. ', 'inspirythemes-food-recipes' ),
			'type'        => 'radio',
			'section'     => 'inspiry_header_background_image_section',
			'choices'     => array(
				'on'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'off' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
		) );

		/* Show/Hide Image control based on Header Image Control */
		$wp_customize->get_control( 'header_image' )->active_callback = function () use ( $wp_customize ) {
			return 'on' === $wp_customize->get_setting( 'header_image_on_off' )->value();
		};


	}

	add_action( 'customize_register', 'inspiry_header_customizer' );
endif;

if ( ! function_exists( 'inspiry_header_defaults' ) ) :
	/**
	 * Set default values for header settings
	 *
	 * @param WP_Customize_Manager $wp_customize
	 */
	function inspiry_header_defaults( WP_Customize_Manager $wp_customize ) {
		$homepage_settings_ids = array(
			'header_terms_count',
			'header_image_on_off',
			'header_logo_image',
			'favicon',
			'header_user_menu_show_hide',

		);
		inspiry_initialize_defaults( $wp_customize, $homepage_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_header_defaults' );
endif;