<?php
/**
 * Customizer settings for Homepage Basic Slider
 *
 * @package FR
 */

if ( ! function_exists( 'inspiry_home_basic_customizer' ) ) :

	function inspiry_home_basic_customizer( WP_Customize_Manager $wp_customize ) {

		$inspiry_google_fonts = inspiry_get_google_fonts_list();

		// Number of recent recipes.
		$wp_customize->add_setting( 'basic_slider_title', array(
			'type'              => 'option',
			'default'           => esc_html__( 'Top Recipes ', 'inspirythemes-food-recipes' ) . '<span>' . esc_html__( 'of the day', 'inspirythemes-food-recipes' ) . '</span>',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'basic_slider_title', array(
			'label'           => esc_html__( 'Slider Title', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Enter Title for slider.', 'inspirythemes-food-recipes' ),
			'type'            => 'text',
			'section'         => 'inspiry_home_slider_section',
			'active_callback' => function () use ( $wp_customize ) {
				return 'Basic Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );

		// Number of recent recipes.
		$wp_customize->add_setting( 'b_slider_statement', array(
			'type'              => 'option',
			'default'           => esc_html__( 'Sliding recipes are much more tasty as food than sliding images. :D', 'inspirythemes-food-recipes' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'wp_kses_post',
		) );
		$wp_customize->add_control( 'b_slider_statement', array(
			'label'           => esc_html__( 'Slider Description', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Enter Description for slider.', 'inspirythemes-food-recipes' ),
			'type'            => 'textarea',
			'section'         => 'inspiry_home_slider_section',
			'active_callback' => function () use ( $wp_customize ) {
				return 'Basic Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );

		/* Show/Hide Slider Title */
		$wp_customize->add_setting( 'basic_slider_post_select', array(
			'type'              => 'option',
			'default'           => 'off',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'basic_slider_post_select', array(
			'label'           => esc_html__( 'Do you want to add post support in slider', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Please select YES if you want to add support in Basic Slider.', 'inspirythemes-food-recipes' ),
			'type'            => 'radio',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => array(
				'on'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'off' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Basic Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );

		/* Show/Hide Slider Title */
		$wp_customize->add_setting( 'basic_slider_on_off', array(
			'type'              => 'option',
			'default'           => 'off',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'basic_slider_on_off', array(
			'label'           => esc_html__( 'Recipes or posts in left Image Slider based on latest/Random or selected', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'This filed contain two option. If you want to display latest recipes or post then select ON. If you want to display selected recipes or posts then choose OFF.', 'inspirythemes-food-recipes' ),
			'type'            => 'radio',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => array(
				'on'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'off' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Basic Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );

		$wp_customize->add_setting( 'basic_slider_random_latest_select_lis', array(
			'type'              => 'option',
			'default'           => 'off',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'basic_slider_random_latest_select_lis', array(
			'label'           => esc_html__( 'Select latest/Random', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Please select Latest or Random and then enter the number(digit) of recipes/posts which you want to show in left image slider', 'inspirythemes-food-recipes' ),
			'type'            => 'radio',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => array(
				'latest' => esc_html__( 'Latest', 'inspirythemes-food-recipes' ),
				'random' => esc_html__( 'Random', 'inspirythemes-food-recipes' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Basic Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'on' === $wp_customize->get_setting( 'basic_slider_on_off' )->value();
			},
		) );

		$wp_customize->add_setting( 'basic_image_slide_numbers', array(
			'type'              => 'option',
			'default'           => 'off',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'basic_image_slide_numbers', array(
			'label'           => esc_html__( 'Latest Recipes or Posts', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Enter the number of recipes or posts which you want to show in left image slider.', 'inspirythemes-food-recipes' ),
			'type'            => 'number',
			'section'         => 'inspiry_home_slider_section',
			'active_callback' => function () use ( $wp_customize ) {
				return 'Basic Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'on' === $wp_customize->get_setting( 'basic_slider_on_off' )->value();
			},
		) );

		if ( class_exists( 'Customizer_Repeater' ) ) {

			$wp_customize->add_setting( 'basic_image_slider', array(
				'sanitize_callback' => 'customizer_repeater_sanitize',
				'transport'         => 'postMessage',
				'type'              => 'option',
			) );
			$wp_customize->add_control( new Customizer_Repeater( $wp_customize, 'basic_image_slider', array(
				'label'                                 => esc_html__( 'Post or Recipes IDs for Basic Slider', 'inspirythemes-food-recipes' ),
				'section'                               => 'inspiry_home_slider_section',
				'customizer_repeater_image_control'     => true,
				'customizer_repeater_icon_control'      => false,
				'customizer_repeater_title_control'     => true,
				'customizer_repeater_subtitle_control'  => false,
				'customizer_repeater_text_control'      => false,
				'customizer_repeater_link_control'      => false,
				'customizer_repeater_shortcode_control' => false,
				'customizer_repeater_repeater_control'  => false,
				'active_callback'                       => function () use ( $wp_customize ) {
					return 'Basic Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'off' === $wp_customize->get_setting( 'basic_slider_on_off' )->value();
				},
			) ) );
		}
	}

	add_action( 'customize_register', 'inspiry_home_basic_customizer' );
endif;

if ( ! function_exists( 'inspiry_home_basic_defaults' ) ) :
	/**
	 * Set default values for home_lis settings
	 *
	 * @param WP_Customize_Manager $wp_customize
	 */
	function inspiry_home_basic_defaults( WP_Customize_Manager $wp_customize ) {
		$homepage_settings_ids = array(
			'basic_slider_title',
			'b_slider_statement',
			'basic_slider_post_select',
			'basic_slider_on_off',
			'basic_slider_random_latest_select_lis',
			'basic_image_slide_numbers',
			'basic_image_slider',
		);
		inspiry_initialize_defaults( $wp_customize, $homepage_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_home_basic_defaults' );
endif;
