<?php
/**
 * Customizer settings for Homepage Left Image Slider
 *
 * @package FR
 */

if ( ! function_exists( 'inspiry_home_lis_customizer' ) ) :

	function inspiry_home_lis_customizer( WP_Customize_Manager $wp_customize ) {

		$inspiry_google_fonts = inspiry_get_google_fonts_list();

		// Number of recent recipes.
		$wp_customize->add_setting( 'l_slider_title', array(
			'type'              => 'option',
			'default'           => 'Top Recipes <span>of the day</span>',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'wp_kses_post',
		) );
		$wp_customize->add_control( 'l_slider_title', array(
			'label'           => esc_html__( 'Slider Title', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Enter Title for slider.', 'inspirythemes-food-recipes' ),
			'type'            => 'text',
			'section'         => 'inspiry_home_slider_section',
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );
		$wp_customize->selective_refresh->add_partial(
			'l_slider_title', array(
				'selector'        => '#slider .slider-head',
				'render_callback' => function () use ( $wp_customize ) {
					return $wp_customize->get_setting( 'l_slider_title' )->value();
				},
			)
		);

		/* Show/Hide Slider Title */
		$wp_customize->add_setting( 'l_slider_title_on_off', array(
			'type'              => 'option',
			'default'           => 'off',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'l_slider_title_on_off', array(
			'label'           => esc_html__( 'Do you want to change the font of Slider Title.', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Please select Yes if you want to change the font fo Slider Title.', 'inspirythemes-food-recipes' ),
			'type'            => 'radio',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => array(
				'on'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'off' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );


		$wp_customize->add_setting( 'l_slider_title_typography-font-color', array(
			'type'              => 'option',
			'default'           => '#5e6063',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( 'l_slider_title_typography-font-color', array(
			'label'           => esc_html__( 'Heading Color', 'inspirythemes-food-recipes' ),
			'type'            => 'color',
			'section'         => 'inspiry_home_slider_section',
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'on' === $wp_customize->get_setting( 'l_slider_title_on_off' )->value();
			},
		) );

		$wp_customize->add_setting( 'l_slider_title_typography-font-family', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'l_slider_title_typography-font-family', array(
			'label'           => esc_html__( 'Heading Font Family', 'inspirythemes-food-recipes' ),
			'type'            => 'select',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => inspiry_get_google_fonts_list(),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'on' === $wp_customize->get_setting( 'l_slider_title_on_off' )->value();
			},
		) );

		$wp_customize->add_setting( 'l_slider_title_typography-font-size', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'l_slider_title_typography-font-size', array(
			'label'           => esc_html__( 'Heading Font Size', 'inspirythemes-food-recipes' ),
			'type'            => 'select',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => font_sizes_array( 'Font Size' ),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'on' === $wp_customize->get_setting( 'l_slider_title_on_off' )->value();
			},
		) );

		$wp_customize->add_setting( 'l_slider_title_typography-font-weight', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'l_slider_title_typography-font-weight', array(
			'label'           => esc_html__( 'Heading Font Weight', 'inspirythemes-food-recipes' ),
			'type'            => 'select',
			'section'         => 'inspiry_home_slider_section',
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'on' === $wp_customize->get_setting( 'l_slider_title_on_off' )->value();
			},
			'choices'         => array(
				''        => esc_html__( 'Font Weight', 'inspirythemes-food-recipes' ),
				'normal'  => 'normal',
				'bold'    => 'bold',
				'bolder'  => 'bolder',
				'lighter' => 'lighter',
				'100'     => '100',
				'200'     => '200',
				'300'     => '300',
				'400'     => '400',
				'500'     => '500',
				'600'     => '600',
				'700'     => '700',
				'800'     => '800',
				'900'     => '900',
				'inherit' => 'inherit',
			),
		) );

		$wp_customize->add_setting( 'l_slider_title_typography-line-height', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'l_slider_title_typography-line-height', array(
			'label'           => esc_html__( 'Heading Line Height', 'inspirythemes-food-recipes' ),
			'type'            => 'select',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => font_sizes_array( 'Line Height' ),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'on' === $wp_customize->get_setting( 'l_slider_title_on_off' )->value();
			},
		) );

		// Number of recent recipes.
		$wp_customize->add_setting( 'l_slider_statement', array(
			'type'              => 'option',
			'default'           => esc_html__( 'Sliding recipes are much more tasty as food than sliding images. :D', 'inspirythemes-food-recipes' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'wp_kses_post',
		) );
		$wp_customize->add_control( 'l_slider_statement', array(
			'label'           => esc_html__( 'Slider Description', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Enter Description for slider.', 'inspirythemes-food-recipes' ),
			'type'            => 'textarea',
			'section'         => 'inspiry_home_slider_section',
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );

		$wp_customize->selective_refresh->add_partial(
			'l_slider_statement', array(
				'selector'        => '#slider .slogan',
				'render_callback' => function () use ( $wp_customize ) {
					return $wp_customize->get_setting( 'l_slider_statement' )->value();
				},
			)
		);

		/* Show/Hide Slider Title */
		$wp_customize->add_setting( 'recipe_post_select', array(
			'type'              => 'option',
			'default'           => 'off',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'recipe_post_select', array(
			'label'           => esc_html__( 'Do you want to add post support in slider', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Please select YES if you want to add support in Left Image Slider.', 'inspirythemes-food-recipes' ),
			'type'            => 'radio',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => array(
				'on'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'off' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );

		/* Show/Hide Slider Title */
		$wp_customize->add_setting( 'left_image_on_off', array(
			'type'              => 'option',
			'default'           => 'off',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'left_image_on_off', array(
			'label'           => esc_html__( 'Recipes or posts in left Image Slider based on latest/Random or selected', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'This filed contain two option. If you want to display latest recipes or post then select ON. If you want to display selected recipes or posts then choose OFF.', 'inspirythemes-food-recipes' ),
			'type'            => 'radio',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => array(
				'on'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'off' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );

		$wp_customize->add_setting( 'random_latest_select_lis', array(
			'type'              => 'option',
			'default'           => 'off',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'random_latest_select_lis', array(
			'label'           => esc_html__( 'Select latest/Random', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Please select Latest or Random and then enter the number(digit) of recipes/posts which you want to show in left image slider', 'inspirythemes-food-recipes' ),
			'type'            => 'radio',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => array(
				'latest' => esc_html__( 'Latest', 'inspirythemes-food-recipes' ),
				'random' => esc_html__( 'Random', 'inspirythemes-food-recipes' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'on' === $wp_customize->get_setting( 'left_image_on_off' )->value();
			},
		) );

		$wp_customize->add_setting( 'left_image_slide_numbers', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => 'off',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'left_image_slide_numbers', array(
			'label'           => esc_html__( 'Latest Recipes or Posts', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Enter the number of recipes or posts which you want to show in left image slider.', 'inspirythemes-food-recipes' ),
			'type'            => 'number',
			'section'         => 'inspiry_home_slider_section',
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'on' === $wp_customize->get_setting( 'left_image_on_off' )->value();
			},
		) );

		if( class_exists( 'Customizer_Repeater' ) ) {

			$wp_customize->add_setting( 'right_info_slider', array(
				'type'              => 'option',
				'transport'         => 'postMessage',
				'sanitize_callback' => 'customizer_repeater_sanitize',
			) );
			$wp_customize->add_control( new Customizer_Repeater( $wp_customize, 'right_info_slider', array(
				'label'                                 => esc_html__( 'Post or Recipes IDs for Left Image Slider', 'inspirythemes-food-recipes' ),
				'section'                               => 'inspiry_home_slider_section',
				'customizer_repeater_image_control'     => false,
				'customizer_repeater_icon_control'      => false,
				'customizer_repeater_title_control'     => true,
				'customizer_repeater_subtitle_control'  => false,
				'customizer_repeater_text_control'      => false,
				'customizer_repeater_link_control'      => false,
				'customizer_repeater_shortcode_control' => false,
				'customizer_repeater_repeater_control'  => false,
				'active_callback'                       => function () use ( $wp_customize ) {
					return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value() && 'off' === $wp_customize->get_setting( 'left_image_on_off' )->value();
				},
			) ) );
		}
		/* Show/Hide Slider Title */
		$wp_customize->add_setting( 'top_recipe_args', array(
			'type'              => 'option',
			'default'           => 'high_rating',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'top_recipe_args', array(
			'label'           => esc_html__( 'Most Rated Recipes', 'inspirythemes-food-recipes' ),
			'description'     => esc_html__( 'Please choose the following options to show the recipe in top right area of Slider. Please keep in mind you have to enable rating option first. For this navigate to Customizing > Recipe Single and find Show Rating for Recipe post.', 'inspirythemes-food-recipes' ),
			'type'            => 'radio',
			'section'         => 'inspiry_home_slider_section',
			'choices'         => array(
				'high_rating' => esc_html__( 'High In Rating', 'inspirythemes-food-recipes' ),
				'most_rated'  => esc_html__( 'Most Rated', 'inspirythemes-food-recipes' ),
			),
			'active_callback' => function () use ( $wp_customize ) {
				return 'Left Image Slider' === $wp_customize->get_setting( 'slider_type' )->value();
			},
		) );
	}

	add_action( 'customize_register', 'inspiry_home_lis_customizer' );
endif;

if ( ! function_exists( 'inspiry_home_lis_defaults' ) ) :
	/**
	 * Set default values for home_lis settings
	 *
	 * @param WP_Customize_Manager $wp_customize
	 */
	function inspiry_home_lis_defaults( WP_Customize_Manager $wp_customize ) {
		$homepage_settings_ids = array(
			'l_slider_title',
			'l_slider_title_on_off',
			'l_slider_title_typography-font-color',
			'l_slider_statement',
			'recipe_post_select',
			'left_image_on_off',
			'right_info_slider',
			'random_latest_select_lis',
			'left_image_slide_numbers',
			'top_recipe_args',
		);
		inspiry_initialize_defaults( $wp_customize, $homepage_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_home_lis_defaults' );
endif;
