<?php
/**
 * Customizer settings for Homepage Whats Hot
 *
 * @package FR
 */

if ( ! function_exists( 'inspiry_home_whats_hot_customizer' ) ) :
	function inspiry_home_whats_hot_customizer( WP_Customize_Manager $wp_customize ) {

		/**
		 * Home Whats Hot Section
		 */
		$wp_customize->add_section( 'inspiry_home_whats_hot_section', array(
			'title' => esc_html__( 'Whats Hot', 'inspirythemes-food-recipes' ),
			'panel' => 'inspiry_home_panel',
		) );

		/* Show/Hide Whats Hot */
		$wp_customize->add_setting( 'whats_hot_on_off', array(
			'type'              => 'option',
			'default'           => 'on',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'whats_hot_on_off', array(
			'label'   => esc_html__( 'Do you want to show whats hot.', 'inspirythemes-food-recipes' ),
			'type'    => 'radio',
			'section' => 'inspiry_home_whats_hot_section',
			'choices' => array(
				'on'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'off' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
		) );

		/* Selected OR recent recipes */
		$wp_customize->add_setting( 'whats_hot_posts_type', array(
			'type'              => 'option',
			'default'           => 'selected',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'whats_hot_posts_type', array(
			'label'   => esc_html__( 'Selected recipes or most recent ones?', 'inspirythemes-food-recipes' ),
			'type'    => 'radio',
			'section' => 'inspiry_home_whats_hot_section',
			'choices' => array(
				'selected'  => esc_html__( 'Selected', 'inspirythemes-food-recipes' ),
				'recent' => esc_html__( 'Recent', 'inspirythemes-food-recipes' ),
			),
		) );

		if( class_exists( 'Customizer_Repeater' ) ) {

			$wp_customize->add_setting( 'whats_hot_list_item', array(
				'sanitize_callback' => 'customizer_repeater_sanitize',
				'type'              => 'option',
			) );
			$wp_customize->add_control( new Customizer_Repeater( $wp_customize, 'whats_hot_list_item', array(
				'label'                                 => esc_html__( 'Whats Hot Recipes /Posts List', 'inspirythemes-food-recipes' ),
				'description'                           => esc_html__( 'The List Item option type allows you to choose recipes for Whats Hot in homepage', 'inspirythemes-food-recipes' ),
				'section'                               => 'inspiry_home_whats_hot_section',
				'customizer_repeater_image_control'     => false,
				'customizer_repeater_icon_control'      => false,
				'customizer_repeater_title_control'     => true,
				'customizer_repeater_subtitle_control'  => false,
				'customizer_repeater_text_control'      => false,
				'customizer_repeater_link_control'      => false,
				'customizer_repeater_shortcode_control' => false,
				'customizer_repeater_repeater_control'  => false,
			) ) );

		}

		// Number of recent recipes.
		$wp_customize->add_setting( 'home_recent_recipe', array(
			'type'              => 'option',
			'default'           => '4',
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'home_recent_recipe', array(
			'label'       => esc_html__( 'Home Recent Recipes Count', 'inspirythemes-food-recipes' ),
			'description' => esc_html__( 'In case you have selected "Recent" option for what\'s hot recipes, you can select the count.', 'inspirythemes-food-recipes' ),
			'type'        => 'number',
			'section'     => 'inspiry_home_whats_hot_section',
		) );

	}

	add_action( 'customize_register', 'inspiry_home_whats_hot_customizer' );
endif;

if ( ! function_exists( 'inspiry_home_whats_hot_defaults' ) ) :
	/**
	 * Set default values for home_whats_hot settings
	 *
	 * @param WP_Customize_Manager $wp_customize
	 */
	function inspiry_home_whats_hot_defaults( WP_Customize_Manager $wp_customize ) {
		$homepage_settings_ids = array(
			'whats_hot_on_off',
			'whats_hot_list_item',
		);
		inspiry_initialize_defaults( $wp_customize, $homepage_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_home_whats_hot_defaults' );
endif;
