<?php
/**
 * Styles Settings
 *
 * @package RH
 * @since 1.0.0
 */

if ( ! function_exists( 'inspiry_styles_customizer' ) ) :

	/**
	 * Customizer Section: Styles
	 *
	 * @param  WP_Customize_Manager $wp_customize - Instance of WP_Customize_Manager.
	 *
	 * @since  1.0.0
	 */
	function inspiry_styles_customizer( WP_Customize_Manager $wp_customize ) {

		/**
		 * Styles Panel
		 */
		$wp_customize->add_section( 'inspiry_styles_section', array(
			'title'    => esc_html__( 'Styles', 'inspirythemes-food-recipes' ),
			'priority' => 41,
		) );

		$wp_customize->add_setting( 'recipe_theme_framework', array(
			'type'              => 'option',
			'default'           => 'show',
			'sanitize_callback' => 'theme_sanitize_radio',
		) );
		$wp_customize->add_control( 'recipe_theme_framework', array(
			'label'       => esc_html__( 'Do you want to use bootstrap grid system.', 'inspirythemes-food-recipes' ),
			'description' => esc_html__( 'If you are using bootstrap grid then your design will be based on 1170px width. No other changes will happens, just your design will look wider.', 'inspirythemes-food-recipes' ),
			'type'        => 'radio',
			'section'     => 'inspiry_styles_section',
			'choices'     => array(
				'show' => esc_html__( 'Bootstrap', 'inspirythemes-food-recipes' ),
				'hide' => esc_html__( 'Classic', 'inspirythemes-food-recipes' ),
			),
		) );


		$wp_customize->add_setting( 'skin_set', array(
			'type'              => 'option',
			'default'           => 'skin_default',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'skin_set', array(
			'label'       => esc_html__( 'Color Skins', 'inspirythemes-food-recipes' ),
			'description' => esc_html__( 'Select color skin from the given options.', 'inspirythemes-food-recipes' ),
			'type'        => 'select',
			'section'     => 'inspiry_styles_section',
			'choices'     => array(
				'skin_default' => esc_html__( 'Default', 'inspirythemes-food-recipes' ),
				'skin_blue'    => esc_html__( 'Blue', 'inspirythemes-food-recipes' ),
				'skin_orange'  => esc_html__( 'Orange', 'inspirythemes-food-recipes' ),
				'skin_red'     => esc_html__( 'Red', 'inspirythemes-food-recipes' ),
			),
		) );

		$wp_customize->add_setting( 'recipe_styles-font-color', array(
			'type'              => 'option',
			'default'           => '#909090',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( 'recipe_styles-font-color', array(
			'label'   => esc_html__( 'Recipe Color', 'inspirythemes-food-recipes' ),
			'type'    => 'color',
			'section' => 'inspiry_styles_section',
		) );

		$wp_customize->add_setting( 'recipe_styles-font-family', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'recipe_styles-font-family', array(
			'label'   => esc_html__( 'Recipe Google Font Family', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_styles_section',
			'choices' => inspiry_get_google_fonts_list(),
		) );

		$wp_customize->add_setting( 'recipe_styles-font-size', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'recipe_styles-font-size', array(
			'label'   => esc_html__( 'Recipe Font Size', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_styles_section',
			'choices' => font_sizes_array( 'Font Size' ),
		) );

		$wp_customize->add_setting( 'recipe_styles-font-weight', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'recipe_styles-font-weight', array(
			'label'   => esc_html__( 'Recipe Google Font Weight', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_styles_section',
			'choices' => array(
				''        => esc_html__( 'Font Weight', 'inspirythemes-food-recipes' ),
				'normal'  => 'normal',
				'bold'    => 'bold',
				'bolder'  => 'bolder',
				'lighter' => 'lighter',
				'100'     => '100',
				'200'     => '200',
				'300'     => '300',
				'400'     => '400',
				'500'     => '500',
				'600'     => '600',
				'700'     => '700',
				'800'     => '800',
				'900'     => '900',
				'inherit' => 'inherit',
			),
		) );

		$wp_customize->add_setting( 'recipe_styles-line-height', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'recipe_styles-line-height', array(
			'label'   => esc_html__( 'Recipe Google Line Height', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_styles_section',
			'choices' => font_sizes_array( 'Line Height' ),
		) );


		$wp_customize->add_setting( 'heading_styles-font-color', array(
			'type'              => 'option',
			'default'           => '#5e6063',
			'sanitize_callback' => 'sanitize_hex_color',
		) );
		$wp_customize->add_control( 'heading_styles-font-color', array(
			'label'   => esc_html__( 'Heading Color', 'inspirythemes-food-recipes' ),
			'type'    => 'color',
			'section' => 'inspiry_styles_section',
		) );

		$wp_customize->add_setting( 'heading_styles-font-family', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'heading_styles-font-family', array(
			'label'   => esc_html__( 'Heading Font Family', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_styles_section',
			'choices' => inspiry_get_google_fonts_list(),
		) );

		$wp_customize->add_setting( 'heading_styles-font-weight', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'heading_styles-font-weight', array(
			'label'   => esc_html__( 'Heading Font Weight', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_styles_section',
			'choices' => array(
				''        => esc_html__( 'Font Weight', 'inspirythemes-food-recipes' ),
				'normal'  => 'normal',
				'bold'    => 'bold',
				'bolder'  => 'bolder',
				'lighter' => 'lighter',
				'100'     => '100',
				'200'     => '200',
				'300'     => '300',
				'400'     => '400',
				'500'     => '500',
				'600'     => '600',
				'700'     => '700',
				'800'     => '800',
				'900'     => '900',
				'inherit' => 'inherit',
			),
		) );

		$wp_customize->add_setting( 'heading_styles-line-height', array(
			'type'              => 'option',
			'default'           => '',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'heading_styles-line-height', array(
			'label'   => esc_html__( 'Heading Line Height', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_styles_section',
			'choices' => font_sizes_array( 'Line Height' ),
		) );

	}

	add_action( 'customize_register', 'inspiry_styles_customizer' );
endif;


if ( ! function_exists( 'inspiry_theme_styles_defaults' ) ) :
	/**
	 * Set default values for theme_styles settings
	 *
	 * @param WP_Customize_Manager $wp_customize
	 */
	function inspiry_theme_styles_defaults( WP_Customize_Manager $wp_customize ) {
		$homepage_settings_ids = array(
			'recipe_theme_framework',
			'skin_set',
			'recipe_styles-font-color',
			'heading_styles-font-color',
		);
		inspiry_initialize_defaults( $wp_customize, $homepage_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_theme_styles_defaults' );
endif;
