<?php
/**
 * Customizer settings for Blog
 *
 * @package FR
 */

if ( ! function_exists( 'inspiry_user_listing_customizer' ) ) :
	function inspiry_user_listing_customizer( WP_Customize_Manager $wp_customize ) {


		$wp_customize->add_section( 'inspiry_user_listing_section', array(
			'title'    => esc_html__( 'User Listing', 'inspirythemes-food-recipes' ),
			'priority' => 37,
		) );

		$wp_customize->add_setting( 'listing_head_chef_id', array(
			'type'              => 'option',
			'transport'         => 'postMessage',
			'default'           => '1',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'listing_head_chef_id', array(
			'label'       => esc_html__( 'Provide head chef or team manager id for users listing', 'inspirythemes-food-recipes' ),
			'description' => esc_html__( 'Provide ID for head chef or team manager for users listing template. It will appear individually before users listings and will be skipped from listing.', 'inspirythemes-food-recipes' ),
			'type'        => 'number',
			'section'     => 'inspiry_user_listing_section',
		) );

		$wp_customize->add_setting( 'skip_subscriber_from_listing', array(
			'type'              => 'option',
			'default'           => 'false',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'skip_subscriber_from_listing', array(
			'label'   => esc_html__( 'Do you want to include subscribers in users listing.', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_user_listing_section',
			'choices' => array(
				'true'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'false' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
		) );

		$wp_customize->add_setting( 'skip_users_with_no_post', array(
			'type'              => 'option',
			'default'           => 'false',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'skip_users_with_no_post', array(
			'label'   => esc_html__( 'Do you want to include users with no posts and recipes.', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_user_listing_section',
			'choices' => array(
				'true'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'false' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
		) );

		$wp_customize->add_setting( 'author_page_layout', array(
			'type'              => 'option',
			'default'           => 'false',
			'sanitize_callback' => 'theme_sanitize_select',
		) );
		$wp_customize->add_control( 'author_page_layout', array(
			'label'   => esc_html__( 'Do you want to Show full width layout Author page.', 'inspirythemes-food-recipes' ),
			'type'    => 'select',
			'section' => 'inspiry_user_listing_section',
			'choices' => array(
				'true'  => esc_html__( 'Yes', 'inspirythemes-food-recipes' ),
				'false' => esc_html__( 'No', 'inspirythemes-food-recipes' ),
			),
		) );


	}

	add_action( 'customize_register', 'inspiry_user_listing_customizer' );
endif;

if ( ! function_exists( 'inspiry_user_listing_defaults' ) ) :
	/**
	 * Set default values for user_listing settings
	 *
	 * @param WP_Customize_Manager $wp_customize
	 */
	function inspiry_user_listing_defaults( WP_Customize_Manager $wp_customize ) {
		$homepage_settings_ids = array(
			'listing_head_chef_id',
			'skip_subscriber_from_listing',
			'skip_users_with_no_post',
			'author_page_layout',
		);
		inspiry_initialize_defaults( $wp_customize, $homepage_settings_ids );
	}

	add_action( 'customize_save_after', 'inspiry_user_listing_defaults' );
endif;
