<?php

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function inspiry_theme_setup() {

	// Text domain loading for translation fix.
	load_theme_textdomain( 'inspirythemes-food-recipes', get_template_directory() . '/languages' );

	// Title Support.
	add_theme_support( 'title-tag' );

	// Custom Logo.
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 60,
			'width'       => 165,
			'flex-height' => true,
			'flex-width'  => true,
		)
	);

	// Custom Background Support.
	$header_img_args = array(
		'flex-width'    => true,
		'width'         => 463,
		'height'        => 117,
		'default-image' => get_template_directory_uri() . '/images/header-image.png',
	);
	add_theme_support( 'custom-header', $header_img_args );

	// Automatic Feed Links Support.
	add_theme_support( 'automatic-feed-links' );

	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );

	// Enqueue editor styles.
	add_editor_style( '/css/custom-editor-style.css' );

	// Gutenberg Align WIde Support.
	add_theme_support( 'align-wide' );

	// Gutenberg Editor Styles Support.
	add_theme_support( 'editor-styles' );

	// Responsive Embeds support
	add_theme_support( 'responsive-embeds' );

	// Gutenberg Editor Color Palette Support.
	add_theme_support(
		'editor-color-palette',
		array(
			array(
				'name'  => esc_html__( 'Paragraph Color Storm Gray', 'inspirythemes-food-recipes' ),
				'slug'  => 'paragraph-color-storm-gray',
				'color' => '#909090',
			),
			array(
				'name'  => esc_html__( 'Heading and Link Color Mariner', 'inspirythemes-food-recipes' ),
				'slug'  => 'heading-link-color-mariner',
				'color' => '#6f716b',
			),
			array(
				'name'  => esc_html__( 'Link Hover Ebony Green', 'inspirythemes-food-recipes' ),
				'slug'  => 'link-hover-ebony-green',
				'color' => '#548f04',
			),
		)
	);

	// Set the default content width.
	$GLOBALS['content_width'] = 760;

	// Adding Default Thumbnail Sizes.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 150, 150 );                              // Default post thumbnail dimensions.
	add_image_size( 'thumbnail-blog', 582, 9999, false ); // for blog pages.
	add_image_size( 'recipe-listing', 250, 212, true ); // For recipe listing page.
	add_image_size( 'portfolio-thumb', 220, 140, true ); // for the portfolio template.
	add_image_size( 'portfolio-main', 940, '', false ); // for the single portfolio page.
	add_image_size( 'full-size', '', '', false );
	add_image_size( 'sidebar-tabs', 63, 53, true );
	add_image_size( 'recipe-4column-thumb', 222, 144, true );
	add_image_size( 'single-carousel-thumb', 132, 104, true );
	add_image_size( 'li-slider-thumb', 515, 262, true );
	add_image_size( 'bs-slider-thumb', 903, 386, true );
	add_image_size( 'weekly-special-thumb', 122, 132, true );
	add_image_size( 'most-rated-thumb', 63, 53, true );
	add_image_size( 'recipe-slider-widget', 400, 250, true );
	add_image_size( 'weekly-for-res', 251, 132, true );
	add_image_size( 'user-listing-thumb', 250, 212, true );
	add_image_size( 'recipe-author-thumb', 84, 78, true );

	// Creating Menu Places.
	register_nav_menus(
		array(
			'main-menu'   => esc_html__( 'Main Menu', 'inspirythemes-food-recipes' ),
			'social-menu' => esc_html__( 'Social Menu', 'inspirythemes-food-recipes' ),
		)
	);
}

add_action( 'after_setup_theme', 'inspiry_theme_setup' );

if( ! function_exists( 'inspiry_content_width' ) ) {
	/**
	 * Set the content width in pixels, based on the theme's design and stylesheet.
	 *
	 * Priority 0 to make it available to lower priority callbacks.
	 *
	 * @global int $content_width
	 */
	function inspiry_content_width() {

		$content_width = $GLOBALS[ 'content_width' ];

		// Get layout.
		if ( is_page_template( 'template-home.php' ) ) {
			$content_width = 1170;
		}

		$GLOBALS[ 'content_width' ] = apply_filters( 'inspiry_content_width', $content_width );
	}

	add_action( 'template_redirect', 'inspiry_content_width', 0 );
}

if( ! function_exists( 'inspiry_post_classes' ) ) {
	/**
	 * @param $classes
	 *
	 * @return mixed
	 */
	function inspiry_post_classes( $classes ) {

		global $post;
		$classes[] = 'clearfix';

		if( 'recipe' == get_post_type( $post->ID ) ){
			$classes[] = 'recipe-listing-item';
		}

		return $classes;
	}

	add_filter( 'post_class', 'inspiry_post_classes', 10, 3 );
}

// Function to Register Sidebars.
require get_template_directory() . '/functions/widgetized-areas.php';


/**
 * Widget titles styling.
 */

add_filter( 'widget_title', 'recipe_widget_title' );

function recipe_widget_title( $title ) {

	// Get the First Word.
	$first_word = strtok( $title, ' ' );

	if ( str_word_count( $title ) > 1 ) {
		// Replace the first word with own string.
		$title = str_replace( $first_word, '<span>' . $first_word . '</span>', $title );
	}

	return $title;
}
// Framework Path.
define( 'INSPIRY_FRAMEWORK', get_template_directory() . '/customizer/' );

/**
 * Add Demo Import File
 */
require get_template_directory() . '/inc/demo/demo.php';

/**
 * For Loading Required CSS Files
 */
require get_template_directory() . '/functions/styles.php';

/**
 * Other Functions
 */
require get_template_directory() . '/functions/other-functions.php';

/**
 * For Loading Required JS and Files
 */
require get_template_directory() . '/functions/scripts.php';

/**
 * Google Fonts
 */
require_once INSPIRY_FRAMEWORK . 'google-fonts/google-fonts.php';


/**
 * Customizer
 */

require_once INSPIRY_FRAMEWORK . 'customizer.php';



/**
 * TGM Class based plugin activation functionality
 */
require_once( trailingslashit( get_template_directory() ) . '/inc/tgm/required-plugins.php' );


/**
 * Convert number of Minutes to Hours
 */
if ( ! function_exists( 'convert_to_hours' ) ) {
	function convert_to_hours( $time ) {
		$time = intval( $time );

		if ( $time > 60 ) {
			$hours   = floor( $time / 60 );
			$minutes = $time - ( $hours * 60 );
			if ( 0 === $minutes ) {
				$minutes = '0';
			}
			if ( $minutes < 10 ) {
				$minutes = '0' . $minutes;
			}

			return "$hours:$minutes " . esc_html__( 'h', 'inspirythemes-food-recipes' );
		}

		return $time . esc_html__( 'm', 'inspirythemes-food-recipes' );
	}
}


if ( ! function_exists( 'atom_search_groupby' ) ) {
	function atom_search_groupby( $groupby ) {
		global $wpdb;

		// we need to group on post ID.
		$groupby_id = "{$wpdb->posts}.ID";
		if ( ! is_search() || strpos( $groupby, $groupby_id ) !== false ) {
			return $groupby;
		}

		// Group by was empty, use ours.
		if ( ! strlen( trim( $groupby ) ) ) {
			return $groupby_id;
		}

		// Wasn't empty, append ours.
		return $groupby . ', ' . $groupby_id;
	}

	add_filter( 'posts_groupby', 'atom_search_groupby' );
}

/**
 * Remove pages from search results
 */
function inspiry_search_post_types($query) {

	if ( $query->is_search && ! is_admin() ) {
		$query->set('post_type', array( 'post', 'recipe' ) );
	}

	return $query;
}
add_filter('pre_get_posts','inspiry_search_post_types');


/**
 * Author page post type combined with post pagi fix.
 */
if ( ! function_exists( 'author_page_404_fix' ) ) {
	function author_page_404_fix( $query ) {
		if ( $query->is_main_query() && ( is_author() || is_tag() || is_category() ) && ! is_404() ) {
			$my_post_type = get_query_var( 'post_type' );
			if ( empty( $my_post_type ) ) {
				$post_types = array( 'post', 'recipe' );
				$query->set( 'post_type', $post_types );
			}
		}
	}

	add_action( 'pre_get_posts', 'author_page_404_fix' );
}


/**
 * Skin Related Code For Demo
 */
if ( isset( $_GET['skin'] ) ) {
	$theme_skin = $_GET['skin'];
	setcookie( 'skin', $theme_skin, time() + 600 );
}


/**
 * Get image id from src function
 */
if ( ! function_exists( 'get_attachment_id_from_src' ) ) {
	function get_attachment_id_from_src( $image_src ) {

		global $wpdb;
		$query = $wpdb->prepare( "SELECT ID FROM {$wpdb->posts} WHERE guid=%s", $image_src );
		$id    = $wpdb->get_var( $query );

		return $id;

	}
}


/**
 * Count user recipes
 */
if ( ! function_exists( 'count_user_posts_by_type' ) ) {
	function count_user_posts_by_type( $userid, $post_type = 'recipe' ) {
		global $wpdb;
		if( ! empty( $userid ) && ! empty( $post_type ) ){
			$query = $wpdb->prepare("
						SELECT COUNT(*)
	                    FROM {$wpdb->posts}
	                    WHERE post_type = %s
						AND post_status = 'publish'
						AND post_author = %s
						", $post_type,  $userid );

			$count = $wpdb->get_var( $query );

			return apply_filters( 'get_usernumposts', $count, $userid );
		}

		return false;

	}
}


/**
 * Adding ID column for user listings.
 */
if ( ! function_exists( 'adding_post_id_column' ) ) {

	add_filter( 'manage_posts_columns', 'adding_post_id_column' );

	function adding_post_id_column( $defaults ) {
		$defaults['post_id'] = 'Post ID';

		return $defaults;
	}
}


// Show The Post ID.
if ( ! function_exists( 'adding_post_id' ) ) {

	add_action( 'manage_posts_custom_column', 'adding_post_id', 10, 2 );

	function adding_post_id( $column_name ) {
		if ( 'post_id' === $column_name ) {
			$get_post_id = get_the_ID();
			if ( $get_post_id ) {
				echo esc_html( $get_post_id );
			}
		}
	}
}



add_action( 'admin_init', 'load_admin_user_script' );
function load_admin_user_script() {
	global $pagenow;

	if ( is_admin() && ( 'profile.php' === $pagenow || 'user-edit.php' === $pagenow ) ) {
		wp_enqueue_media();
		wp_enqueue_script( 'my_custom_script', get_template_directory_uri() . '/js/profile-admin.js', array(), '1.0.0', true );
	}
}


if( !function_exists( 'inspiry_image_upload' ) ) {
	/**
	 * Ajax image upload for recipe submit and update
	 */
	function inspiry_image_upload( ) {

		// Verify Nonce
		$nonce = $_REQUEST['nonce'];
		if ( ! wp_verify_nonce( $nonce, 'inspiry_allow_upload' ) ) {
			$ajax_response = array(
				'success' => false ,
				'reason' => esc_html__('Security check failed!', 'inspirythemes-food-recipes')
			);
			echo json_encode( $ajax_response );
			die;
		}

		$submitted_file = $_FILES['inspiry_upload_file'];
		$uploaded_image = wp_handle_upload( $submitted_file, array( 'test_form' => false ) );   //Handle PHP uploads in WordPress, sanitizing file names, checking extensions for mime type, and moving the file to the appropriate directory within the uploads directory.

		if ( isset( $uploaded_image['file'] ) ) {
			$file_name          =   basename( $submitted_file['name'] );
			$file_type          =   wp_check_filetype( $uploaded_image['file'] );   //Retrieve the file type from the file name.

			// Prepare an array of post data for the attachment.
			$attachment_details = array(
				'guid'           => $uploaded_image['url'],
				'post_mime_type' => $file_type['type'],
				'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $file_name ) ),
				'post_content'   => '',
				'post_status'    => 'inherit'
			);

			$attach_id      =   wp_insert_attachment( $attachment_details, $uploaded_image['file'] );       // This function inserts an attachment into the media library
			$attach_data    =   wp_generate_attachment_metadata( $attach_id, $uploaded_image['file'] );     // This function generates metadata for an image attachment. It also creates a thumbnail and other intermediate sizes of the image attachment based on the sizes defined
			wp_update_attachment_metadata( $attach_id, $attach_data );                                      // Update metadata for an attachment.

			$thumbnail_url = inspiry_get_thumbnail_url( $attach_data ); // return escaped url

			$ajax_response = array(
				'success'   => true,
				'url' => $thumbnail_url,
				'attachment_id'    => $attach_id
			);

			echo json_encode( $ajax_response );
			die;

		} else {
			$ajax_response = array(
				'success' => false,
				'reason' => esc_html__('Image upload failed!', 'inspirythemes-food-recipes')
			);
			echo json_encode( $ajax_response );
			die;
		}

	}
	add_action( 'wp_ajax_ajax_img_upload', 'inspiry_image_upload' );    // only for logged in user
}



if( !function_exists( 'inspiry_get_thumbnail_url' ) ){
	/**
	 * Get thumbnail url based on attachment data
	 *
	 * @param $attach_data
	 * @return string
	 */
	function inspiry_get_thumbnail_url( $attach_data ){
		$upload_dir         =   wp_upload_dir();
		$image_path_array   =   explode( '/', $attach_data['file'] );
		$image_path_array   =   array_slice( $image_path_array, 0, count( $image_path_array ) - 1 );
		$image_path         =   implode( '/', $image_path_array );
		$thumbnail_name     =   $attach_data['sizes']['thumbnail']['file'];
		return esc_url( $upload_dir['baseurl'] . '/' . $image_path . '/' . $thumbnail_name ) ;
	}
}



if ( !function_exists( 'inspiry_remove_gallery_image' ) ) {
	/**
	 * recipe Submit Form - Gallery Image Removal
	 */
	function inspiry_remove_gallery_image() {

		// Verify Nonce
		$nonce = $_POST['nonce'];
		if ( ! wp_verify_nonce ( $nonce, 'inspiry_allow_upload' ) ) {
			$ajax_response = array(
				'post_meta_removed' => false ,
				'attachment_removed' => false ,
				'reason' => esc_html__('Security check failed!', 'inspirythemes-food-recipes')
			);
			echo json_encode( $ajax_response );
			die;
		}

		$post_meta_removed = false;
		$attachment_removed = false;

		if( isset( $_POST['recipe_id'] ) && isset( $_POST['attachment_id'] ) ) {
			$recipe_id = intval( $_POST['recipe_id'] );
			$attachment_id = intval( $_POST['attachment_id'] );
			if ( $recipe_id > 0 && $attachment_id > 0 ) {
				$post_meta_removed = delete_post_meta( $recipe_id, 'maejstic_recipe_images', $attachment_id );
				$attachment_removed = wp_delete_attachment ( $attachment_id );
			} else if ( $attachment_id > 0 ) {
				if( false === wp_delete_attachment ( $attachment_id ) ){
					$attachment_removed = false;
				} else {
					$attachment_removed = true;
				}
			}
		}

		$ajax_response = array(
			'post_meta_removed' => $post_meta_removed,
			'attachment_removed' => $attachment_removed,
		);

		echo json_encode( $ajax_response );
		die;

	}
	add_action( 'wp_ajax_remove_gallery_image', 'inspiry_remove_gallery_image' );
}


/**
 * User Ajax login Function
 */
if ( ! function_exists( 'ajax_login' ) ) {

	// Enable the user with no privileges to run ajax_login() in AJAX.
	add_action( 'wp_ajax_nopriv_ajaxlogin', 'ajax_login' );

	function ajax_login() {

		// First check the nonce, if it fails the function will break.
		check_ajax_referer( 'ajax-login-nonce', 'security' );

		// Nonce is checked, get the POST data and sign user on.
		$info                  = array();
		$info['user_login']    = sanitize_text_field( $_POST['username'] );
		$info['user_password'] = sanitize_text_field( $_POST['password'] );
		$info['remember']      = true;

		$user_signon = wp_signon( $info, false );
		if ( is_wp_error( $user_signon ) ) {
			echo json_encode( array(
				'loggedin' => false,
				'message'  => esc_html__( 'Wrong username or password.', 'inspirythemes-food-recipes' )
			) );
		} else {
			echo json_encode( array(
				'loggedin' => true,
				'message'  => esc_html__( 'Login successful, redirecting...', 'inspirythemes-food-recipes' )
			) );
		}

		die();
	}
}



/**
 * Pagination Fix
 */
if ( ! function_exists( 'inspiry_pagination_fix' ) ) :
	function inspiry_pagination_fix( $redirect_url ) {
		if ( is_front_page() ) {
			$redirect_url = false;
		}

		return $redirect_url;
	}

	add_filter( 'redirect_canonical', 'inspiry_pagination_fix' );
endif;


/**
 * Google map api function
 */
if ( ! function_exists( 'inspiry_google_maps_api_key' ) ) :
	/**
	 * This function adds API key ( if provided in settings ) to google maps arguments.
	 *
	 * @param $google_map_arguments
	 *
	 * @return array $google_map_arguments
	 */
	function inspiry_google_maps_api_key( $google_map_arguments ) {
		/* Get Google Maps API Key if available */
		$google_maps_api_key = get_option( 'inspiry_google_maps_api_key' );

		if ( ! empty( $google_maps_api_key ) ) {
			$google_map_arguments['key'] = urlencode( $google_maps_api_key );
		}

		return $google_map_arguments;
	}

	add_filter( 'inspiry_google_map_arguments', 'inspiry_google_maps_api_key' );
endif;


// Define the get_the_archive_title callback.
function inspiry_get_the_archive_title( $title ) {

	$refactor = explode( ':', $title );
	if ( count( $refactor ) >= 2 ) {
		return $refactor[0] . ': <span>' . $refactor[1] . '</span>';
	}

	return $title;
}

// Add the filter.
add_filter( 'get_the_archive_title', 'inspiry_get_the_archive_title' );

function font_sizes_array( $input ) {
	$fonts[''] = esc_html( $input );
	for ( $i = 0; $i <= 150; $i ++ ) {
		$fonts[ $i . 'px' ] = $i . 'px';
	}

	return $fonts;
}

function customizer_array( $array ) {
	foreach ( $array as $k => $v ) {

		if ( isset( $array[ $k ] ['id'] ) && ! empty( $array[ $k ] ['id'] ) ) {
			$array[ $k ] ['title'] = $array[ $k ] ['id'];
			unset( $array[ $k ]['id'] );
		}

		if ( isset( $array[ $k ] ['image'] ) && ! empty( $array[ $k ] ['image'] ) ) {
			$array[ $k ] ['image_url'] = $array[ $k ] ['image'];
			unset( $array[ $k ]['image'] );
		}
		if ( isset( $array[ $k ] ['nivo_image'] ) && ! empty( $array[ $k ] ['nivo_image'] ) ) {
			$array[ $k ] ['image_url'] = $array[ $k ] ['nivo_image'];
			unset( $array[ $k ]['nivo_image'] );
		}

		if ( isset( $array[ $k ] ['whats_hot_recipe'] ) && ! empty( $array[ $k ] ['whats_hot_recipe'] ) ) {
			$array[ $k ] ['title'] = $array[ $k ] ['whats_hot_recipe'];
			unset( $array[ $k ]['whats_hot_recipe'] );
		}

		if ( isset( $array[ $k ] ['whats_hot_post'] ) && ! empty( $array[ $k ] ['whats_hot_post'] ) ) {
			$array[ $k ] ['title'] = $array[ $k ] ['whats_hot_post'];
			unset( $array[ $k ]['whats_hot_post'] );
		}

	}

	return $array;
}

function sync_ot_to_customizer_once() {

	if ( ! get_option( 'sync_ot_to_customizer_once' ) && function_exists( 'ot_get_option' ) ) {

		$options = get_option( 'option_tree' );

		foreach ( $options as $key => $option ) {
			if ( ! is_array( $option ) ) {
				update_option( $key, $option );
			} else {
				update_option( $key, wp_json_encode( customizer_array( $option ) ) );
			}
		}

		$logo_id = get_attachment_id_from_src( ot_get_option( 'header_logo_image' ) );
		$fav_id  = get_attachment_id_from_src( ot_get_option( 'favicon' ) );

		if ( null !== $logo_id && ! empty( $logo_id ) ) {
			update_option( 'header_logo_image', $logo_id );
		}

		if ( null !== $fav_id && ! empty( $fav_id ) ) {
			update_option( 'favicon', $fav_id );
		}

		if ( is_array( $options['adv_search_page_checkbox'] ) && ! empty( $options['adv_search_page_checkbox'] ) ) {
			update_option( 'adv_search_page_checkbox', implode( ',', $options['adv_search_page_checkbox'] ) );
		}
		if ( is_array( $options['adv_search_fields_checkbox'] ) && ! empty( $options['adv_search_fields_checkbox'] ) ) {
			update_option( 'adv_search_fields_checkbox', implode( ',', $options['adv_search_fields_checkbox'] ) );
		}


		if ( is_array( $options['recipe_styles'] ) && ! empty( $options['recipe_styles'] ) ) {
			foreach ( $options['recipe_styles'] as $key => $value ) {
				update_option( 'recipe_styles-' . $key, $value );
			}
		} else {
			update_option( 'recipe_styles-font-color', '' );
			update_option( 'recipe_styles-font-size', '' );
			update_option( 'recipe_styles-font-weight', '' );
			update_option( 'recipe_styles-font-family', '' );
			update_option( 'recipe_styles-line-height', '' );
		}

		if ( is_array( $options['l_slider_title_typography'] ) && ! empty( $options['l_slider_title_typography'] ) ) {
			foreach ( $options['l_slider_title_typography'] as $key => $value ) {
				update_option( 'l_slider_title_typography-' . $key, $value );
			}
		} else {
			update_option( 'l_slider_title_typography-font-color', '' );
			update_option( 'l_slider_title_typography-font-size', '' );
			update_option( 'l_slider_title_typography-font-weight', '' );
			update_option( 'l_slider_title_typography-font-family', '' );
			update_option( 'l_slider_title_typography-line-height', '' );
		}

		if ( is_array( $options['heading_styles'] ) && ! empty( $options['heading_styles'] ) ) {
			foreach ( $options['heading_styles'] as $key => $value ) {
				update_option( 'heading_styles-' . $key, $value );
			}
		} else {
			update_option( 'heading_styles-font-color', '' );
			update_option( 'heading_styles-font-size', '' );
			update_option( 'heading_styles-font-weight', '' );
			update_option( 'heading_styles-font-family', '' );
			update_option( 'heading_styles-line-height', '' );
		}

		update_option( 'sync_ot_to_customizer_once', true );
		update_option( 'custom_css', 'quick_css_box' );
	}
}

add_action( 'admin_init', 'sync_ot_to_customizer_once', PHP_INT_MAX );

function sync_ot_to_customizer( $options ) {
	foreach ( $options as $key => $option ) {
		if ( ! is_array( $option ) ) {
			update_option( $key, $option );
		} else {
			update_option( $key, wp_json_encode( customizer_array( $option ) ) );
		}
	}

	$logo_id = get_attachment_id_from_src( ot_get_option( 'header_logo_image' ) );
	$fav_id  = get_attachment_id_from_src( ot_get_option( 'favicon' ) );

	if ( null !== $logo_id && ! empty( $logo_id ) ) {
		update_option( 'header_logo_image', $logo_id );
	}

	if ( null !== $fav_id && ! empty( $fav_id ) ) {
		update_option( 'favicon', $fav_id );
	}

	if ( is_array( $options['adv_search_page_checkbox'] ) && ! empty( $options['adv_search_page_checkbox'] ) ) {
		update_option( 'adv_search_page_checkbox', implode( ',', $options['adv_search_page_checkbox'] ) );
	}
	if ( is_array( $options['adv_search_fields_checkbox'] ) && ! empty( $options['adv_search_fields_checkbox'] ) ) {
		update_option( 'adv_search_fields_checkbox', implode( ',', $options['adv_search_fields_checkbox'] ) );
	}


	if ( is_array( $options['recipe_styles'] ) && ! empty( $options['recipe_styles'] ) ) {
		foreach ( $options['recipe_styles'] as $key => $value ) {
			update_option( 'recipe_styles-' . $key, $value );
		}
	} else {
		update_option( 'recipe_styles-font-color', '' );
		update_option( 'recipe_styles-font-size', '' );
		update_option( 'recipe_styles-font-weight', '' );
		update_option( 'recipe_styles-font-family', '' );
		update_option( 'recipe_styles-line-height', '' );
	}

	if ( is_array( $options['l_slider_title_typography'] ) && ! empty( $options['l_slider_title_typography'] ) ) {
		foreach ( $options['l_slider_title_typography'] as $key => $value ) {
			update_option( 'l_slider_title_typography-' . $key, $value );
		}
	} else {
		update_option( 'l_slider_title_typography-font-color', '' );
		update_option( 'l_slider_title_typography-font-size', '' );
		update_option( 'l_slider_title_typography-font-weight', '' );
		update_option( 'l_slider_title_typography-font-family', '' );
		update_option( 'l_slider_title_typography-line-height', '' );
	}

	if ( is_array( $options['heading_styles'] ) && ! empty( $options['heading_styles'] ) ) {
		foreach ( $options['heading_styles'] as $key => $value ) {
			update_option( 'heading_styles-' . $key, $value );
		}
	} else {
		update_option( 'heading_styles-font-color', '' );
		update_option( 'heading_styles-font-size', '' );
		update_option( 'heading_styles-font-weight', '' );
		update_option( 'heading_styles-font-family', '' );
		update_option( 'heading_styles-line-height', '' );
	}
	update_option( 'custom_css', 'quick_css_box' );
}

add_action( 'ot_after_theme_options_save', 'sync_ot_to_customizer', 1 );

function common_array_filter( $val ) {
	$val = trim( $val );

	return ( $val != '' && $val != 0 && $val != 'null' );
}

if ( !function_exists( 'inspiry_allowed_html_tags' ) ) {
	/**
	 * @return array Array of allowed html tags.
	 */
	function inspiry_allowed_html_tags() {

		$allowed_tags = array(
			'img' => array(
				'src' => array(),
				'class' => array(),
				'alt'   => array(),
				'style' => true
			),'a' => array(
				'class' => array(),
				'href' => array(),
				'title' => array()
			),
			'p' => array('style' => array(), 'class' => array()),
			'br' => array(),
			'em' => array(),
			'strong' => array('class' => array(), 'style' => array()),
			'span' => array('class' => array(), 'style' => array()),
			'svg' => array(
				'viewbox' => array(),
				'width' => array(),
				'height' => array(),
				'class'   => array(),
				'enable-background' => array(),
				'xmlns' => array(),
				'xmlns:xlink' => array(),
				'x' => array(),
				'y' => array(),
				'xml:space' => array(),
				'version' => array(),
			),
			'path' => array(
				'class' => array(),
				'd' => array()
			),
			'circle' => array(
				'class' => array(),
				'cx' => array(),
				'cy' => array(),
				'r' => array(),
			),
			'g' => array(
				'class' => array()
			),
			'i' => array(
				'class' => array()
			),
			'iframe' => array(
				'src'             => array(),
				'frameborder'     => array(),
				'allowfullscreen' => array(),
			)
		);

		return apply_filters( 'filter_allowed_html_tags', $allowed_tags );
	}
}