<?php /*
	* Theme scripts
    *
 */

if ( ! function_exists( 'load_theme_scripts' ) ) {
	/**
	 * For Loading Required JS and Files
	 */
	function load_theme_scripts() {

		if ( ! is_admin() ) {

			$jscript_url = get_template_directory_uri() . '/js/';

			$common_script_strings = array(
				'meanMenuTitle' => esc_html__( 'Go to...', 'inspirythemes-food-recipes' )
			);

			$map_coordinates = array(
				'map_lati'      =>  get_option( 'map_latitude' ),
				'map_longi'      =>  get_option( 'map_longitude' ),
				'map_zoom'      =>  get_option( 'map_zoom_level' )
			);

			$recipe_submit_data = array(
				'ajaxURL'       => admin_url( 'admin-ajax.php' ),
				'uploadNonce'   => wp_create_nonce( 'inspiry_allow_upload' ),
				'fileTypeTitle' => esc_html__( 'Valid file formats', 'inspirythemes-food-recipes' ),
				'ajaxurl'       => admin_url( 'admin-ajax.php' ),
			);

			// Enqueue Scripts.
			wp_register_script( 'jsEasing', $jscript_url . 'jquery.easing.1.3.js', array( 'jquery' ), '1.3', true );
			wp_register_script( 'prettyphoto', $jscript_url . 'prettyPhoto/js/jquery.prettyPhoto.js', array( 'jquery' ), '3.1.3', true );
			wp_register_script( 'cycle-plugin-two', $jscript_url . 'jquery.cycle2.js', array( 'jquery' ), '2.0130909', true );
			wp_register_script( 'nivoSlider', $jscript_url . 'nivo-slider/jquery.nivo.slider.js', array( 'jquery' ), '2.7.1', true );
			wp_register_script( 'accordion-slider', $jscript_url . 'accordion-slider.js', array( 'jquery' ), '1.0', true );
			wp_register_script( 'select2', 'https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js', array( 'jquery' ), '4.1.0', true );
			wp_register_script( 'bootstrap', $jscript_url . 'bootstrap.min.js', array( 'jquery' ), '3.3.7', true );
			wp_register_script( 'gmap', $jscript_url . 'gmap.js', array( 'jquery' ), '1.0.0', true );
			wp_register_script( 'custom_script', $jscript_url . 'script.js', array( 'jquery', 'jquery-ui-core' ), '1.0', true );

			wp_enqueue_script( 'jsEasing' );
			wp_enqueue_script( 'prettyphoto' );
			wp_enqueue_script( 'cycle-plugin-two' );
			wp_enqueue_script( 'nivoSlider' );
			wp_enqueue_script( 'select2' );

			$theme_framework = get_option( 'recipe_theme_framework' );
			$author_layout   = get_option( 'author_page_layout' );

			if ( 'hide' !== $theme_framework ) {
				wp_enqueue_script( 'bootstrap' );
			}
			wp_localize_script( 'custom_script', 'bootstrap', array(
				'grid'          =>  $theme_framework,
				'author_page'   =>  $author_layout,
				'empty_search_alter'    =>  esc_html__( 'Search field is empty', 'inspirythemes-food-recipes' )
			) );

			if ( is_page_template( 'template-contact.php' ) || is_singular( 'recipe' ) ) {

				/* default map query arguments */
				$google_map_arguments = array();

				// Google Map API.
				wp_enqueue_script(
					'google-map-api',
					esc_url_raw(
						add_query_arg(
							apply_filters(
								'inspiry_google_map_arguments',
								$google_map_arguments
							),
							'//maps.google.com/maps/api/js'
						)
					),
					array(),
					'3.21',
					true
				);

				wp_localize_script( 'custom_script', 'scriptVar', $map_coordinates );
			}
			if ( is_page_template( 'template-recipe-submit.php' ) ) {

				wp_localize_script( 'custom_script', 'recipeSubmit', $recipe_submit_data );
			}

			wp_localize_script( 'custom_script', 'scriptText', $common_script_strings );

			wp_enqueue_script( 'custom_script' );

			if ( is_page_template( 'template-contact.php' ) ) {
				wp_enqueue_script( 'gmap' );
			}

			if ( is_singular() ) {
				wp_enqueue_script( 'comment-reply' );
			}
		}
	}
}

add_action( 'wp_enqueue_scripts', 'load_theme_scripts' );
