<?php
/*-----------------------------------------------------------------------------------*/
/*	Load Required Font Styles
/*-----------------------------------------------------------------------------------*/

if ( ! function_exists( 'inspiry_google_fonts' ) ) :
	/**
	 * Google fonts enqueue url
	 */
	function inspiry_google_fonts() {
		$fonts_url       = '';
		$font_families   = array();
		$font_families[] = 'Droid+Sans:400,700';
		$font_families[] = 'Pacifico';

		if( get_option( 'l_slider_title_on_off' ) == 'on' ){
			$font_families[] = ucwords( str_replace( ' ', '+', get_option( 'l_slider_title_typography-font-family' ) ) );
		}

		if ( ! empty( $font_families ) ) {
			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);

			$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
		}

		return esc_url_raw( $fonts_url );
	}
endif;

/**
 * For Loading Required CSS Files
 */
if ( ! function_exists( 'load_my_styles' ) ) {
	function load_my_styles() {
		if ( ! is_admin() ) {

			// Theme main stylesheet
			wp_enqueue_style( 'foodrecipes-style', get_stylesheet_uri(), array(), wp_get_theme()->get( 'Version' ) );

			// Theme stylesheet.
			wp_enqueue_style( 'inspiry-google-fonts', inspiry_google_fonts(), array() );
			wp_register_style( 'nivoslider', get_template_directory_uri() . '/js/nivo-slider/nivo-slider.css' );
			wp_register_style( 'prettyPhoto', get_template_directory_uri() . '/js/prettyPhoto/css/prettyPhoto.css' );
			wp_register_style( 'select2', 'https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css' );
			wp_register_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css' );
			wp_register_style( 'blueskin', get_template_directory_uri() . '/skin/blue/blue.css' );
			wp_register_style( 'redskin', get_template_directory_uri() . '/skin/red/red.css' );
			wp_register_style( 'orangeskin', get_template_directory_uri() . '/skin/orange/orange.css' );
			wp_register_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.css' );
			wp_register_style( 'main', get_template_directory_uri() . '/css/main.css' );
			wp_register_style( 'print', get_template_directory_uri() . '/css/print.css' );

			wp_enqueue_style( 'nivoslider' );
			wp_enqueue_style( 'prettyPhoto' );
			wp_enqueue_style( 'select2' );
			wp_enqueue_style( 'font-awesome' );
			wp_enqueue_style( 'main' );
			wp_enqueue_style( 'print' );

			/* Theme Skins */
			$theme_skin = get_option( 'skin_set' );
			if ( ! empty( $theme_skin ) ) {
				$theme_framework = get_option( 'recipe_theme_framework' );
			} else {
				$theme_framework = 'hide';
			}


			if ( isset( $_GET['skin'] ) ) {
				$theme_skin = $_GET['skin'];
			} elseif ( isset( $_COOKIE['skin'] ) ) {
				$theme_skin = $_COOKIE['skin'];
			}
			if ( ! empty( $theme_skin ) ) {
				switch ( $theme_skin ) {
					case 'skin_blue':
						wp_enqueue_style( 'blueskin' );
						break;
					case 'skin_red':
						wp_enqueue_style( 'redskin' );
						break;
					case 'skin_orange':
						wp_enqueue_style( 'orangeskin' );
						break;
				}
			}
			wp_enqueue_style( 'responsive' );

			if ( ! empty( $theme_framework ) && 'hide' !== $theme_framework ) {
				wp_enqueue_style( 'bootstrap' );
			}
		}
	}
}
add_action( 'wp_enqueue_scripts', 'load_my_styles' );


if ( ! function_exists( 'inspiry_gutenberg_editor_fonts' ) ) {
	/**
	 * WP Theme Editor Fonts
	 */
	function inspiry_gutenberg_editor_fonts() {
		wp_enqueue_style(
			'inspiry-gutenberg-google-fonts',
			inspiry_google_fonts(),
			array(),
			'1.0',
			'all'
		);
	}

	if( is_admin() ){
		add_action( 'enqueue_block_assets', 'inspiry_gutenberg_editor_fonts' );
	}
}

if ( ! function_exists( 'inspiry_generate_dynamic_css' ) ) :
	/**
	 * Add dynamic styling from theme.
	 */
	function inspiry_generate_dynamic_css() {

		$color       = get_option( 'recipe_styles-font-color' );
		$font_family = get_option( 'recipe_styles-font-family' );
		$font_size   = get_option( 'recipe_styles-font-size' );
		$font_weight = get_option( 'recipe_styles-font-weight' );
		$line_height = get_option( 'recipe_styles-line-height' );

		$color2       = get_option( 'heading_styles-font-color' );
		$font_family2 = get_option( 'heading_styles-font-family' );
		$font_weight2 = get_option( 'heading_styles-font-weight' );
		$line_height2 = get_option( 'heading_styles-line-height' );

		$change_slider_heading_styles = get_option( 'l_slider_title_on_off' );
		if( $change_slider_heading_styles == 'on' ){
			$color3       = get_option( 'l_slider_title_typography-font-color' );
			$font_family3 = get_option( 'l_slider_title_typography-font-family' );
			$font_size3   = get_option( 'l_slider_title_typography-font-size' );
			$font_weight3 = get_option( 'l_slider_title_typography-font-weight' );
			$line_height3 = get_option( 'l_slider_title_typography-line-height' );
		}

		$custom_css = "
		body{
		  color : {$color};
		  font-size : {$font_size};
		  font-family : {$font_family};
		  font-weight : {$font_weight};
		  line-height : {$line_height};
	    }
	    h1,h2,h3,h4,h5,h6,h1 a,h2 a,h3 a,h4 a,h5 a,h6 a,
	    #left-area .recipe-cat-info li.about,
	    #left-area .recipe-cat-info li,
	    #left-area .recipe-info li,
	    #left-area .info-left .recipe-tags span,
	    form label{
		  color : {$color2};
		  font-family : {$font_family2};
		  font-weight : {$font_weight2};
		 line-height : {$line_height2};
	    }
	    ";

		if( $change_slider_heading_styles == 'on' ){
			$custom_css .= "
		#slider.slider2 .slider-head{
		  color:{$color3};
		  font-size:{$font_size3};
		  font-family:{$font_family3};
		  font-weight:{$font_weight3};
		  line-height:{$line_height3};
	    }
		";
		}

		$custom_css .= "
		h1 span, h2 span, h3 span, h4 span, h5 span, h6 span,p,a{
		  color : {$color};
	    }
		";
		wp_add_inline_style( 'main', $custom_css );
	}

	add_action( 'wp_enqueue_scripts', 'inspiry_generate_dynamic_css', 12 );
endif;


if( class_exists( 'Post_Views_Counter' ) ){
	/**
	 * dequeue styles to manage progress of the theme
	 */
	function inspiry_dequeue_extra_plugin_styles(){
		wp_dequeue_style( 'post-views-counter-frontend' );
	}

	add_action( 'wp_enqueue_scripts', 'inspiry_dequeue_extra_plugin_styles', 100 );
}

/**
 * Adding admin styles
 */
if ( ! function_exists( 'inspiry_admin_styles' ) ) {
	function inspiry_admin_styles() {
		$admin_styles_url = get_template_directory_uri() . '/css/inspiry-admin-styles.css';
		wp_enqueue_style( 'inspiry-admin-styles', $admin_styles_url );
	}

	add_action( 'admin_enqueue_scripts', 'inspiry_admin_styles' );
}

// Stopping the WP Favourite Post Plugin CSS
if( function_exists( 'wpfp_get_option' ) ){
	$wpfp_options = get_option('wpfp_options');
	$wpfp_options['dont_load_css_file'] = true;
	update_option('wpfp_options', $wpfp_options);
}