<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Food Recipe
 * @since 1.4
 * @version 1.4
 */

?><!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	<?php
	$theme_framework = get_option( 'recipe_theme_framework', 'hide' );
	wp_head();
	?>
</head>
<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<?php if ( ! empty( $theme_framework ) && 'hide' !== $theme_framework ) { ?>
	<div id="main-loader"><img src="<?php echo get_template_directory_uri(); ?>/images/main-loader.gif" alt="Loader"></div>
<?php } ?>

<!-- ============= HEADER STARTS HERE ============== -->
<div id="header-wrapper" class="clearfix">
	<div id="header" class="container clearfix">
		<?php
		global $theme_framework;
		$sitelogo = get_option( 'header_logo_image' );
		$sitename = get_bloginfo( 'name' );

		if ( has_custom_logo() ) {
			$sitelogo = get_theme_mod( 'custom_logo' );
		}

		if ( ! empty( $sitelogo ) ) {
			?>
			<a class="responsive_logo" href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( wp_get_attachment_url( $sitelogo ) ); ?>" alt="<?php the_title_attribute( array( 'post' => $sitelogo ) ); ?>" class="logo"/></a>
			<?php echo ( is_page_template( 'template-home.php' ) ) ? '<h1 class="sitenametext">' . esc_attr( $sitename ) . '</h1>' : ''; ?>
			<?php
		} else {
			if ( is_front_page() ) {
				echo '<h1 class="logotext"><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_attr( $sitename ) . '</a></h1>';
			} else {
				echo '<h2 class="logotext"><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_attr( $sitename ) . '</a></h2>';
			}
		}

		$header_image       = get_header_image();
		$header_image_on_of = get_option( 'header_image_on_off' );
		$header_image_ot    = get_option( 'header_image' );

		if ( ! empty( $header_image ) ) {
			?>
			<img class="header-img" src="<?php echo esc_url( $header_image ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" alt="<?php the_title_attribute( array( 'post' => $sitelogo ) ); ?>"/>
			<?php
		} else {
			if ( ! empty( $header_image_ot ) && ( 'on' === $header_image_on_of ) ) {
				echo '<img class="header-img" src="' . esc_url( $header_image_ot ) . '" alt="' . esc_html( $sitename ) . '" />';
			}
			?>
			<?php
		}

		global $wp;
		$header_user_menu_on = get_option( 'header_user_menu_show_hide' );
		$current_page_url    = add_query_arg( $wp->query_string, '', home_url( $wp->request ) );
		if ( 'on' === $header_user_menu_on ) {
			?>
			<div class="header-user-nav">
				<ul>
					<?php
					if ( is_user_logged_in() ) {
						$current_user = wp_get_current_user();
						?>
						<li>
							<a href="<?php echo esc_url( get_author_posts_url( $current_user->ID ) ); ?>">
								<i class="fa fa-user"></i> &nbsp;
								<?php echo esc_html( $current_user->display_name ); ?>
							</a>
						</li>
						<li>
							<a href="<?php echo esc_url( wp_logout_url( $current_page_url ) ); ?>">
								<i class="fa fa-sign-out"></i>
								&nbsp;<?php echo esc_html__( 'Logout', 'inspirythemes-food-recipes' ); ?>
							</a>
						</li>
						<?php
					} else {
						$login_text = ( 1 === get_option( 'users_can_register' ) ) ? esc_html__( 'Login / Register', 'inspirythemes-food-recipes' ) : esc_html__( 'Login', 'inspirythemes-food-recipes' );
						?>
						<li>&nbsp;
							<a href="<?php echo esc_url( wp_login_url( $current_page_url ) ); ?>">
								<i class="fa fa-sign-out"></i> &nbsp;
								<?php echo esc_html( $login_text ); ?>
							</a>
						</li>
						<?php
					}
					?>
				</ul>
			</div>
			<?php
		}

		?>

	</div><!-- end of header div -->

	<span class="w-pet-border"></span>

	<!-- NAVIGATION BAR STARTS HERE -->
	<div id="nav-wrap">
		<div class="inn-nav container clearfix">
			<div class="row">
				<!-- MAIN NAVIGATION STARTS HERE -->
				<div class="col-md-10">
					<?php
					wp_nav_menu( array(
						'theme_location' => 'main-menu',
						'container'      => false,
						'menu_class'     => 'nav',
						'fallback_cb'    => false
					) );
					?>
				</div>
				<!-- MAIN NAVIGATION ENDS HERE -->
				<div class="col-md-2">
					<!-- SOCIAL NAVIGATION -->
					<?php
					wp_nav_menu( array(
						'theme_location' => 'social-menu',
						'container'      => false,
						'menu_class'     => 'social-nav',
						'fallback_cb'    => false
					) );
					?>
				</div>
			</div>
		</div>
	</div><!-- end of nav-wrap -->
	<!-- NAVIGATION BAR ENDS HERE -->

</div><!-- end of header-wrapper div -->

<!-- ============= HEADER ENDS HERE ============== -->


<!-- ============= CONTAINER STARTS HERE ============== -->
<div class="main-wrap">
	<div id="container" class="container">

		<!-- WEBSITE SEARCH STARTS HERE -->
		<?php
		$adv_search          = get_option( 'adv_search_show_hide' );
		$adv_search_pages    = get_option( 'adv_search_page_checkbox' );
		$adv_search_pages    = ! is_array( $adv_search_pages ) ? explode( ',', $adv_search_pages ) : $adv_search_pages;
		$adv_search_page_url = get_option( 'adv_search_page_url' );
		$page_id             = get_the_ID();
		$adv_search_class    = '';
		if ( 'on' === $adv_search && ! empty( $adv_search_page_url ) && ! empty( $adv_search_pages ) && ( in_array( "$page_id", $adv_search_pages, true ) ) ) {
			$adv_search_class = 'adv-search';
			$search_template  = 'inc/advance-search';
		} else {
			$search_template = 'inc/simple-search';
		}
		?>
		<div class="top-search clearfix <?php echo esc_attr( $adv_search_class ); ?>">
			<h3 class="head-pet"><span><?php esc_html_e( 'Recipe Search', 'inspirythemes-food-recipes' ); ?></span></h3>
			<div class="row">
				<?php
				get_template_part( $search_template );
				?>
			</div>
		</div>
		<!-- end of top-search div-->

		<!-- ============= CONTENT AREA STARTS HERE ============== -->
		<div id="content" class="clearfix <?php echo is_page_template( 'template-home.php' ) ? 'homepage' : ''; ?>">
