<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for parent theme Inspiry Food Recipes for publication on ThemeForest
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once get_template_directory() . '/inc/tgm/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'inspiry_food_recipes_theme_register_required_plugins' );

/**
 * Register the required plugins for this theme.
 *
 * In this example, we register five plugins:
 * - one included with the TGMPA library
 * - two from an external source, one from an arbitrary source, one from a GitHub repository
 * - two from the .org repo, where one demonstrates the use of the `is_callable` argument
 *
 * The variables passed to the `tgmpa()` function should be:
 * - an array of plugin arrays;
 * - optionally a configuration array.
 * If you are not changing anything in the configuration array, you can remove the array and remove the
 * variable from the function call: `tgmpa( $plugins );`.
 * In that case, the TGMPA default settings will be used.
 *
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */

function inspiry_food_recipes_theme_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		// Classic Editor.
		array(
			'name'     => 'Food Recipes Pack', // The plugin name.
			'slug'     => 'food-recipes-pack', // The plugin slug (typically the folder name).
			'source'   => 'https://inspiry-plugins.s3.us-east-2.amazonaws.com/foodrecipes/food-recipes-pack/1.x/food-recipes-pack.zip', // The plugin source.
			'required' => true, // If false, the plugin is only 'recommended' instead of required.
			'version'  => '1.0.5',
		),
		// Display Tweets twitter feed plugin.
		array(
			'name'     => esc_html__( 'Post Views Counter', 'inspirythemes-food-recipes' ),
			'slug'     => 'post-views-counter',
			'required' => false,
		),
		// Display Tweets twitter feed plugin.
		array(
			'name'     => esc_html__( 'Quick and Easy Tweets', 'inspirythemes-food-recipes' ),
			'slug'     => 'quick-and-easy-tweets',
			'required' => false,
		),
		// WP Favorite Posts plugin.
		array(
			'name'     => esc_html__( 'WP Favorite Posts', 'inspirythemes-food-recipes' ),
			'slug'     => 'wp-favorite-posts',
			'required' => false,
		),
		// Inspiry One Click Demo.
		array(
			'name'     => esc_html__( 'One Click Demo Import', 'inspirythemes-food-recipes' ),
			'slug'     => 'one-click-demo-import',
			'required' => false,
		),
		// Social Plugin plugin
		array(
			'name'      => esc_html__( 'Easy Social Icons', 'inspirythemes-food-recipes' ),
			'slug'      => 'easy-social-icons',
			'required'  => false
		)
	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'inspiry-food-recipes-theme',
		// Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',
		// Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins',
		// Menu slug.
		'has_notices'  => true,
		// Show admin notices or not.
		'dismissable'  => true,
		// If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',
		// If 'dismissible' is false, this message will be output at top of nag.
		'is_automatic' => false,
		// Automatically activate plugins after installation or not.
		'message'      => '',
		// Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}