<?php
/*
* Template Name: All Chefs List
*/
get_header();

if ( is_active_sidebar( 'sidebar-11' ) ) {
	$wrap_classes = 'col-md-8';
} else {
	$wrap_classes = 'col-md-12 full-wide';
}
?>
	<div class="row recipe-listing-row">
		<div id="left-area" class="users-listing clearfix <?php echo esc_attr( $wrap_classes ); ?>">
			<h1><?php the_title(); ?></h1>
			<span class="w-pet-border"></span>

			<?php
			if ( have_posts() ) :
				while ( have_posts() ) :
					the_post();
					$content_data = get_the_content();
					if ( ! empty( $content_data ) ) {
						?>
						<div <?php post_class(); ?> id="page-<?php the_ID(); ?>">
							<?php
							if ( has_post_thumbnail() ) {
								$image_id  = get_post_thumbnail_id();
								$image_url = wp_get_attachment_image_src( $image_id, 'full-size', true );
								?>
								<div class="post-thumb single-img-box">
									<a rel="prettyPhoto" title="<?php the_title_attribute(); ?>"
									   href="<?php echo esc_url( $image_url[0] ); ?>">
										<?php the_post_thumbnail( 'thumbnail-blog' ); ?>
									</a>
								</div>
								<?php
							}
							the_content();
							?>
						</div><!-- end of post div -->
						<?php
					}
				endwhile;
			endif;
			?>

			<br/>

			<?php
			$head_id       = get_option( 'listing_head_chef_id', 0 );
			$subs_included = get_option( 'skip_subscriber_from_listing', 'false' );
			if ( $head_id ) {
				$user_data        = get_userdata( $head_id );
				$get_photo_url    = get_user_meta( $head_id, 'photo', true );
				$user_description = get_user_meta( $head_id, 'description', true );
				$user_designation = get_user_meta( $head_id, 'user_designation', true );
				$user_website     = get_user_meta( $head_id, 'url', true );
				$user_twitter     = get_user_meta( $head_id, 'twitter', true );
				$user_facebook    = get_user_meta( $head_id, 'facebook', true );
				$user_google      = get_user_meta( $head_id, 'google', true );
				$user_linkedin    = get_user_meta( $head_id, 'linkedin', true );
				$user_youtube     = get_user_meta( $head_id, 'youtube', true );
				$user_page_link   = get_author_posts_url( $head_id );
				?>
				<div class="user-head-wrap">
					<figure class="author-wrap">
						<a href="<?php echo esc_url( $user_page_link ); ?>">
							<?php
							if ( $get_photo_url ) {
								$attachment_id = get_attachment_id_from_src( esc_url( $get_photo_url ) );
								$user_thumb    = wp_get_attachment_image_src( $attachment_id, 'user-listing-thumb', false );
								if ( $user_thumb ) {
									?>
									<img src="<?php echo esc_url( $user_thumb[0] ); ?>" alt="<?php echo esc_attr( $user_data->display_name ); ?>"/>
									<?php
								} else {
									echo '<img src="' . get_template_directory_uri() . '/images/noimage.png" alt="' . esc_attr( $user_data->display_name ) . '" />';
								}
							} else {
								echo '<img src="' . get_template_directory_uri() . '/images/noimage.png" alt="' . esc_attr( $user_data->display_name ) . '" />';
							}
							?>
						</a>
					</figure>
					<div class="head-contents-wrap">
						<h3 class="user-listing-heading">
							<a href="<?php echo esc_url( $user_page_link ); ?>"><?php echo esc_attr( $user_data->display_name ); ?></a>
							<?php if ( $user_designation ) {
							    echo '<span class="head-designation">' . esc_attr( $user_designation ) . ' //</span>';
							}; ?>
						</h3>
						<p class="counts">
							<?php
							esc_html_e( 'Posts: ', 'inspirythemes-food-recipes' );
							echo count_user_posts( $head_id );
							?>
                            <span>//</span>
                            <?php
							esc_html_e( 'Recipes: ', 'inspirythemes-food-recipes' );
							echo count_user_posts_by_type( $head_id, 'recipe' );
							?>
						</p>
						<div class="head-bottom">
							<p class="social">
								<?php
								if ( $user_website ) {
									echo '<a class="url" href="' . esc_url( $user_website ) . '"><i class = "fa fa-google"></i></a>';
								};
								if ( $user_twitter ) {
									echo '<a class="twitter" href="' . esc_url( $user_twitter ) . '"><i class = "fa fa-twitter"></i></a>';
								};
								if ( $user_facebook ) {
									echo '<a class="facebook" href="' . esc_url( $user_facebook ) . '"><i class = "fa fa-facebook"></i></a>';
								};
								if ( $user_linkedin ) {
									echo '<a class="linkedin" href="' . esc_url( $user_linkedin ) . '"><i class = "fa fa-linkedin"></i></a>';
								};
								if ( $user_youtube ) {
									echo '<a class="youtube" href="' . esc_url( $user_youtube ) . '"><i class = "fa fa-youtube"></i></a>';
								};
								?>
							</p>
						</div>
					</div>
					<?php
					if( !empty( $user_description ) ){
						?>
						<p class="user-description"><?php echo esc_html( $user_description ); ?></p>
						<?php
					}
					?>
					<a class="head-readmore readmore" href="<?php echo esc_url( $user_page_link ); ?>"><?php esc_html_e( 'Read more', 'inspirythemes-food-recipes' ); ?></a>
				</div>
				<?php
			}
			?>

			<div class="user-listing-wrap row">
				<?php
				$author_not_post = get_option( 'skip_users_with_no_post' );
				$all_users       = get_users();
				foreach ( $all_users as $user ) {
					$author_not_post = get_option( 'skip_users_with_no_post' );

					$user_posts   = count_user_posts( $user->ID );
					$user_recipes = count_user_posts_by_type( $user->ID, 'recipe' );
					if ( $user_posts > 0 || $user_recipes > 0 || 'false' !== $author_not_post ) {
						if ( $user->ID === $head_id ) {
							continue;
						}
						if ( 'false' === $subs_included ) {
							if ( 'subscriber' === $user->roles[0] ) {
								continue;
							}
						}
						$get_photo_url    = get_user_meta( $user->ID, 'photo', true );
						$user_description = get_user_meta( $user->ID, 'description', true );
						$user_designation = get_user_meta( $user->ID, 'user_designation', true );
						$user_website     = get_user_meta( $user->ID, 'url', true );
						$user_twitter     = get_user_meta( $user->ID, 'twitter', true );
						$user_facebook    = get_user_meta( $user->ID, 'facebook', true );
						$user_linkedin    = get_user_meta( $user->ID, 'linkedin', true );
						$user_youtube     = get_user_meta( $user->ID, 'youtube', true );
						$user_page_link   = get_author_posts_url( $user->ID );
						?>
						<div class="user-list-col col-xs-4">
							<h3 class="user-listing-heading"><a
										href="<?php echo esc_url( $user_page_link ); ?>"><?php echo esc_attr( $user->display_name ); ?></a>
							</h3>
							<figure class="author-wrap">
								<a href="<?php echo esc_url( $user_page_link ); ?>">
									<?php
									if ( $get_photo_url ) {
										$attachment_id = get_attachment_id_from_src( esc_url( $get_photo_url ) );
										$user_thumb    = wp_get_attachment_image_src( $attachment_id, 'user-listing-thumb', false );
										if ( $user_thumb ) {
											?>
											<img src="<?php echo esc_url( $user_thumb[0] ); ?>"
												 alt="<?php echo esc_attr( $user->display_name ); ?>"/>
											<?php
										} else {
											echo '<img src="' . get_template_directory_uri() . '/images/noimage.png" alt="' . esc_attr( $user->display_name ) . '" />';
										}
									} else {
										echo '<img src="' . get_template_directory_uri() . '/images/noimage.png" alt="' . esc_attr( $user->display_name ) . '" />';
									}
									?>
								</a>
							</figure>
							<?php if ( $user_designation ) {
							    echo '<h5 class="user-role">' . esc_attr( $user_designation ) . ' //</h5>';
							}; ?>
							<p class="counts"><?php esc_html_e( 'Posts: ', 'inspirythemes-food-recipes' );
								echo esc_html( $user_posts ); ?> <span>//</span><?php esc_html_e( 'Recipes: ', 'inspirythemes-food-recipes' );
								echo esc_html( $user_recipes ); ?></p>
							<?php
							echo '<p class="user-description">' . wp_trim_words( esc_attr( $user_description ), 11, '...<a href="' . esc_url( $user_page_link ) . '">more</a>' ) . '</p>';
							?>
							<p class="social">
								<?php
								if ( $user_website ) {
									echo '<a class="url" href="' . esc_url( $user_website ) . '"><i class = "fa fa-google"></i></a>';
								};
								if ( $user_twitter ) {
									echo '<a class="twitter" href="' . esc_url( $user_twitter ) . '"><i class = "fa fa-twitter"></i></a>';
								};
								if ( $user_facebook ) {
									echo '<a class="facebook" href="' . esc_url( $user_facebook ) . '"><i class = "fa fa-facebook"></i></a>';
								};
								if ( $user_linkedin ) {
									echo '<a class="linkedin" href="' . esc_url( $user_linkedin ) . '"><i class = "fa fa-linkedin"></i></a>';
								};
								if ( $user_youtube ) {
									echo '<a class="youtube" href="' . esc_url( $user_youtube ) . '"><i class = "fa fa-youtube"></i></a>';
								};
								?>
							</p>
						</div>
						<?php
					}
				}
				?>
			</div>
		</div><!-- end of left-area -->
		<!-- LEFT AREA ENDS HERE -->
		<?php if ( is_active_sidebar( 'sidebar-11' ) ) { ?>
            <div id="sidebar" class="col-md-4">
				<?php
				dynamic_sidebar( 'sidebar-11' );
				?>
            </div><!-- end of sidebar -->
		<?php } ?>

    </div>
<?php
get_footer();
