<?php
/*
* Template Name: Submit Recipe
*/

$show_message = false;

if ( ! empty( $_POST['action'] ) && 'submit-recipe' === $_POST['action'] ) { // WPCS: CSRF input var ok.

	$title             = wp_kses_post( $_POST['inspiry_recipe_title'] ); // WPCS: CSRF input var ok.
	$short_description = esc_html( $_POST['short-description'] ); // WPCS: CSRF input var ok.
	$description       = wp_kses_post( $_POST['description'] ) . ' [ingredients][method]'; // WPCS: CSRF input var ok.

	// ADD THE FORM INPUT TO $new_recipe ARRAY.
	$new_recipe = array(
		'post_title'   => $title,
		'post_content' => $description,
		'post_excerpt' => $short_description,
		'post_status'  => 'pending',    // Choose: publish, pending, future, draft, etc.
		'post_type'    => 'recipe',
	);

	if ( is_user_logged_in() ) {
		global $current_user;
		wp_get_current_user();
		$new_recipe['post_author'] = $current_user->ID;
	}

	// SAVE THE POST.
	$recipe_id = wp_insert_post( $new_recipe );

	// Attache Post Meta
	if ( isset( $_POST['yield'] ) ) {
		add_post_meta( $recipe_id, 'RECIPE_META_yield', sanitize_text_field( $_POST['yield'] ), true );
	}

	if ( isset( $_POST['servings'] ) ) {
		add_post_meta( $recipe_id, 'RECIPE_META_servings', sanitize_text_field( $_POST['servings'] ), true );
	}

	if ( isset( $_POST['prep-time'] ) ) {
		add_post_meta( $recipe_id, 'RECIPE_META_prep_time', sanitize_text_field( $_POST['prep-time'] ), true );
	}

	if ( isset( $_POST['cook-time'] ) ) {
		add_post_meta( $recipe_id, 'RECIPE_META_cook_time', sanitize_text_field( $_POST['cook-time'] ), true );
	}

	if ( isset( $_POST['ready-in'] ) ) {
		add_post_meta( $recipe_id, 'RECIPE_META_ready_in', sanitize_text_field( $_POST['ready-in'] ), true );
	}

	// =====================
	if ( isset( $_POST['ingredient'] ) ) {
		add_post_meta( $recipe_id, 'RECIPE_META_ingredients', $_POST['ingredient'], true );
	}

	if ( isset( $_POST['recipe_step'] ) ) {
		add_post_meta( $recipe_id, 'RECIPE_META_method_steps', $_POST['recipe_step'], true );
	}

	if ( isset( $_POST['video_based_recipe'] ) ) {
		add_post_meta( $recipe_id, 'RECIPE_META_recipe_video_check', wp_kses_post( $_POST['video_based_recipe'] ), true );
	}


	if ( isset( $_POST['video_embed_code'] ) ) {
		add_post_meta( $recipe_id, 'RECIPE_META_recipe_video_code', wp_kses( $_POST['video_embed_code'], [ 'iframe' => ['src' => [],'allowfullscreen' => [],'frameborder' => []]] ), true );
	}

	if ( isset( $_POST[ 'gallery_image_ids' ] ) ) {

		if ( ! empty ( $_POST[ 'gallery_image_ids' ] ) && is_array( $_POST[ 'gallery_image_ids' ] ) ) {
			$gallery_image_ids = array();
			foreach ( $_POST[ 'gallery_image_ids' ] as $gallery_image_id ) {
				$gallery_image_ids[] = intval( $gallery_image_id );
				add_post_meta( $recipe_id, 'RECIPE_META_more_images_recipe', $gallery_image_id );
			}
			if ( isset( $_POST[ 'featured_image_id' ] ) ) {
				$featured_image_id = intval( $_POST[ 'featured_image_id' ] );
				if ( in_array( $featured_image_id, $gallery_image_ids ) ) {     // validate featured image id
					update_post_meta( $recipe_id, '_thumbnail_id', $featured_image_id );
				}
			} elseif ( ! empty ( $gallery_image_ids ) ) {
				update_post_meta( $recipe_id, '_thumbnail_id', $gallery_image_ids[ 0 ] );
			}
		}
	}

	// Attach Recipe Taxonomies to created recipe
	if ( isset( $_POST['recipe-type'] ) && ( $_POST['recipe-type'] != "-1" ) ) {
		wp_set_object_terms( $recipe_id, intval( sanitize_text_field( $_POST['recipe-type'] ) ), 'recipe_type' );
	}

	if ( isset( $_POST['skill-level'] ) && ( $_POST['skill-level'] != "-1" ) ) {
		wp_set_object_terms( $recipe_id, intval( sanitize_text_field( $_POST['skill-level'] ) ), 'skill_level' );
	}

	if ( isset( $_POST['cuisine'] ) && ( $_POST['cuisine'] != "-1" ) ) {
		wp_set_object_terms( $recipe_id, intval( sanitize_text_field( $_POST['cuisine'] ) ), 'cuisine' );
	}

	if ( isset( $_POST['course'] ) && ( $_POST['course'] != "-1" ) ) {
		wp_set_object_terms( $recipe_id, intval( sanitize_text_field( $_POST['course'] ) ), 'course' );
	}


	$post_tags_pre = wp_kses_post( $_POST['tags'] );
	if ( ! empty( $post_tags_pre ) ) {
		$post_tags_array = explode( ',', $post_tags_pre );
		if ( is_array( $post_tags_array ) && ! empty( $post_tags_array ) ) {
			wp_set_post_tags( $recipe_id, $post_tags_array );
		}
	}

	$show_message = true;
	$rs_address   = get_option( 'submit_recipe_email_target' );
	if ( ! empty( $rs_address ) && class_exists( 'Food_Recipes_Pack_Mail' ) ) {

		$recipe_submit = new Food_Recipes_Pack_Mail();
		$recipe_submit->recipe_submit_mail( $rs_address, $title, $short_description );
	}
} // END THE IF STATEMENT THAT STARTED THE WHOLE FORM

//POST THE POST YO
do_action( 'wp_insert_post', 'wp_insert_post' );

get_header();

if ( is_active_sidebar( 'recipe-submit' ) ) {
	$wrap_classes = 'col-md-8';
} else {
	$wrap_classes = 'col-md-12 full-wide';
}
?>
    <div class="row recipe-listing-row">
        <div id="left-area" class="clearfix <?php echo esc_attr( $wrap_classes ); ?>">
			<?php
			if ( have_posts() ) :
				while ( have_posts() ) :
					the_post();
				?>
                <div <?php post_class(); ?> id="page-<?php the_ID(); ?>">
                    <h1 class="post-title"><?php the_title(); ?></h1>
                    <p class="meta"><span
                                class="comments"><?php comments_popup_link( esc_html__( '0 Comments', 'inspirythemes-food-recipes' ), esc_html__( '1 Comment', 'inspirythemes-food-recipes' ), esc_html__( '% Comments', 'inspirythemes-food-recipes' ) ); ?></span>
                        <span>|</span> <?php esc_html__( 'Last Update:', 'inspirythemes-food-recipes' ); ?>
                        <span> <?php the_time( get_option( 'date_format' ) ); ?></span></p>
					<?php
					if ( has_post_thumbnail() ) {
						?>
                        <div class="post-thumb single-img-box">
                            <a rel="prettyPhoto" title="<?php the_title_attribute(); ?>"
                               href="<?php $image_id = get_post_thumbnail_id();
							   $image_url            = wp_get_attachment_image_src( $image_id, 'full-size', true );
							   echo esc_url( $image_url[0] );
							   ?>">
								<?php the_post_thumbnail( 'thumbnail-blog' ); ?>
                            </a>
                        </div>
						<?php
					}

					the_content();
					?>
                </div><!-- end of post div -->

			<?php
				endwhile;
			endif;

			if ( is_user_logged_in() ) {
				if( class_exists( 'Food_Recipes_Pack_Public' ) ){
					Food_Recipes_Pack_Public::render_submit_recipe( $show_message );
                }
			} else {
				if( class_exists( 'Food_Recipes_Pack_Public' ) ){
					Food_Recipes_Pack_Public::render_submit_login_forms();
				}
				?>

				<?php
			}
			?>
        </div><!-- end of left-area -->
        <!-- LEFT AREA ENDS HERE -->
	    <?php if ( is_active_sidebar( 'recipe-submit' ) ) { ?>
		    <div id="sidebar" class="col-md-4">
			    <?php
			    dynamic_sidebar( 'recipe-submit' );
			    ?>
		    </div><!-- end of sidebar -->
	    <?php } ?>
    </div>
<?php get_footer(); ?>